@@ -1,7 +1,7 @@
-(use-modules (lepton core toplevel)
+(use-modules (lepton attrib)
              (lepton object)
-             (lepton attrib)
-             (lepton page))
+             (lepton page)
+             (lepton toplevel))
 
 (define (make-attribs)
   (list
