@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,11 +24,11 @@
 #include <glib.h>  /* Include needed to make GList work. */
 
 /* Wrappers around a new list mechanism */
-typedef struct _GedaList SELECTION;
-typedef struct _GedaList GedaPageList;
+typedef struct _LeptonList LeptonSelection;
+typedef struct _LeptonList LeptonPageList;
 
 /* lepton-schematic structures */
-typedef struct st_conn CONN;
+typedef struct st_conn LeptonConn;
 
 /* Managed text buffers */
 typedef struct _TextBuffer TextBuffer;
@@ -49,7 +49,7 @@ typedef enum { F_OPEN_RC           = 1,
 } FOpenFlags;
 
 
-/*! \brief Structure for connections between OBJECTs
+/*! \brief Structure for connections between LeptonObjects
  *
  * The st_conn structure contains a single connection
  * to another object.
@@ -57,7 +57,7 @@ typedef enum { F_OPEN_RC           = 1,
  */
 struct st_conn {
   /*! \brief The "other" object connected to this one */
-  OBJECT *other_object;
+  LeptonObject *other_object;
   /*! \brief type of connection. Always in reference to how the "other"
     object is connected to the current one */
   int type;
@@ -72,17 +72,11 @@ struct st_conn {
 };
 
 /*! \brief Type of callback function for object damage notification */
-typedef int(*ChangeNotifyFunc)(void *, OBJECT *);
+typedef int(*ChangeNotifyFunc)(void *, LeptonObject *);
 
 /*! \brief Type of callback function for querying loading of backups */
 typedef gboolean(*LoadBackupQueryFunc)(void *, GString *);
 
-/* used by the rc loading mechanisms */
-typedef struct {
-  int   m_val;
-  const char *m_str;
-} vstbl_entry;
-
 /* Used by g_rc_parse_handler() */
 typedef void (*ConfigParseErrorFunc)(GError **, void *);
 
