@@ -64,6 +64,18 @@ lepton_text_object_get_size (const LeptonObject *object);
 gdouble
 lepton_text_object_get_size_in_points (const LeptonObject *object);
 
+const gchar*
+lepton_text_object_get_name (const LeptonObject *object);
+
+void
+lepton_text_object_set_name (const LeptonObject *object,
+                             const char *name);
+const gchar*
+lepton_text_object_get_value (const LeptonObject *object);
+
+void
+lepton_text_object_set_value (LeptonObject *object,
+                              const char *value);
 const gchar*
 lepton_text_object_get_string (const LeptonObject *object);
 
@@ -140,6 +152,9 @@ lepton_text_object_set_visibility (LeptonObject *object,
 gint
 lepton_text_object_get_visibility (const LeptonObject *object);
 
+const char*
+lepton_text_object_visible_string (const LeptonObject *object);
+
 const char*
 lepton_text_object_alignment_to_string (gint alignment);
 
