@@ -89,12 +89,6 @@
 
 void edascm_init_smob ();
 void edascm_init_toplevel ();
-void edascm_init_component ();
-void edascm_init_page ();
-void edascm_init_attrib ();
-void edascm_init_config ();
-void edascm_init_closure (void);
-void edascm_init_rc ();
 
 /* ---------------------------------------- */
 
@@ -115,8 +109,6 @@ enum geda_smob_flags {
   GEDA_SMOB_TOPLEVEL = 0,
   GEDA_SMOB_PAGE = 1,
   GEDA_SMOB_OBJECT = 2,
-  GEDA_SMOB_CONFIG = 3,
-  GEDA_SMOB_CLOSURE = 4,
   GEDA_SMOB_TYPE_MASK = 0xf,
   GEDA_SMOB_GC_FLAG = 0x100
 };
@@ -165,12 +157,6 @@ SCM edascm_from_toplevel (LeptonToplevel *toplevel);
 /*! Tests whether a Scheme value is an LeptonObject smob. */
 #define EDASCM_OBJECTP(x) EDASCM_SMOB_TYPEP(x, GEDA_SMOB_OBJECT)
 
-/*! Tests whether a Scheme value is an EdaConfig smob. */
-#define EDASCM_CONFIGP(x) EDASCM_SMOB_TYPEP(x, GEDA_SMOB_CONFIG)
-
-/*! Tests whether a Scheme value is a C closure smob. */
-#define EDASCM_CLOSUREP(x) EDASCM_SMOB_TYPEP(x, GEDA_SMOB_CLOSURE)
-
 /*!
  * \brief Test whether a structure may be garbage-collected
  * \par Macro Description
@@ -196,15 +182,3 @@ SCM edascm_from_toplevel (LeptonToplevel *toplevel);
                             : (SCM_SMOB_FLAGS (x) & ~GEDA_SMOB_GC_FLAG))
 
 /* ---------------------------------------- */
-
-SCM edascm_from_object_glist (const GList *objs);
-int edascm_is_object_type (SCM smob, int type);
-
-
-/* ---------------------------------------- */
-
-extern SCM edascm_object_state_sym;
-
-/* ---------------------------------------- */
-
-SCM edascm_from_closure (SCM (*func)(SCM, gpointer), gpointer user_data);
