@@ -1,9 +1,3 @@
-/* g_rc.c */
-SCM scheme_directory(SCM s_path);
-
-/* g_register.c */
-void g_register_libgeda_dirs (void);
-
 /* m_hatch.c */
 void m_hatch_polygon(GArray *points, gint angle, gint pitch, GArray *lines);
 
@@ -43,9 +37,6 @@ void s_conn_print(GList *conn_list);
 void
 s_conn_add_object (LeptonPage *page,
                    LeptonObject *object);
-void
-s_conn_remove_object (LeptonPage *page,
-                      LeptonObject *object);
 
 /* s_encoding.c */
 gchar* s_encoding_base64_encode (gchar* src, guint srclen, guint* dstlenp, gboolean strict);
