@@ -1,5 +1,5 @@
 ;;; Lepton EDA netlister
-;;; Copyright (C) 2019-2021 Lepton EDA Contributors
+;;; Copyright (C) 2019-2022 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
   #:use-module (srfi srfi-9 gnu)
   #:use-module (srfi srfi-26)
 
-  #:use-module (lepton core gettext)
+  #:use-module (lepton gettext)
   #:use-module (lepton library)
   #:use-module (lepton log)
   #:use-module (lepton object)
