@@ -1,6 +1,6 @@
 ;;; Lepton EDA Symbol Checker
 ;;; Scheme API
-;;; Copyright (C) 2017-2020 Lepton EDA Contributors
+;;; Copyright (C) 2017-2022 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
                 #:select (read-string)
                 #:prefix rdelim:)
 
-  #:use-module (lepton core gettext)
+  #:use-module (lepton gettext)
   #:use-module (lepton log)
   #:use-module (lepton page)
   #:use-module (lepton repl)
@@ -50,7 +50,7 @@ General options:
 Report bugs at <~A>
 Lepton EDA homepage: <~A>
 ")
-          (car (program-arguments))
+          (basename (car (program-arguments)))
           (lepton-version-ref 'bugs)
           (lepton-version-ref 'url))
   (primitive-exit 0))
@@ -87,7 +87,7 @@ Run `~A --help' for more information.\n")
         (version (symcheck-option-ref 'version))
         (interactive (symcheck-option-ref 'interactive)))
     (when version
-      (display-lepton-version #:print-name #t)
+      (display-lepton-version #:print-name #t #:copyright #t)
       (primitive-exit 0))
     (if help
         (usage))
