@@ -139,8 +139,8 @@ GList
     {
         /* yes */
         /* verify symbol version (not file format but rather contents) */
-        o_component_check_symversion (page, last_component);
-        last_component = NULL;  /* no longer need to check */
+      lepton_component_check_symversion (page, last_component);
+      last_component = NULL;  /* no longer need to check */
     }
 
     switch (objtype) {
@@ -184,7 +184,7 @@ GList
         break;
 
       case(OBJ_COMPONENT):
-        if ((new_obj = o_component_read (page, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = lepton_component_read (page, line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         new_object_list = g_list_prepend (new_object_list, new_obj);
 
@@ -234,7 +234,7 @@ GList
           {
             /* yes */
             /* verify symbol version (not file format but rather contents) */
-            o_component_check_symversion (page, last_component);
+            lepton_component_check_symversion (page, last_component);
             last_component = NULL;
           }
 
@@ -261,7 +261,7 @@ GList
         if (lepton_object_is_component (new_obj))
         {
           object_list_save = new_object_list;
-          new_object_list = new_obj->component->prim_objs;
+          new_object_list = lepton_component_object_get_contents (new_obj);
 
           embedded_level++;
         } else {
@@ -281,14 +281,14 @@ GList
           new_object_list = g_list_reverse (new_object_list);
 
           new_obj = (LeptonObject*) object_list_save->data;
-          new_obj->component->prim_objs = new_object_list;
+          lepton_component_object_set_contents (new_obj, new_object_list);
           new_object_list = object_list_save;
 
           /* set the parent field now */
-          for (iter = new_obj->component->prim_objs;
+          for (iter = lepton_component_object_get_contents (new_obj);
                iter != NULL; iter = g_list_next (iter)) {
             LeptonObject *tmp = (LeptonObject*) iter->data;
-            tmp->parent = new_obj;
+            lepton_object_set_parent (tmp, new_obj);
           }
 
           embedded_level--;
@@ -346,7 +346,7 @@ GList
   /* and had no attached attributes */
   if (last_component)
   {
-    o_component_check_symversion (page, last_component);
+    lepton_component_check_symversion (page, last_component);
     last_component = NULL;  /* no longer need to check */
   }
 
@@ -405,7 +405,7 @@ o_read (LeptonPage *page,
   objects = o_read_buffer (page, NULL, buffer, size, filename, err);
   g_free (buffer);
 
-  s_page_append_list (page, objects);
+  lepton_page_append_list (page, objects);
 
   return page;
 }
