@@ -67,9 +67,9 @@ lepton_arc_object_new (gint color,
    */
 
   /* World coordinates */
-  new_node->arc->x      = center_x;
-  new_node->arc->y      = center_y;
-  new_node->arc->radius = radius;
+  lepton_arc_object_set_center_x (new_node, center_x);
+  lepton_arc_object_set_center_y (new_node, center_y);
+  lepton_arc_object_set_radius (new_node, radius);
 
   /* must check the sign of start_angle, sweep_angle ... */
   if(sweep_angle < 0) {
@@ -78,8 +78,8 @@ lepton_arc_object_new (gint color,
   }
   if(start_angle < 0) start_angle = 360 + start_angle;
 
-  new_node->arc->start_angle = start_angle;
-  new_node->arc->sweep_angle = sweep_angle;
+  lepton_arc_object_set_start_angle (new_node, start_angle);
+  lepton_arc_object_set_sweep_angle (new_node, sweep_angle);
 
   /* Default init */
   lepton_object_set_line_options (new_node,
@@ -114,11 +114,11 @@ lepton_arc_object_copy (const LeptonObject *object)
   g_return_val_if_fail (object->arc != NULL, NULL);
 
   new_object = lepton_arc_object_new (lepton_object_get_color (object),
-                                      object->arc->x,
-                                      object->arc->y,
-                                      object->arc->radius,
-                                      object->arc->start_angle,
-                                      object->arc->sweep_angle);
+                                      lepton_arc_object_get_center_x (object),
+                                      lepton_arc_object_get_center_y (object),
+                                      lepton_arc_object_get_radius (object),
+                                      lepton_arc_object_get_start_angle (object),
+                                      lepton_arc_object_get_sweep_angle (object));
 
   lepton_object_set_line_options (new_object,
                                   lepton_object_get_stroke_cap_type (object),
@@ -324,23 +324,23 @@ lepton_arc_object_modify (LeptonObject *object,
   switch(whichone) {
   case ARC_CENTER:
     /* modify the center of arc object */
-    object->arc->x = x;
-    object->arc->y = y;
+    lepton_arc_object_set_center_x (object, x);
+    lepton_arc_object_set_center_y (object, y);
     break;
 
   case ARC_RADIUS:
     /* modify the radius of arc object */
-    object->arc->radius = x;
+    lepton_arc_object_set_radius (object, x);
     break;
 
   case ARC_START_ANGLE:
     /* modify the start angle of the arc object */
-    object->arc->start_angle = x;
+    lepton_arc_object_set_start_angle (object, x);
     break;
 
   case ARC_SWEEP_ANGLE:
     /* modify the end angle of the arc object */
-    object->arc->sweep_angle = x;
+    lepton_arc_object_set_sweep_angle (object, x);
     break;
 
   default:
@@ -379,11 +379,11 @@ lepton_arc_object_modify (LeptonObject *object,
  *  \param [in] fileformat_ver
  *  \return The ARC LeptonObject that was created, or NULL on error.
  */
-LeptonObject
-*o_arc_read (const char buf[],
-             unsigned int release_ver,
-             unsigned int fileformat_ver,
-             GError **err)
+LeptonObject*
+lepton_arc_object_read (const char buf[],
+                        unsigned int release_ver,
+                        unsigned int fileformat_ver,
+                        GError **err)
 {
   LeptonObject *new_obj;
   char type;
@@ -510,12 +510,17 @@ lepton_arc_object_translate (LeptonObject *object,
                              int dx,
                              int dy)
 {
+  int x, y;
+
   g_return_if_fail (lepton_object_is_arc (object));
   g_return_if_fail (object->arc != NULL);
 
+  x = lepton_arc_object_get_center_x (object);
+  y = lepton_arc_object_get_center_y (object);
+
   /* Do world coords */
-  object->arc->x = object->arc->x + dx;
-  object->arc->y = object->arc->y + dy;
+  lepton_arc_object_set_center_x (object, x + dx);
+  lepton_arc_object_set_center_y (object, y + dy);
 }
 
 /*! \brief
@@ -543,32 +548,30 @@ lepton_arc_object_rotate (int world_centerx,
                           int angle,
                           LeptonObject *object)
 {
-  int x, y, newx, newy;
+  int x, y, newx, newy, old_start_angle;
 
   g_return_if_fail (lepton_object_is_arc (object));
   g_return_if_fail (object->arc != NULL);
 
-  /* translate object to origin */
-  object->arc->x -= world_centerx;
-  object->arc->y -= world_centery;
+  /* Get arc coords and translate them to origin. */
+  x = lepton_arc_object_get_center_x (object) - world_centerx;
+  y = lepton_arc_object_get_center_y (object) - world_centery;
 
-  /* get center, and rotate center */
-  x = object->arc->x;
-  y = object->arc->y;
+  /* rotate center coords */
   if(angle % 90 == 0) {
     lepton_point_rotate_90 (x, y, angle % 360, &newx, &newy);
   } else {
     lepton_point_rotate (x, y, angle % 360, &newx, &newy);
   }
-  object->arc->x = newx;
-  object->arc->y = newy;
 
-  /* apply rotation to angles */
-  object->arc->start_angle = (object->arc->start_angle + angle) % 360;
+  /* Apply rotation to angles.  Only start angle changes, sweep
+   * angle remains the same. */
+  old_start_angle = lepton_arc_object_get_start_angle (object);
+  lepton_arc_object_set_start_angle (object, (old_start_angle + angle) % 360);
 
-  /* translate object to its previous place */
-  object->arc->x += world_centerx;
-  object->arc->y += world_centery;
+  /* Translate new coords to the previous place. */
+  lepton_arc_object_set_center_x (object, newx + world_centerx);
+  lepton_arc_object_set_center_y (object, newy + world_centery);
 }
 
 /*! \brief Mirror the WORLD coordinates of an ARC.
@@ -591,23 +594,26 @@ lepton_arc_object_mirror (int world_centerx,
                           int world_centery,
                           LeptonObject *object)
 {
+  int start_angle, sweep_angle;
+
   g_return_if_fail (lepton_object_is_arc (object));
   g_return_if_fail (object->arc != NULL);
 
-  /* translate object to origin */
-  object->arc->x -= world_centerx;
+  lepton_arc_object_set_center_x (object, (2 * world_centerx -
+                                           lepton_arc_object_get_center_x (object)));
 
-  /* get center, and mirror it (vertical mirror) */
-  object->arc->x = -object->arc->x;
+  start_angle = lepton_arc_object_get_start_angle (object);
+  sweep_angle = lepton_arc_object_get_sweep_angle (object);
 
   /* apply mirror to angles (vertical mirror) */
-  object->arc->start_angle = (180 - object->arc->start_angle) % 360;
+  start_angle = (180 - start_angle) % 360;
   /* start_angle *MUST* be positive */
-  if(object->arc->start_angle < 0) object->arc->start_angle += 360;
-  object->arc->sweep_angle = -object->arc->sweep_angle;
+  if (start_angle < 0) start_angle += 360;
+  /* Reverse sweep direction. */
+  sweep_angle = -sweep_angle;
 
-  /* translate object back to its previous position */
-  object->arc->x += world_centerx;
+  lepton_arc_object_set_start_angle (object, start_angle);
+  lepton_arc_object_set_sweep_angle (object, sweep_angle);
 }
 
 
@@ -642,12 +648,12 @@ lepton_arc_object_calculate_bounds (const LeptonObject *object,
 
   halfwidth = lepton_object_get_stroke_width (object) / 2;
 
-  radius      = object->arc->radius;
-  start_angle = object->arc->start_angle;
-  sweep_angle = object->arc->sweep_angle;
+  radius      = lepton_arc_object_get_radius (object);
+  start_angle = lepton_arc_object_get_start_angle (object);
+  sweep_angle = lepton_arc_object_get_sweep_angle (object);
 
-  x1 = object->arc->x;
-  y1 = object->arc->y;
+  x1 = lepton_arc_object_get_center_x (object);
+  y1 = lepton_arc_object_get_center_y (object);
   x2 = x1 + radius * cos(start_angle * M_PI / 180);
   y2 = y1 + radius * sin(start_angle * M_PI / 180);
   x3 = x1 + radius * cos((start_angle + sweep_angle) * M_PI / 180);
@@ -710,11 +716,11 @@ lepton_arc_object_get_position (const LeptonObject *object,
   g_return_val_if_fail (object->arc != NULL, FALSE);
 
   if (x != NULL) {
-    *x = object->arc->x;
+    *x = lepton_arc_object_get_center_x (object);
   }
 
   if (y != NULL) {
-    *y = object->arc->y;
+    *y = lepton_arc_object_get_center_y (object);
   }
 
   return TRUE;
@@ -740,16 +746,25 @@ lepton_arc_object_shortest_distance (LeptonObject *object,
 {
   double shortest_distance;
   double radius;
+  double center_x, center_y;
+  double start_angle, sweep_angle;
 
+  g_return_val_if_fail (lepton_object_is_arc (object), G_MAXDOUBLE);
   g_return_val_if_fail (object->arc != NULL, G_MAXDOUBLE);
 
-  radius = (double)object->arc->radius;
+  radius = (double) lepton_arc_object_get_radius (object);
+
+  center_x = (double) lepton_arc_object_get_center_x (object);
+  center_y = (double) lepton_arc_object_get_center_y (object);
+
+  start_angle = (double) lepton_arc_object_get_start_angle (object);
+  sweep_angle = (double) lepton_arc_object_get_sweep_angle (object);
 
   if (lepton_arc_within_sweep (object->arc, x, y))
   {
     double distance_to_center;
 
-    distance_to_center = hypot (x - object->arc->x, y - object->arc->y);
+    distance_to_center = hypot (x - center_x, y - center_y);
 
     shortest_distance = fabs (distance_to_center - radius);
 
@@ -759,17 +774,17 @@ lepton_arc_object_shortest_distance (LeptonObject *object,
     double distance_to_end1;
     double dx, dy;
 
-    angle = G_PI * ((double)object->arc->start_angle) / 180;
+    angle = G_PI * start_angle / 180;
 
-    dx = ((double)x) - radius * cos (angle) - ((double)object->arc->x);
-    dy = ((double)y) - radius * sin (angle) - ((double)object->arc->y);
+    dx = ((double)x) - radius * cos (angle) - center_x;
+    dy = ((double)y) - radius * sin (angle) - center_y;
 
     distance_to_end0 = hypot (dx, dy);
 
-    angle += G_PI * ((double)object->arc->sweep_angle) / 180;
+    angle += G_PI * sweep_angle / 180;
 
-    dx = ((double)x) - radius * cos (angle) - ((double)object->arc->x);
-    dy = ((double)y) - radius * sin (angle) - ((double)object->arc->y);
+    dx = ((double)x) - radius * cos (angle) - center_x;
+    dy = ((double)y) - radius * sin (angle) - center_y;
 
     distance_to_end1 = hypot (dx, dy);
 
