@@ -2069,3 +2069,190 @@ propagate_key_file_error (GError *src, GError **dest)
   (*dest)->domain = EDA_CONFIG_ERROR;
   (*dest)->code = code;
 }
+
+
+/*! \brief Get domain of a GError error as a string.
+ *
+ * The \a error will be converted to a string according to the
+ * following rules:
+ * - If \a error is NULL, "misc-error" is returned.
+ * - If \a error is a GFileError, "system-error" is returned.
+ * - If \a error is an EdaConfigError, "config-error" is returned.
+ * - Otherwise, "misc-error" is returned.
+ *
+ * \param error The GError error.
+ * \return The error type string.
+ */
+const char*
+config_error_type (GError **error)
+{
+  if (error == NULL || *error == NULL)
+  {
+    return "misc-error";
+  }
+
+  GError *err = *error;
+
+  if (err->domain == G_IO_ERROR)
+  {
+    return "system-error";
+  }
+
+  if (err->domain == EDA_CONFIG_ERROR)
+  {
+    return "config-error";
+  }
+
+  /* All other errors. */
+  return "misc-error";
+}
+
+
+/*! \brief Return the config error code of a GError as a string.
+ *
+ * The \a code string returned depends on what error domain is
+ * set.  If the domain is not EDA_CONFIG_ERROR, the function
+ * returns "unknown".  Otherwise it returns the string value
+ * according to the error code, or "unknown" if the error code is
+ * unknown.
+ *
+ * \param error The GError value.
+ * \return The string representing error code for Scheme.
+ */
+const char*
+config_error_code (GError **error)
+{
+  if (error == NULL || *error == NULL)
+  {
+    return "unknown";
+  }
+
+  GError *err = *error;
+
+  if (err->domain == EDA_CONFIG_ERROR)
+  {
+    /* Configuration context-related errors. */
+    switch (err->code)
+    {
+    case EDA_CONFIG_ERROR_UNKNOWN_ENCODING:
+      return "unknown-encoding";
+    case EDA_CONFIG_ERROR_PARSE:
+      return "parse";
+    case EDA_CONFIG_ERROR_KEY_NOT_FOUND:
+      return "key-not-found";
+    case EDA_CONFIG_ERROR_GROUP_NOT_FOUND:
+      return "group-not-found";
+    case EDA_CONFIG_ERROR_INVALID_VALUE:
+      return "invalid-value";
+    default:
+      return "unknown";
+    }
+  }
+
+  /* All other errors. */
+  return "unknown";
+}
+
+
+/*! \brief Return error message of a GError.
+ *
+ * \param error The GError value.
+ * \return The error message.
+ */
+char*
+config_error_message (GError **error)
+{
+  if (error == NULL || *error == NULL)
+  {
+    return NULL;
+  }
+
+  GError *err = *error;
+
+  return err->message;
+}
+
+/*! \brief Test if GError error is about missing file.
+ *
+ * \param error The GError value.
+ * \return TRUE if GError matches G_IO_ERROR_NOT_FOUND, otherwise FALSE.
+ */
+gboolean
+config_error_file_not_found (GError *error)
+{
+  return g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND);
+}
+
+
+/*! \brief Add a configuration change event handler.
+ * \par Function Description
+ * Add \a proc as a function to be called when configuration is
+ * modified in the context \a cfg.  \a proc will be called with the
+ * following prototype:
+ *
+ * \code
+ * (proc CFG GROUP KEY)
+ * \endcode
+ *
+ * \param cfg The configuration context.
+ * \param proc  Procedure to add as configuration change handler.
+ * \return TRUE if the procedure has been added, FALSE if it had
+ *         been already added previously.
+ */
+gboolean
+config_add_event (EdaConfig *cfg,
+                  gpointer handler,
+                  gpointer proc)
+{
+  /* Test if proc was already connected. */
+  guint signal_id = g_signal_lookup ("config-changed", EDA_TYPE_CONFIG);
+  gulong handler_id =
+    g_signal_handler_find (cfg,
+                           (GSignalMatchType) (G_SIGNAL_MATCH_FUNC
+                                               | G_SIGNAL_MATCH_DATA
+                                               | G_SIGNAL_MATCH_ID),
+                           signal_id,
+                           0,
+                           NULL,
+                           (gpointer) handler,
+                           (gpointer) proc);
+  if (handler_id) {
+    return FALSE;
+  }
+
+  g_signal_connect (cfg,
+                    "config-changed",
+                    G_CALLBACK (handler),
+                    (gpointer) proc);
+  return TRUE;
+}
+
+/*! \brief Remove a configuration change event handler.
+ * \par Function Description
+ * Stop \a proc from being called when configuration is modified in
+ * the context \a cfg.
+ *
+ * \param cfg The configuration context.
+ * \param proc  Procedure to remove as configuration change handler.
+ * \return TRUE if \a proc has been successfully removed, otherwise FALSE.
+ */
+gboolean
+config_remove_event (EdaConfig *cfg,
+                     gpointer handler,
+                     gpointer proc)
+{
+  guint signal_id = g_signal_lookup ("config-changed", EDA_TYPE_CONFIG);
+  guint found =
+    g_signal_handlers_disconnect_matched (cfg,
+                                          (GSignalMatchType) (G_SIGNAL_MATCH_FUNC
+                                                              | G_SIGNAL_MATCH_DATA
+                                                              | G_SIGNAL_MATCH_ID),
+                                          signal_id,
+                                          0,
+                                          NULL,
+                                          (gpointer) handler,
+                                          (gpointer) proc);
+  g_warn_if_fail (found < 2);
+
+  return found;
+}
