@@ -199,9 +199,9 @@ lepton_export_set_renderer_font (EdaRenderer *renderer,
 }
 
 
-static void
-lepton_export_set_renderer_color_map (EdaRenderer *renderer,
-                                      gboolean color)
+GArray*
+lepton_export_make_color_map (gboolean color,
+                              size_t background_color)
 {
   size_t i;
   GArray *render_color_map = NULL;
@@ -212,27 +212,30 @@ lepton_export_set_renderer_color_map (EdaRenderer *renderer,
   LeptonColor* print_colors = print_colors_array();
   render_color_map =
     g_array_append_vals (render_color_map, print_colors, colors_count());
+
+  /* If no color exporting is desired, transform the color map
+   * into a black-and-white color map by making the background
+   * color white and replacing all other enabled colors with solid
+   * black. */
   if (!color) {
     /* Create a black and white color map.  All non-background colors
      * are black. */
-    LeptonColor white = {255, 255, 255, 255, TRUE};
-    LeptonColor black = {0, 0, 0, 255, TRUE};
+    LeptonColor white = {1.0, 1.0, 1.0, 1.0};
+    LeptonColor black = {0.0, 0.0, 0.0, 1.0};
     for (i = 0; i < colors_count(); i++) {
       LeptonColor *c = &g_array_index (render_color_map, LeptonColor, i);
-      if (!c->enabled) continue;
+      /* Skip disabled (fully-transparent) colors. */
+      if (!lepton_color_enabled (c)) continue;
 
-      if (c->a == 0) {
-        c->enabled = FALSE;
-        continue;
-      }
-      if (i == OUTPUT_BACKGROUND_COLOR) {
+      if (i == background_color)
+      {
         *c = white;
       } else {
         *c = black;
       }
     }
   }
-  eda_renderer_set_color_map (renderer, render_color_map);
+  return render_color_map;
 }
 
 
@@ -442,7 +445,9 @@ lepton_export_png (void)
     lepton_export_set_renderer_font (renderer, settings.font);
   }
 
-  lepton_export_set_renderer_color_map (renderer, settings.color);
+  GArray *color_map = lepton_export_make_color_map (settings.color,
+                                                    OUTPUT_BACKGROUND_COLOR);
+  eda_renderer_set_color_map (renderer, color_map);
 
   /* Create a dummy context to permit calculating extents taking text
    * into account. */
@@ -484,6 +489,7 @@ lepton_export_png (void)
   export_cairo_check_error (status);
 
   g_object_unref (G_OBJECT (renderer));
+  g_array_free (color_map, TRUE);
 }
 
 /* Worker function used by both lepton_export_ps and export_eps */
@@ -504,7 +510,9 @@ export_postscript (gboolean is_eps)
     lepton_export_set_renderer_font (renderer, settings.font);
   }
 
-  lepton_export_set_renderer_color_map (renderer, settings.color);
+  GArray *color_map = lepton_export_make_color_map (settings.color,
+                                                    OUTPUT_BACKGROUND_COLOR);
+  eda_renderer_set_color_map (renderer, color_map);
 
   /* Create a surface. To begin with, we don't know the size. */
   surface = cairo_ps_surface_create (settings.outfile, 1, 1);
@@ -549,6 +557,7 @@ export_postscript (gboolean is_eps)
   cairo_surface_finish (surface);
   export_cairo_check_error (cairo_surface_status (surface));
   g_object_unref (G_OBJECT (renderer));
+  g_array_free (color_map, TRUE);
 }
 
 void
@@ -580,7 +589,9 @@ lepton_export_pdf (void)
     lepton_export_set_renderer_font (renderer, settings.font);
   }
 
-  lepton_export_set_renderer_color_map (renderer, settings.color);
+  GArray *color_map = lepton_export_make_color_map (settings.color,
+                                                    OUTPUT_BACKGROUND_COLOR);
+  eda_renderer_set_color_map (renderer, color_map);
 
   /* Create a surface. To begin with, we don't know the size. */
   surface = cairo_pdf_surface_create (settings.outfile, 1, 1);
@@ -602,6 +613,7 @@ lepton_export_pdf (void)
   cairo_surface_finish (surface);
   export_cairo_check_error (cairo_surface_status (surface));
   g_object_unref (G_OBJECT (renderer));
+  g_array_free (color_map, TRUE);
 }
 
 void
@@ -618,7 +630,9 @@ lepton_export_svg ()
     lepton_export_set_renderer_font (renderer, settings.font);
   }
 
-  lepton_export_set_renderer_color_map (renderer, settings.color);
+  GArray *color_map = lepton_export_make_color_map (settings.color,
+                                                    OUTPUT_BACKGROUND_COLOR);
+  eda_renderer_set_color_map (renderer, color_map);
 
   /* Create a surface and run export_layout_page() to figure out
    * the picture extents and set up the cairo transformation
@@ -645,6 +659,7 @@ lepton_export_svg ()
   export_cairo_check_error (cairo_surface_status (surface));
 
   g_object_unref (G_OBJECT (renderer));
+  g_array_free (color_map, TRUE);
 }
 
 /* Parse a distance specification. A distance specification consists
