@@ -248,7 +248,7 @@ f_open_flags (LeptonToplevel *toplevel,
   }
 
   /* write full, absolute filename into page->page_filename */
-  s_page_set_filename (page, full_filename);
+  lepton_page_set_filename (page, full_filename);
 
   /* Before we open the page, let's load the corresponding gafrc. */
   /* First cd into file's directory. */
@@ -323,11 +323,11 @@ f_open_flags (LeptonToplevel *toplevel,
 
   if (!load_backup_file) {
     /* If it's not the backup file */
-    page->CHANGED=0; /* added 4/7/98 */
+    lepton_page_set_changed (page, 0);
   } else {
     /* We are loading the backup file, so lepton should ask
        the user if save it or not when closing the page. */
-    page->CHANGED=1;
+    lepton_page_set_changed (page, 1);
   }
 
   g_free(full_filename);
@@ -467,8 +467,8 @@ f_save (LeptonPage *page,
   g_free (dirname);
   g_free (only_filename);
 
-  if (o_save (s_page_objects (page), real_filename, &tmp_err)) {
-
+  if (o_save (lepton_page_objects (page), real_filename, &tmp_err))
+  {
     page->saved_since_first_loaded = 1;
 
     /* Reset the last saved timer */
