@@ -45,45 +45,4 @@ void liblepton_init(void)
   s_clib_init();
   s_attrib_init();
   s_color_init();
-
-  if (getenv ("LEPTON_INHIBIT_RC_FILES") == NULL) {
-    g_register_libgeda_dirs ();
-  }
-
-  edascm_init ();
 }
-
-
-
-/*! \brief Prepend Lepton compiled path to Guile compiled paths env var.
- *  \note  To take effect, must be called before scm_boot_guile().
- */
-void
-set_guile_compiled_path()
-{
-  const char  varname[] = "GUILE_LOAD_COMPILED_PATH";
-  const char* lepton_precompile_dir = LEPTON_SCM_PRECOMPILE_DIR;
-  const char* value = getenv (varname);
-
-  if (value == NULL || strlen (value) == 0)
-  {
-    setenv (varname, lepton_precompile_dir, 1);
-  }
-  else
-  {
-    const size_t len = strlen (lepton_precompile_dir)
-                       + 1  /* ":" */
-                       + strlen (value)
-                       + 1; /* \0  */
-    char* buffer = (char*) malloc (len);
-
-    strcpy (buffer, lepton_precompile_dir);
-    strcat (buffer, ":");
-    strcat (buffer, value);
-
-    setenv (varname, buffer, 1);
-
-    free (buffer);
-  }
-
-} /* set_guile_compiled_path() */
