@@ -57,6 +57,32 @@ static gint calculate_initial_sweep(gint pitch, gint min_y, gint max_y)
 {
   gint delta = max_y - min_y;
 
+  /* Return the vertical center of the extents if pitch is zero.
+   * This should never happen. */
+  g_return_val_if_fail (pitch != 0, delta / 2);
+
+  /*  The algorithm is as follows:
+   *
+   * Calculate the maximum distance that needs to be hatched:
+   *    md = (delta - pitch)
+   *
+   * Calculate the actual distance that needs to be hatched, the
+   * perpendicular distance between the farthest hatch
+   * lines. Dividing by the pitch and then multiplying by the
+   * pitch makes the result an even multiple of the pitch by
+   * integer truncation:
+   *    ad = md / pitch * pitch
+   *
+   * Calculate the leftover distance on each side:
+   *    l2 = delta - ad
+   *
+   * Calculates the leftover distance on one side:
+   *    l = l2 / 2
+   *
+   * Calculate the coordinate of the first pitch line:
+   *    min_y + l
+   */
+
   return min_y + ((delta - ((delta - pitch) / pitch * pitch)) / 2);
 }
 
@@ -173,6 +199,7 @@ m_hatch_circle (LeptonCircle *circle,
 
   g_return_if_fail(circle!=NULL);
   g_return_if_fail(lines!=NULL);
+  g_return_if_fail (pitch > 0);
 
   lepton_transform_init(&transform);
   lepton_transform_rotate(&transform, angle);
@@ -225,7 +252,7 @@ m_hatch_path (LeptonPath *path,
 
   points = g_array_new (FALSE, FALSE, sizeof (LeptonPoint));
 
-  s_path_to_polygon (path, points);
+  lepton_path_to_polygon (path, points);
   m_hatch_polygon (points, angle, pitch, lines);
 
   g_array_free (points, TRUE);
