@@ -60,9 +60,10 @@
 void
 o_attrib_add (LeptonObject *object, LeptonObject *item)
 {
-  /* Add link from item to attrib listing */
-  item->attached_to = object;
-  object->attribs = g_list_append (object->attribs, item);
+  GList *attribs = lepton_object_get_attribs (object);
+  GList *new_attribs = g_list_append (attribs, item);
+  lepton_object_set_attached_to (item, object);
+  lepton_object_set_attribs (object, new_attribs);
 }
 
 
@@ -81,7 +82,8 @@ o_attrib_attach (LeptonObject *attrib,
   g_return_if_fail (object != NULL);
 
   /* is the object already part of the list ? */
-  if (g_list_find (object->attribs, attrib)) {
+  if (g_list_find (lepton_object_get_attribs (object), attrib))
+  {
     g_warning (_("Attribute [%1$s] already attached\n"),
                lepton_text_object_get_string (attrib));
     return;
@@ -93,7 +95,8 @@ o_attrib_attach (LeptonObject *attrib,
     return;
   }
 
-  if (attrib->attached_to != NULL) {
+  if (lepton_object_get_attached_to (attrib) != NULL)
+  {
     g_warning (_("Attempt to attach attribute [%1$s] to more than one object\n"),
                lepton_text_object_get_string (attrib));
     return;
@@ -101,7 +104,7 @@ o_attrib_attach (LeptonObject *attrib,
 
   /* attribute inherit its selectable status from the object:
   */
-  attrib->selectable = object->selectable;
+  lepton_object_set_selectable (attrib, lepton_object_get_selectable (object));
 
   o_attrib_add (object, attrib);
 
@@ -137,17 +140,19 @@ o_attrib_detach_all (LeptonObject *object)
 {
   LeptonObject *a_current;
   GList *a_iter;
+  GList *attribs = lepton_object_get_attribs (object);
 
-  for (a_iter = object->attribs; a_iter != NULL;
+  for (a_iter = attribs;
+       a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
     a_current = (LeptonObject*) a_iter->data;
 
-    a_current->attached_to = NULL;
+    lepton_object_set_attached_to (a_current, NULL);
     lepton_object_set_color (a_current, DETACHED_ATTRIBUTE_COLOR);
   }
 
-  g_list_free (object->attribs);
-  object->attribs = NULL;
+  g_list_free (attribs);
+  lepton_object_set_attribs (object, NULL);
 }
 
 /*! \brief Print all attributes to a Postscript document.
@@ -172,26 +177,6 @@ void o_attrib_print(GList *attributes)
   }
 }
 
-/*! \todo Finish function.
- *  \brief Remove an attribute item from an attribute list.
- *  \par Function Description
- *  This function removes the given attribute from an attribute list.
- *  This function should be used when detaching an attribute.
- *
- *  \param [in] list      The attribute list to remove attribute from.
- *  \param [in] remove    The LeptonObject to remove from list.
- */
-void
-o_attrib_remove (GList **list,
-                 LeptonObject *remove)
-{
-  g_return_if_fail (remove != NULL);
-
-  remove->attached_to = NULL;
-
-  *list = g_list_remove (*list, remove);
-}
-
 /*! \brief Read attributes from a TextBuffer.
  *
  *  \param [in]  page                   The LeptonPage object.
@@ -255,7 +240,7 @@ o_read_attribs (LeptonPage *page,
         break;
 
       case(OBJ_COMPONENT):
-        if ((new_obj = o_component_read (page, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = lepton_component_read (page, line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         object_list = g_list_prepend (object_list, new_obj);
         break;
@@ -355,7 +340,8 @@ o_attrib_string_get_name_value (const gchar *string, gchar **name_ptr, gchar **v
   prev_char = g_utf8_find_prev_char (string, ptr);
   next_char = g_utf8_find_next_char (ptr, NULL);
   if (prev_char == NULL || *prev_char == ' ' ||
-      next_char == NULL || *next_char == ' ' || *next_char == '\0' ) {
+      next_char == NULL || *next_char == ' ')
+  {
     return FALSE;
   }
 
@@ -370,47 +356,6 @@ o_attrib_string_get_name_value (const gchar *string, gchar **name_ptr, gchar **v
   return TRUE;
 }
 
-
-/*! \brief Get name and value from an attribute LeptonObject
- *
- *  \par Function Description
- *  See o_attrib_string_get_name_value() for more details
- *
- *  \param [in]  attrib     The attribute LeptonObject whose name/value to return.
- *  \param [out] name_ptr   The return location for the name, or NULL.
- *  \param [out] value_ptr  The return location for the value, or NULL.
- *  \return TRUE on success, FALSE otherwise.
- */
-gboolean
-o_attrib_get_name_value (const LeptonObject *attrib,
-                         gchar **name_ptr,
-                         gchar **value_ptr)
-{
-  g_return_val_if_fail (lepton_object_is_text (attrib), FALSE);
-
-  return o_attrib_string_get_name_value (lepton_text_object_get_string (attrib),
-                                         name_ptr, value_ptr);
-}
-
-/*! \brief Get the name from an attribute
- *
- * \par Function Description
- * Get an interned string for the attribute name of the attribute text
- * object \a attrib.  If \a attrib is an invalid attribute, returns
- * NULL.
- *
- * \param attrib   An attribute #LeptonObject
- * \return The interned attribute name, or NULL.
- */
-const gchar *
-o_attrib_get_name (const LeptonObject *attrib)
-{
-  g_return_val_if_fail (attrib, 0);
-  g_return_val_if_fail (lepton_object_is_text (attrib), 0);
-
-  return attrib->text->name;
-}
-
 /*! \brief Find all floating attributes in the given object list.
  *
  *  \param [in] list  GList of LeptonObjects to search for floating attributes.
@@ -430,8 +375,9 @@ GList *o_attrib_find_floating_attribs (const GList *list)
     /* Skip non text objects, attached attributes and text which doesn't
      * constitute a valid attributes (e.g. general text placed on the page)
      */
-    if (o_attrib_is_attrib (o_current) &&
-        o_current->attached_to == NULL) {
+    if (lepton_object_is_attrib (o_current) &&
+        lepton_object_get_attached_to (o_current) == NULL)
+    {
 
       floating_attributes = g_list_prepend (floating_attributes, o_current);
     }
@@ -466,7 +412,7 @@ LeptonObject *o_attrib_find_attrib_by_name (const GList *list,
     LeptonObject *attrib = (LeptonObject*) iter->data;
     g_return_val_if_fail (lepton_object_is_text (attrib), NULL);
 
-    if ((needle == o_attrib_get_name (attrib)) &&
+    if ((needle == lepton_text_object_get_name (attrib)) &&
         (num_found++ == count)) {
       return attrib;
     }
@@ -498,7 +444,7 @@ static char *o_attrib_search_attrib_list_by_name (const GList *list,
   attrib = o_attrib_find_attrib_by_name (list, name, counter);
 
   if (attrib != NULL)
-    o_attrib_get_name_value (attrib, NULL, &value);
+    value = g_strdup (lepton_text_object_get_value (attrib));
 
   return value;
 }
@@ -553,7 +499,8 @@ char *o_attrib_search_attached_attribs_by_name (LeptonObject *object,
                                                 const char *name,
                                                 int counter)
 {
-  return o_attrib_search_attrib_list_by_name (object->attribs, name, counter);
+  GList *attribs = lepton_object_get_attribs (object);
+  return o_attrib_search_attrib_list_by_name (attribs, name, counter);
 }
 
 
@@ -578,7 +525,8 @@ char *o_attrib_search_inherited_attribs_by_name (LeptonObject *object,
 {
   g_return_val_if_fail (lepton_object_is_component (object), NULL);
 
-  return o_attrib_search_floating_attribs_by_name (object->component->prim_objs, name, counter);
+  GList *primitives = lepton_component_object_get_contents (object);
+  return o_attrib_search_floating_attribs_by_name (primitives, name, counter);
 }
 
 
@@ -631,11 +579,13 @@ GList * o_attrib_return_attribs (LeptonObject *object)
   GList *inherited_attribs;
   LeptonObject *a_current;
   GList *a_iter;
+  GList *primitives = NULL;
 
   g_return_val_if_fail (object != NULL, NULL);
 
   /* Directly attached attributes */
-  for (a_iter = object->attribs; a_iter != NULL;
+  for (a_iter = lepton_object_get_attribs (object);
+       a_iter != NULL;
        a_iter = g_list_next (a_iter)) {
     a_current = (LeptonObject*) a_iter->data;
 
@@ -643,7 +593,7 @@ GList * o_attrib_return_attribs (LeptonObject *object)
       continue;
 
     /* Don't add invalid attributes to the list */
-    if (!o_attrib_is_attrib (a_current))
+    if (!lepton_object_is_attrib (a_current))
       continue;
 
     attribs = g_list_prepend (attribs, a_current);
@@ -654,8 +604,8 @@ GList * o_attrib_return_attribs (LeptonObject *object)
   /* Inherited attributes (inside component objects) */
   if (lepton_object_is_component (object))
   {
-    inherited_attribs =
-      o_attrib_find_floating_attribs (object->component->prim_objs);
+    primitives = lepton_component_object_get_contents (object);
+    inherited_attribs = o_attrib_find_floating_attribs (primitives);
 
     attribs = g_list_concat (attribs, inherited_attribs);
   }
@@ -675,17 +625,6 @@ GList * o_attrib_return_attribs (LeptonObject *object)
  */
 int o_attrib_is_inherited (const LeptonObject *attrib)
 {
-  return (attrib->attached_to == NULL &&
-          attrib->parent != NULL);
-}
-
-/*! \brief Query whether an object is an attribute.
- *
- *  \return  TRUE if \a obj is an attribute, FALSE otherwise.
- */
-gboolean
-o_attrib_is_attrib (const LeptonObject *obj)
-{
-  return (lepton_object_is_text (obj) &&
-          o_attrib_get_name (obj));
+  return (lepton_object_get_attached_to (attrib) == NULL &&
+          lepton_object_get_parent (attrib) != NULL);
 }
