@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -359,6 +359,35 @@ lepton_object_set_selectable (LeptonObject *object,
 }
 
 
+
+/*! \brief Get the 'selected' flag of the object.
+ *
+ *  \param [in] object the object
+ *  \return TRUE if the object is selected, FALSE otherwise.
+ */
+gboolean
+lepton_object_get_selected (const LeptonObject *object)
+{
+  g_return_val_if_fail (object != NULL, FALSE);
+
+  return object->selected;
+}
+
+/*! \brief Sets the 'selected' flag of the object.
+ *
+ *  \param [in,out] object the object
+ *  \param [in] selected TRUE to select, and FALSE to unselect the object.
+ */
+void
+lepton_object_set_selected (LeptonObject *object,
+                            gboolean selected)
+{
+  g_return_if_fail (object != NULL);
+
+  object->selected = selected;
+}
+
+
 /*! \brief Get the stroke of an object.
  *
  *  \param [in] object    The object.
@@ -1979,7 +2008,7 @@ lepton_object_new (int type,
   lepton_object_set_color (new_node, default_color_id());
   new_node->dont_redraw = FALSE;
   lepton_object_set_selectable (new_node, TRUE);
-  new_node->selected = FALSE;
+  lepton_object_set_selected (new_node, FALSE);
 
   new_node->bus_ripper_direction = 0;
 
