@@ -83,6 +83,62 @@ lepton_page_set_changed (LeptonPage *page,
 }
 
 
+/*! \brief Get page's \a place_list field value.
+ *
+ *  \param [in] page The page to obtain the field of.
+ *  \return The value of the \a place_list field.
+ */
+GList*
+lepton_page_get_place_list (LeptonPage *page)
+{
+  g_return_val_if_fail (page != NULL, NULL);
+
+  return page->place_list;
+}
+
+/*! \brief Set page's \a place_list field value.
+ *
+ *  \param [in] page The page.
+ *  \param [in] place_list The new \a place_list value.
+ */
+void
+lepton_page_set_place_list (LeptonPage *page,
+                            GList *place_list)
+{
+  g_return_if_fail (page != NULL);
+
+  page->place_list = place_list;
+}
+
+
+/*! \brief Get page's \a selection_list field value.
+ *
+ *  \param [in] page The page to obtain the field of.
+ *  \return The value of the \a selection_list field.
+ */
+LeptonSelection*
+lepton_page_get_selection_list (LeptonPage *page)
+{
+  g_return_val_if_fail (page != NULL, NULL);
+
+  return page->selection_list;
+}
+
+/*! \brief Set page's \a selection_list field value.
+ *
+ *  \param [in] page The page.
+ *  \param [in] selection_list The new \a selection_list value.
+ */
+void
+lepton_page_set_selection_list (LeptonPage *page,
+                                LeptonSelection *selection_list)
+{
+  g_return_if_fail (page != NULL);
+
+  page->selection_list = selection_list;
+}
+
+
 /* Called just before removing an LeptonObject from a LeptonPage
  * or after appending an LeptonObject to a LeptonPage. */
 static void
@@ -139,8 +195,8 @@ pre_object_removed (LeptonPage *page,
  *  current page is not changed by this function.
  */
 LeptonPage*
-s_page_new (LeptonToplevel *toplevel,
-            const gchar *filename)
+lepton_page_new (LeptonToplevel *toplevel,
+                 const gchar *filename)
 {
   g_return_val_if_fail (toplevel, NULL);
   g_return_val_if_fail (filename, NULL);
@@ -152,10 +208,10 @@ s_page_new (LeptonToplevel *toplevel,
 
   page->pid = global_pid++;
 
-  page->CHANGED = 0;
+  lepton_page_set_changed (page, 0);
 
   /* big assumption here that page_filename isn't null */
-  s_page_set_filename (page, filename);
+  lepton_page_set_filename (page, filename);
 
   page->up = -2;
   page->page_control = 0;
@@ -167,9 +223,9 @@ s_page_new (LeptonToplevel *toplevel,
   page->_object_list = NULL;
 
   /* new selection mechanism */
-  page->selection_list = o_selection_new();
+  lepton_page_set_selection_list (page, o_selection_new());
 
-  page->place_list = NULL;
+  lepton_page_set_place_list (page, NULL);
 
   /* init undo struct pointers */
   s_undo_init(page);
@@ -196,15 +252,13 @@ s_page_new (LeptonToplevel *toplevel,
  *  \par Function Description
  *  Deletes a single page <B>page</B> from <B>toplevel</B>'s list of pages.
  *
- *  See #s_page_delete_list() to delete all pages of a <B>toplevel</B>
- *
  *  If the current page of toplevel is given as parameter <B>page</B>,
  *  the function sets the field <B>page_current</B> of the LeptonToplevel
  *  struct to NULL.
  */
 void
-s_page_delete (LeptonToplevel *toplevel,
-               LeptonPage *page)
+lepton_page_delete (LeptonToplevel *toplevel,
+                    LeptonPage *page)
 {
   LeptonPage *tmp;
   gchar *backup_filename;
@@ -219,20 +273,23 @@ s_page_delete (LeptonToplevel *toplevel,
    */
 
   /* save page_current and switch to page */
-  if (page == toplevel->page_current) {
+  if (page == lepton_toplevel_get_page_current (toplevel))
+  {
     tmp = NULL;
-  } else {
-    tmp = toplevel->page_current;
-    s_page_goto (toplevel, page);
+  }
+  else
+  {
+    tmp = lepton_toplevel_get_page_current (toplevel);
+    lepton_toplevel_goto_page (toplevel, page);
   }
 
   /* Get the real filename and file permissions */
-  real_filename = follow_symlinks (s_page_get_filename(page), NULL);
+  real_filename = follow_symlinks (lepton_page_get_filename(page), NULL);
 
   if (real_filename == NULL) {
-    g_message ("s_page_delete:");
+    g_message ("lepton_page_delete:");
     g_message (_("Can't get the real filename of %1$s."),
-               s_page_get_filename (page));
+               lepton_page_get_filename (page));
   }
   else {
     backup_filename = f_get_autosave_filename (real_filename);
@@ -242,7 +299,7 @@ s_page_delete (LeptonToplevel *toplevel,
          (!g_file_test(backup_filename, G_FILE_TEST_IS_DIR)) )
     {
       if (unlink(backup_filename) != 0) {
-        g_message ("s_page_delete:");
+        g_message ("lepton_page_delete:");
         g_message (_("Unable to delete backup file %1$s."),
                    backup_filename);
       }
@@ -255,7 +312,7 @@ s_page_delete (LeptonToplevel *toplevel,
   g_object_unref( page->selection_list );
 
   /* then delete objects of page */
-  s_page_delete_objects (page);
+  lepton_page_delete_objects (page);
 
   /* Free the objects in the place list. */
   lepton_object_list_delete (page->place_list);
@@ -294,60 +351,32 @@ s_page_delete (LeptonToplevel *toplevel,
 
   /* restore page_current */
   if (tmp != NULL) {
-    s_page_goto (toplevel, tmp);
+    lepton_toplevel_goto_page (toplevel, tmp);
   } else {
     /* page was page_current */
-    s_toplevel_set_page_current (toplevel, NULL);
+    lepton_toplevel_set_page_current (toplevel, NULL);
     /* page_current must be updated by calling function */
   }
 
 }
 
 
-/*! \brief Deletes the list of pages of <B>toplevel</B>.
- *  \par Function Description
- *  Deletes the list of pages of <B>toplevel</B>.
- *  This function should only be called when you are finishing up.
- *
- *  \param toplevel  The LeptonToplevel object.
- */
-void
-s_page_delete_list(LeptonToplevel *toplevel)
-{
-  GList *list_copy, *iter;
-  LeptonPage *page;
-
-  /* s_page_delete removes items from the page list, so make a copy */
-  list_copy = g_list_copy (lepton_list_get_glist (toplevel->pages));
-
-  for (iter = list_copy; iter != NULL; iter = g_list_next (iter)) {
-    page = (LeptonPage *)iter->data;
-
-    s_page_delete (toplevel, page);
-  }
-
-  g_list_free (list_copy);
-
-  /* reset toplevel fields */
-  s_toplevel_set_page_current (toplevel, NULL);
-}
-
 /*! \brief Add a weak reference watcher to an LeptonPage.
  * \par Function Description
  * Adds the weak reference callback \a notify_func to \a page.  When
  * \a page is destroyed, \a notify_func will be called with two
  * arguments: the \a page, and the \a user_data.
  *
- * \sa s_page_weak_unref
+ * \sa lepton_page_weak_unref
  *
  * \param [in,out] page       Page to weak-reference.
  * \param [in] notify_func    Weak reference notify function.
  * \param [in] user_data      Data to be passed to \a notify_func.
  */
 void
-s_page_weak_ref (LeptonPage *page,
-                 void (*notify_func)(void *, void *),
-                 void *user_data)
+lepton_page_weak_ref (LeptonPage *page,
+                      void (*notify_func)(void *, void *),
+                      void *user_data)
 {
   g_return_if_fail (page != NULL);
   page->weak_refs = s_weakref_add (page->weak_refs, notify_func, user_data);
@@ -357,16 +386,16 @@ s_page_weak_ref (LeptonPage *page,
  * \par Function Description
  * Removes the weak reference callback \a notify_func from \a page.
  *
- * \sa s_page_weak_ref()
+ * \sa lepton_page_weak_ref()
  *
  * \param [in,out] page       Page to weak-reference.
  * \param [in] notify_func    Notify function to search for.
  * \param [in] user_data      Data to to search for.
  */
 void
-s_page_weak_unref (LeptonPage *page,
-                   void (*notify_func)(void *, void *),
-                   void *user_data)
+lepton_page_weak_unref (LeptonPage *page,
+                        void (*notify_func)(void *, void *),
+                        void *user_data)
 {
   g_return_if_fail (page != NULL);
   page->weak_refs = s_weakref_remove (page->weak_refs,
@@ -379,14 +408,14 @@ s_page_weak_unref (LeptonPage *page,
  * value of \a weak_pointer_loc will be set to NULL when \a page is
  * destroyed.
  *
- * \sa s_page_remove_weak_ptr
+ * \sa lepton_page_remove_weak_ptr
  *
  * \param [in,out] page          Page to weak-reference.
  * \param [in] weak_pointer_loc  Memory address of a pointer.
  */
 void
-s_page_add_weak_ptr (LeptonPage *page,
-                     void *weak_pointer_loc)
+lepton_page_add_weak_ptr (LeptonPage *page,
+                          void *weak_pointer_loc)
 {
   g_return_if_fail (page != NULL);
   page->weak_refs = s_weakref_add_ptr (page->weak_refs,
@@ -397,282 +426,20 @@ s_page_add_weak_ptr (LeptonPage *page,
  * \par Function Description
  * Removes the weak pointer at \a weak_pointer_loc from \a page.
  *
- * \sa s_page_add_weak_ptr()
+ * \sa lepton_page_add_weak_ptr()
  *
  * \param [in,out] page          Page to weak-reference.
  * \param [in] weak_pointer_loc  Memory address of a pointer.
  */
 void
-s_page_remove_weak_ptr (LeptonPage *page,
-                        void *weak_pointer_loc)
+lepton_page_remove_weak_ptr (LeptonPage *page,
+                             void *weak_pointer_loc)
 {
   g_return_if_fail (page != NULL);
   page->weak_refs = s_weakref_remove_ptr (page->weak_refs,
                                           (void**) weak_pointer_loc);
 }
 
-/*! \brief changes the current page in toplevel
- *  \par Function Description
- *  Changes the current page in \a toplevel to the page \a p_new.
- *
- *  \param toplevel  The LeptonToplevel object
- *  \param p_new     The LeptonPage to go to
- */
-void
-s_page_goto (LeptonToplevel *toplevel,
-             LeptonPage *p_new)
-{
-  gchar *dirname;
-
-  s_toplevel_set_page_current (toplevel, p_new);
-
-  dirname = g_path_get_dirname (s_page_get_filename(p_new));
-  if (chdir (dirname)) {
-    /* An error occured with chdir */
-    /* FIXME[2017-02-21] Libraries should not be changing the
-     * current working directory.  If it is not possible to avoid a
-     * chdir() call, then the error needs to be handled and/or
-     * reported. */
-  }
-  g_free (dirname);
-
-}
-
-/*! \brief Search for pages by filename.
- *  \par Function Description
- *  Searches in \a toplevel's list of pages for a page with a filename
- *  equal to \a filename.
- *
- *  \param toplevel  The LeptonToplevel object
- *  \param filename  The filename string to search for
- *
- *  \return LeptonPage pointer to a matching page, NULL otherwise.
- */
-LeptonPage*
-s_page_search (LeptonToplevel *toplevel,
-               const gchar *filename)
-{
-  const GList *iter;
-  LeptonPage *page;
-
-  for ( iter = lepton_list_get_glist( toplevel->pages );
-        iter != NULL;
-        iter = g_list_next( iter ) ) {
-
-    page = (LeptonPage *)iter->data;
-    /* FIXME this may not be correct on platforms with
-     * case-insensitive filesystems. */
-    if ( strcmp( s_page_get_filename (page), filename ) == 0 )
-      return page;
-  }
-  return NULL;
-}
-
-/*! \brief Search for page by its filename's basename.
- *  \par Function Description
- *  Searches in \a toplevel's list of pages for a page with
- *  basename( filename ) equal to \a filename.
- *
- *  \param toplevel  The LeptonToplevel object
- *  \param filename  The filename string to search for
- *
- *  \return LeptonPage pointer to a matching page, NULL otherwise.
- */
-LeptonPage*
-s_page_search_by_basename (LeptonToplevel *toplevel,
-                           const gchar *filename)
-{
-  const GList* iter   = NULL;
-  LeptonPage*  page   = NULL;
-  LeptonPage*  result = NULL;
-
-  for ( iter = lepton_list_get_glist( toplevel->pages );
-        iter != NULL;
-        iter = g_list_next( iter ) )
-  {
-    page = (LeptonPage*) iter->data;
-
-    const gchar* fname = s_page_get_filename (page);
-    gchar* bname = g_path_get_basename (fname);
-
-    /* FIXME this may not be correct on platforms with
-     * case-insensitive filesystems. */
-
-    if ( strcmp( bname, filename ) == 0 )
-    {
-      result = page;
-      g_free (bname);
-      break;
-    }
-
-    g_free (bname);
-  }
-
-  return result;
-}
-
-/*! \brief Search for a page given its page id in a page list.
- *  \par Function Description
- *  This functions returns the page that have the page id \a pid in
- *  the list of pages starting at \a page_list, or NULL if there is no
- *  such page.
- *
- *  \param [in] list      The list of page to search the page in.
- *  \param [in] pid       The ID of the page to find.
- *  \returns A pointer on the page found or NULL if not found.
- */
-LeptonPage*
-s_page_search_by_page_id (LeptonPageList *list,
-                          int pid)
-{
-  const GList *iter;
-
-  for ( iter = lepton_list_get_glist (list);
-        iter != NULL;
-        iter = g_list_next (iter) ) {
-    LeptonPage *page = (LeptonPage *)iter->data;
-    if (page->pid == pid) {
-      return page;
-    }
-  }
-
-  return NULL;
-}
-
-/*! \brief Print full LeptonToplevel structure.
- *  \par Function Description
- *  This function prints the internal structure of <B>toplevel</B>'s
- *  list of pages.
- *
- *  \param [in] toplevel  The LeptonToplevel object to print.
- */
-void
-s_page_print_all (LeptonToplevel *toplevel)
-{
-  const GList *iter;
-  LeptonPage *page;
-
-  for ( iter = lepton_list_get_glist( toplevel->pages );
-        iter != NULL;
-        iter = g_list_next( iter ) ) {
-
-    page = (LeptonPage *) iter->data;
-    printf ("FILENAME: %1$s\n", s_page_get_filename (page));
-    lepton_object_list_print (page->_object_list);
-  }
-}
-
-
-/*! \brief Check if CHANGED flag is set for any page in list.
- *  \par Function Description
- *  This function checks the CHANGED flag for all pages in the <B>list</B>
- *  object.
- *
- *  \param [in] list  LeptonPageList to check CHANGED flag in.
- *  \return 1 if any page has the CHANGED flag set, 0 otherwise.
- */
-gboolean
-s_page_check_changed (LeptonPageList *list)
-{
-  const GList *iter;
-  LeptonPage *p_current;
-
-  for ( iter = lepton_list_get_glist( list );
-        iter != NULL;
-        iter = g_list_next( iter ) ) {
-
-    p_current = (LeptonPage *)iter->data;
-    if (p_current->CHANGED) {
-      return TRUE;
-    }
-  }
-
-  return FALSE;
-}
-
-/*! \brief Reset the CHANGED flag of all pages.
- *  \par Function Description
- *  This function resets the CHANGED flag of each page following \a head.
- *
- *  \param [in,out] list  LeptonPage list to set CHANGED flags in.
- */
-void
-s_page_clear_changed (LeptonPageList *list)
-{
-  const GList *iter;
-  LeptonPage *p_current;
-
-  for ( iter = lepton_list_get_glist( list );
-        iter != NULL;
-        iter = g_list_next( iter ) ) {
-
-    p_current = (LeptonPage *) iter->data;
-    p_current->CHANGED = 0;
-  }
-}
-
-/*! \brief Autosave initialization function.
- *  \par Function Description
- *  This function sets up the autosave callback function.
- *
- *  \param [in] toplevel  The LeptonToplevel object.
- */
-void
-s_page_autosave_init (LeptonToplevel *toplevel)
-{
-  if (toplevel->auto_save_interval != 0) {
-
-    /* 1000 converts seconds into milliseconds */
-    toplevel->auto_save_timeout =
-      g_timeout_add(toplevel->auto_save_interval*1000,
-                    (GSourceFunc) s_page_autosave,
-                    toplevel);
-  }
-}
-
-/*! \brief Autosave callback function.
- *  \par Function Description
- *  This function is a callback of the glib g_timeout functions.
- *  It is called every "interval" milliseconds and it sets a flag to save
- *  a backup copy of the opened pages.
- *
- *  \param [in] toplevel  The LeptonToplevel object.
- *  \return The length in milliseconds to set for next interval.
- */
-gint
-s_page_autosave (LeptonToplevel *toplevel)
-{
-  const GList *iter;
-  LeptonPage *p_current;
-
-  if (toplevel == NULL) {
-    return 0;
-  }
-
-  /* Do nothing if the interval is 0 */
-  if (toplevel->auto_save_interval == 0) {
-    return toplevel->auto_save_interval;
-  }
-
-  /* Should we just disable the autosave timeout returning 0 or
-     just wait for more pages to be added? */
-  if ( toplevel->pages == NULL)
-    return toplevel->auto_save_interval;
-
-  for ( iter = lepton_list_get_glist( toplevel->pages );
-        iter != NULL;
-        iter = g_list_next( iter ) ) {
-
-    p_current = (LeptonPage *) iter->data;
-
-    if (p_current->ops_since_last_backup != 0) {
-      /* Real autosave is done in o_undo_savestate */
-      p_current->do_autosave_backup = 1;
-    }
-  }
-
-  return toplevel->auto_save_interval;
-}
 
 /*! \brief Append an LeptonObject to the LeptonPage
  *
@@ -684,8 +451,8 @@ s_page_autosave (LeptonToplevel *toplevel)
  *  \param [in] object    The LeptonObject being added to the page.
  */
 void
-s_page_append (LeptonPage *page,
-               LeptonObject *object)
+lepton_page_append (LeptonPage *page,
+                    LeptonObject *object)
 {
   page->_object_list = g_list_append (page->_object_list, object);
   object_added (page, object);
@@ -701,8 +468,8 @@ s_page_append (LeptonPage *page,
  *  \param [in] obj_list  The LeptonObject list being added to the page.
  */
 void
-s_page_append_list (LeptonPage *page,
-                    GList *obj_list)
+lepton_page_append_list (LeptonPage *page,
+                         GList *obj_list)
 {
   GList *iter;
   page->_object_list = g_list_concat (page->_object_list, obj_list);
@@ -721,8 +488,8 @@ s_page_append_list (LeptonPage *page,
  *  \param [in] object    The LeptonObject being removed from the page.
  */
 void
-s_page_remove (LeptonPage *page,
-               LeptonObject *object)
+lepton_page_remove (LeptonPage *page,
+                    LeptonObject *object)
 {
   pre_object_removed (page, object);
   page->_object_list = g_list_remove (page->_object_list, object);
@@ -740,15 +507,15 @@ s_page_remove (LeptonPage *page,
  * \param [in] object2   The LeptonObject being added to the page.
  */
 void
-s_page_replace (LeptonPage *page,
-                LeptonObject *object1,
-                LeptonObject *object2)
+lepton_page_replace (LeptonPage *page,
+                     LeptonObject *object1,
+                     LeptonObject *object2)
 {
   GList *iter = g_list_find (page->_object_list, object1);
 
   /* If object1 not found, append object2 */
   if (iter == NULL) {
-    s_page_append (page, object2);
+    lepton_page_append (page, object2);
     return;
   }
 
@@ -762,7 +529,7 @@ s_page_replace (LeptonPage *page,
  *  \param [in] page      The LeptonPage being cleared.
  */
 void
-s_page_delete_objects (LeptonPage *page)
+lepton_page_delete_objects (LeptonPage *page)
 {
   GList *objects = page->_object_list;
   GList *iter;
@@ -785,7 +552,8 @@ s_page_delete_objects (LeptonPage *page)
  *  \param [in] page      The LeptonPage to get objects on.
  *  \returns a const pointer to the LeptonPage's GList of objects
  */
-const GList *s_page_objects (LeptonPage *page)
+const GList*
+lepton_page_objects (LeptonPage *page)
 {
   return page->_object_list;
 }
@@ -797,7 +565,6 @@ const GList *s_page_objects (LeptonPage *page)
  *  Finds the objects which are inside, or intersect
  *  the passed box shaped region.
  *
- *  \param [in] toplevel  The LeptonToplevel object.
  *  \param [in] page      The LeptonPage to find objects on.
  *  \param [in] rects     The LeptonBox regions to check.
  *  \param [in] n_rects   The number of regions.
@@ -805,11 +572,10 @@ const GList *s_page_objects (LeptonPage *page)
  *  \return The GList of LeptonObjects in the region.
  */
 GList*
-s_page_objects_in_regions (LeptonToplevel *toplevel,
-                           LeptonPage *page,
-                           LeptonBox *rects,
-                           int n_rects,
-                           gboolean include_hidden)
+lepton_page_objects_in_regions (LeptonPage *page,
+                                LeptonBox *rects,
+                                int n_rects,
+                                gboolean include_hidden)
 {
   GList *iter;
   GList *list = NULL;
@@ -852,7 +618,7 @@ s_page_objects_in_regions (LeptonToplevel *toplevel,
  * \return the full path to the underlying file of the \a page
  */
 const gchar *
-s_page_get_filename (const LeptonPage *page)
+lepton_page_get_filename (const LeptonPage *page)
 {
   g_return_val_if_fail (page, "");
   g_return_val_if_fail (page->_filename, "");
@@ -870,8 +636,8 @@ s_page_get_filename (const LeptonPage *page)
  * \param filename  The new file path for \a page
  */
 void
-s_page_set_filename (LeptonPage *page,
-                     const char *filename)
+lepton_page_set_filename (LeptonPage *page,
+                          const char *filename)
 {
   g_return_if_fail (page);
   g_return_if_fail (filename);
@@ -885,3 +651,17 @@ s_page_set_filename (LeptonPage *page,
   g_free (page->_filename);
   page->_filename = absolute;
 }
+
+
+/*! \brief Get GList of pages from a #LeptonPageList list.
+ *
+ *  \param [in] page_list The #LeptonPageList object.
+ *  \return The pointer to GList of pages.
+ */
+GList*
+lepton_page_list_get_glist (LeptonPageList *page_list)
+{
+  g_return_val_if_fail (page_list != NULL, NULL);
+
+  return lepton_list_get_glist (page_list);
+}
