@@ -46,8 +46,12 @@
 #define NUM_BEZIER_SEGMENTS 100
 
 
+/*! \brief Create a new LeptonPath structure.
+ *
+ *  \return The newly created LeptonPath structure.
+ */
 LeptonPath*
-s_path_new (void)
+lepton_path_new ()
 {
   LeptonPath *path;
 
@@ -60,29 +64,10 @@ s_path_new (void)
 }
 
 
-LeptonPath*
-s_path_new_from (LeptonPathSection *sections)
-{
-  LeptonPath *path;
-  int i;
-
-  g_return_val_if_fail (sections != NULL, NULL);
-
-  for (i = 0; sections[i].code != PATH_END; i++);
-  if (i <= 0)
-    return s_path_new ();
-
-  path = g_new (LeptonPath, 1);
-
-  path->num_sections = i;
-  path->num_sections_max = i;
-  path->sections = g_new (LeptonPathSection, i);
-
-  memcpy (path->sections, sections, i * sizeof (LeptonPathSection));
-  return path;
-}
-
-
+/*! \brief Free memory associated with the LeptonPath object.
+ *
+ *  \param [in] LeptonPath object to be freed.
+ */
 void
 lepton_path_free (LeptonPath * path)
 {
@@ -92,11 +77,172 @@ lepton_path_free (LeptonPath * path)
   }
 }
 
+/*! \brief Get the code type of path section.
+ *  \par Function Description
+ *  This function returns the PATH_CODE name of a
+ *  #LeptonPathSection object.
+ *
+ *  \param [in] section The #LeptonPathSection object.
+ *  \return PATH_CODE enum value of the path section object.
+ */
+PATH_CODE
+lepton_path_section_get_code (LeptonPathSection *section)
+{
+  return section->code;
+}
 
+/*! \brief Get X coordinate of the first point of path section.
+ *  \par Function Description
+ *  Given a #LeptonPathSection variable, this getter returns the X
+ *  coordinate of its first point.
+ *
+ *  \param [in] section The #LeptonPathSection variable.
+ *  \return The X coordinate value of the first point of the path
+ *  section.
+ */
+int
+lepton_path_section_get_x1 (LeptonPathSection *section)
+{
+  return section->x1;
+}
+
+/*! \brief Get Y coordinate of the first point of path section.
+ *  \par Function Description
+ *  Given a #LeptonPathSection variable, this getter returns the Y
+ *  coordinate of its first point.
+ *
+ *  \param [in] section The #LeptonPathSection variable.
+ *  \return The Y coordinate value of the first point of the path
+ *  section.
+ */
+int
+lepton_path_section_get_y1 (LeptonPathSection *section)
+{
+  return section->y1;
+}
+
+/*! \brief Get X coordinate of the second point of path section.
+ *  \par Function Description
+ *  Given a #LeptonPathSection variable, this getter returns the X
+ *  coordinate of its second point.
+ *
+ *  \param [in] section The #LeptonPathSection variable.
+ *  \return The X coordinate value of the second point of the path
+ *  section.
+ */
+int
+lepton_path_section_get_x2 (LeptonPathSection *section)
+{
+  return section->x2;
+}
+
+/*! \brief Get Y coordinate of the second point of path section.
+ *  \par Function Description
+ *  Given a #LeptonPathSection variable, this getter returns the Y
+ *  coordinate of its second point.
+ *
+ *  \param [in] section The #LeptonPathSection variable.
+ *  \return The Y coordinate value of the second point of the path
+ *  section.
+ */
+int
+lepton_path_section_get_y2 (LeptonPathSection *section)
+{
+  return section->y2;
+}
+
+/*! \brief Get X coordinate of the third point of path section.
+ *  \par Function Description
+ *  Given a #LeptonPathSection variable, this getter returns the X
+ *  coordinate of its third point.
+ *
+ *  \param [in] section The #LeptonPathSection variable.
+ *  \return The X coordinate value of the third point of the path
+ *  section.
+ */
+int
+lepton_path_section_get_x3 (LeptonPathSection *section)
+{
+  return section->x3;
+}
+
+/*! \brief Get Y coordinate of the third point of path section.
+ *  \par Function Description
+ *  Given a #LeptonPathSection variable, this getter returns the Y
+ *  coordinate of its third point.
+ *
+ *  \param [in] section The #LeptonPathSection variable.
+ *  \return The Y coordinate value of the third point of the path
+ *  section.
+ */
+int
+lepton_path_section_get_y3 (LeptonPathSection *section)
+{
+  return section->y3;
+}
+
+/*! \brief Return a path section code enum value from a string.
+ * \par Function Description
+ * Given a string \a s, returns the #PATH_CODE enum value
+ * corresponding to it.  This is mainly intended to be used for
+ * value conversion in Scheme FFI functions.
+ *
+ * \param [in] s The string.
+ */
+int
+lepton_path_section_code_from_string (char *s)
+{
+  int result = PATH_END;
+
+  if      (strcmp (s, "moveto") == 0) { result = PATH_MOVETO; }
+  else if (strcmp (s, "lineto") == 0) { result = PATH_LINETO; }
+  else if (strcmp (s, "curveto") == 0) {result = PATH_CURVETO; }
+  else if (strcmp (s, "closepath") == 0) {result = PATH_END; }
+
+  return result;
+}
+
+/*! \brief Return a string holding the representation of #PATH_CODE value.
+ * \par Function Description
+ * Given a #PATH_CODE value, returns its external representation
+ * as a string.  This is mainly intended to be used in Scheme FFI
+ * functions.
+ *
+ *  \param [in] code The #PATH_CODE value.
+ */
+const char*
+lepton_path_section_code_to_string (int code)
+{
+  const char *result = NULL;
+
+  switch (code)
+  {
+  case PATH_MOVETO:
+  case PATH_MOVETO_OPEN: result = "moveto"; break;
+  case PATH_LINETO: result = "lineto"; break;
+  case PATH_CURVETO: result = "curveto"; break;
+  case PATH_END: result = "closepath"; break;
+  default: break;
+  }
+
+  return result;
+}
+
+/*! \brief Create a new "moveto" section in #LeptonPath object.
+ *  \par Function Description
+ *  The function modifies #LeptonPath object by adding a new
+ *  "moveto" section with given coordinates x and y.  If the last
+ *  section of the path is already a "moveto" one, amend it
+ *  instead of adding a new section.
+ *
+ *  \param [in,out] path The #LeptonPath object.
+ *  \param [in] x The X coordinate of the "moveto" point.
+ *  \param [in] y The Y coordinate of the "moveto" point.
+ */
 void
-s_path_moveto (LeptonPath *path,
-               double x,
-               double y)
+lepton_path_moveto (LeptonPath *path,
+                    double x,
+                    double y)
 {
   LeptonPathSection *sections;
   int num_sections;
@@ -129,10 +275,19 @@ s_path_moveto (LeptonPath *path,
 }
 
 
+/*! \brief Create a new "lineto" section in #LeptonPath object.
+ *  \par Function Description
+ *  The function modifies #LeptonPath object by adding a new
+ *  "lineto" section with given coordinates x and y.
+ *
+ *  \param [in,out] path The #LeptonPath object.
+ *  \param [in] x The X coordinate of the "lineto" point.
+ *  \param [in] y The Y coordinate of the "lineto" point.
+ */
 void
-s_path_lineto (LeptonPath *path,
-               double x,
-               double y)
+lepton_path_lineto (LeptonPath *path,
+                    double x,
+                    double y)
 {
   LeptonPathSection *sections;
   int num_sections;
@@ -153,14 +308,28 @@ s_path_lineto (LeptonPath *path,
 }
 
 
+/*! \brief Create a new "curveto" section in #LeptonPath object.
+ *  \par Function Description
+ *  The function modifies #LeptonPath object by adding a new
+ *  "curveto" section with given coordinates of three control
+ *  points.
+ *
+ *  \param [in,out] path The #LeptonPath object.
+ *  \param [in] x1 The X coordinate of the first control point.
+ *  \param [in] y1 The Y coordinate of the first control point.
+ *  \param [in] x2 The X coordinate of the second control point.
+ *  \param [in] y2 The Y coordinate of the second control point.
+ *  \param [in] x3 The X coordinate of the third control point.
+ *  \param [in] y3 The Y coordinate of the third control point.
+ */
 void
-s_path_curveto (LeptonPath *path,
-                double x1,
-                double y1,
-                double x2,
-                double y2,
-                double x3,
-                double y3)
+lepton_path_curveto (LeptonPath *path,
+                     double x1,
+                     double y1,
+                     double x2,
+                     double y2,
+                     double x3,
+                     double y3)
 {
   LeptonPathSection *sections;
   int num_sections;
@@ -185,8 +354,15 @@ s_path_curveto (LeptonPath *path,
 }
 
 
+/*! \brief Finish #LeptonPath object creation.
+ *  \par Function Description
+ *  Finishes #LeptonPath object creation by adding a last ending
+ *  section.
+ *
+ *  \param [in,out] path The #LeptonPath object.
+ */
 void
-s_path_art_finish (LeptonPath * path)
+lepton_path_art_finish (LeptonPath * path)
 {
   int num_sections;
 
@@ -226,9 +402,15 @@ struct _RSVGParsePathCtx {
 };
 
 
-static void s_path_arc_segment (RSVGParsePathCtx * ctx,
-                                double xc, double yc, double th0, double th1,
-                                double rx, double ry, double x_axis_rotation)
+static void
+lepton_path_arc_segment (RSVGParsePathCtx * ctx,
+                         double xc,
+                         double yc,
+                         double th0,
+                         double th1,
+                         double rx,
+                         double ry,
+                         double x_axis_rotation)
 {
   double sin_th, cos_th;
   double a00, a01, a10, a11;
@@ -238,7 +420,7 @@ static void s_path_arc_segment (RSVGParsePathCtx * ctx,
 
   sin_th = sin (x_axis_rotation * (M_PI / 180.0));
   cos_th = cos (x_axis_rotation * (M_PI / 180.0));
-  /* inverse transform compared with s_path_arc */
+  /* inverse transform compared with lepton_path_arc */
   a00 = cos_th * rx;
   a01 = -sin_th * ry;
   a10 = sin_th * rx;
@@ -252,15 +434,15 @@ static void s_path_arc_segment (RSVGParsePathCtx * ctx,
   y3 = yc + sin (th1);
   x2 = x3 + t * sin (th1);
   y2 = y3 - t * cos (th1);
-  s_path_curveto (ctx->path,
-              a00 * x1 + a01 * y1, a10 * x1 + a11 * y1,
-              a00 * x2 + a01 * y2, a10 * x2 + a11 * y2,
-              a00 * x3 + a01 * y3, a10 * x3 + a11 * y3);
+  lepton_path_curveto (ctx->path,
+                       a00 * x1 + a01 * y1, a10 * x1 + a11 * y1,
+                       a00 * x2 + a01 * y2, a10 * x2 + a11 * y2,
+                       a00 * x3 + a01 * y3, a10 * x3 + a11 * y3);
 }
 
 
 /*
- * s_path_arc: Add an arc to the path context.
+ * lepton_path_arc: Add an arc to the path context.
  * @ctx: Path context.
  * @rx: Radius in x direction (before rotation).
  * @ry: Radius in y direction (before rotation).
@@ -271,9 +453,15 @@ static void s_path_arc_segment (RSVGParsePathCtx * ctx,
  * @y: New y coordinate.
  *
  */
-static void s_path_arc (RSVGParsePathCtx * ctx,
-                        double rx, double ry, double x_axis_rotation,
-                        int large_arc_flag, int sweep_flag, double x, double y)
+static void
+lepton_path_arc (RSVGParsePathCtx * ctx,
+                 double rx,
+                 double ry,
+                 double x_axis_rotation,
+                 int large_arc_flag,
+                 int sweep_flag,
+                 double x,
+                 double y)
 {
   double sin_th, cos_th;
   double a00, a01, a10, a11;
@@ -329,9 +517,12 @@ static void s_path_arc (RSVGParsePathCtx * ctx,
   n_segs = ceil (fabs (th_arc / (M_PI * 0.5 + 0.001)));
 
   for (i = 0; i < n_segs; i++)
-    s_path_arc_segment (ctx, xc, yc,
-                 th0 + i * th_arc / n_segs,
-                 th0 + (i + 1) * th_arc / n_segs, rx, ry, x_axis_rotation);
+    lepton_path_arc_segment (ctx,
+                             xc, yc,
+                             th0 + i * th_arc / n_segs,
+                             th0 + (i + 1) * th_arc / n_segs,
+                             rx, ry,
+                             x_axis_rotation);
 
   ctx->cpx = x;
   ctx->cpy = y;
@@ -340,7 +531,9 @@ static void s_path_arc (RSVGParsePathCtx * ctx,
 
 /* supply defaults for missing parameters, assuming relative coordinates
    are to be interpreted as x,y */
-static void s_path_parse_default_xy (RSVGParsePathCtx * ctx, int n_params)
+static void
+lepton_path_parse_default_xy (RSVGParsePathCtx * ctx,
+                              int n_params)
 {
   int i;
 
@@ -362,7 +555,9 @@ static void s_path_parse_default_xy (RSVGParsePathCtx * ctx, int n_params)
 }
 
 
-static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
+static void
+lepton_path_parse_do_cmd (RSVGParsePathCtx *ctx,
+                          gboolean final)
 {
   double x1, y1, x2, y2, x3, y3;
 
@@ -370,8 +565,8 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
   case 'm':
     /* moveto */
     if (ctx->param == 2 || final) {
-      s_path_parse_default_xy (ctx, 2);
-      s_path_moveto (ctx->path, ctx->params[0], ctx->params[1]);
+      lepton_path_parse_default_xy (ctx, 2);
+      lepton_path_moveto (ctx->path, ctx->params[0], ctx->params[1]);
       ctx->mpx = ctx->cpx = ctx->rpx = ctx->params[0];
       ctx->mpy = ctx->cpy = ctx->rpy = ctx->params[1];
       ctx->param = 0;
@@ -381,8 +576,8 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
   case 'l':
     /* lineto */
     if (ctx->param == 2 || final) {
-      s_path_parse_default_xy (ctx, 2);
-      s_path_lineto (ctx->path, ctx->params[0], ctx->params[1]);
+      lepton_path_parse_default_xy (ctx, 2);
+      lepton_path_lineto (ctx->path, ctx->params[0], ctx->params[1]);
       ctx->cpx = ctx->rpx = ctx->params[0];
       ctx->cpy = ctx->rpy = ctx->params[1];
       ctx->param = 0;
@@ -391,14 +586,14 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
   case 'c':
     /* curveto */
     if (ctx->param == 6 || final) {
-      s_path_parse_default_xy (ctx, 6);
+      lepton_path_parse_default_xy (ctx, 6);
       x1 = ctx->params[0];
       y1 = ctx->params[1];
       x2 = ctx->params[2];
       y2 = ctx->params[3];
       x3 = ctx->params[4];
       y3 = ctx->params[5];
-      s_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
+      lepton_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
       ctx->rpx = x2;
       ctx->rpy = y2;
       ctx->cpx = x3;
@@ -409,14 +604,14 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
   case 's':
     /* smooth curveto */
     if (ctx->param == 4 || final) {
-      s_path_parse_default_xy (ctx, 4);
+      lepton_path_parse_default_xy (ctx, 4);
       x1 = 2 * ctx->cpx - ctx->rpx;
       y1 = 2 * ctx->cpy - ctx->rpy;
       x2 = ctx->params[0];
       y2 = ctx->params[1];
       x3 = ctx->params[2];
       y3 = ctx->params[3];
-      s_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
+      lepton_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
       ctx->rpx = x2;
       ctx->rpy = y2;
       ctx->cpx = x3;
@@ -427,7 +622,7 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
   case 'h':
     /* horizontal lineto */
     if (ctx->param == 1) {
-      s_path_lineto (ctx->path, ctx->params[0], ctx->cpy);
+      lepton_path_lineto (ctx->path, ctx->params[0], ctx->cpy);
       ctx->cpx = ctx->rpx = ctx->params[0];
       ctx->param = 0;
     }
@@ -435,7 +630,7 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
   case 'v':
     /* vertical lineto */
     if (ctx->param == 1) {
-      s_path_lineto (ctx->path, ctx->cpx, ctx->params[0]);
+      lepton_path_lineto (ctx->path, ctx->cpx, ctx->params[0]);
       ctx->cpy = ctx->rpy = ctx->params[0];
       ctx->param = 0;
     }
@@ -447,7 +642,7 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
        http://www.icce.rug.nl/erikjan/bluefuzz/beziers/beziers/beziers.html
      */
     if (ctx->param == 4 || final) {
-      s_path_parse_default_xy (ctx, 4);
+      lepton_path_parse_default_xy (ctx, 4);
       /* raise quadratic bezier to cubic */
       x1 = (ctx->cpx + 2 * ctx->params[0]) * (1.0 / 3.0);
       y1 = (ctx->cpy + 2 * ctx->params[1]) * (1.0 / 3.0);
@@ -455,7 +650,7 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
       y3 = ctx->params[3];
       x2 = (x3 + 2 * ctx->params[0]) * (1.0 / 3.0);
       y2 = (y3 + 2 * ctx->params[1]) * (1.0 / 3.0);
-      s_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
+      lepton_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
       ctx->rpx = ctx->params[0];
       ctx->rpy = ctx->params[1];
       ctx->cpx = x3;
@@ -477,7 +672,7 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
       y3 = ctx->params[1];
       x2 = (x3 + 2 * xc) * (1.0 / 3.0);
       y2 = (y3 + 2 * yc) * (1.0 / 3.0);
-      s_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
+      lepton_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
       ctx->rpx = xc;
       ctx->rpy = yc;
       ctx->cpx = x3;
@@ -485,7 +680,7 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
       ctx->param = 0;
     } else if (final) {
       if (ctx->param > 2) {
-        s_path_parse_default_xy (ctx, 4);
+        lepton_path_parse_default_xy (ctx, 4);
         /* raise quadratic bezier to cubic */
         x1 = (ctx->cpx + 2 * ctx->params[0]) * (1.0 / 3.0);
         y1 = (ctx->cpy + 2 * ctx->params[1]) * (1.0 / 3.0);
@@ -493,14 +688,14 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
         y3 = ctx->params[3];
         x2 = (x3 + 2 * ctx->params[0]) * (1.0 / 3.0);
         y2 = (y3 + 2 * ctx->params[1]) * (1.0 / 3.0);
-        s_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
+        lepton_path_curveto (ctx->path, x1, y1, x2, y2, x3, y3);
         ctx->rpx = ctx->params[0];
         ctx->rpy = ctx->params[1];
         ctx->cpx = x3;
         ctx->cpy = y3;
       } else {
-        s_path_parse_default_xy (ctx, 2);
-        s_path_lineto (ctx->path, ctx->params[0], ctx->params[1]);
+        lepton_path_parse_default_xy (ctx, 2);
+        lepton_path_lineto (ctx->path, ctx->params[0], ctx->params[1]);
         ctx->cpx = ctx->rpx = ctx->params[0];
         ctx->cpy = ctx->rpy = ctx->params[1];
       }
@@ -509,9 +704,14 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
     break;
   case 'a':
     if (ctx->param == 7 || final) {
-      s_path_arc (ctx,
-               ctx->params[0], ctx->params[1], ctx->params[2],
-               ctx->params[3], ctx->params[4], ctx->params[5], ctx->params[6]);
+      lepton_path_arc (ctx,
+                       ctx->params[0],
+                       ctx->params[1],
+                       ctx->params[2],
+                       ctx->params[3],
+                       ctx->params[4],
+                       ctx->params[5],
+                       ctx->params[6]);
       ctx->param = 0;
     }
     break;
@@ -521,7 +721,9 @@ static void s_path_parse_do_cmd (RSVGParsePathCtx * ctx, gboolean final)
 }
 
 
-static void s_path_parse_data (RSVGParsePathCtx * ctx, const char *data)
+static void
+lepton_path_parse_data (RSVGParsePathCtx *ctx,
+                        const char *data)
 {
   int i = 0;
   double val = 0;
@@ -623,7 +825,7 @@ static void s_path_parse_data (RSVGParsePathCtx * ctx, const char *data)
         }
       }
       ctx->params[ctx->param++] = val;
-      s_path_parse_do_cmd (ctx, FALSE);
+      lepton_path_parse_do_cmd (ctx, FALSE);
 
       in_num = FALSE;
     }
@@ -641,21 +843,21 @@ static void s_path_parse_data (RSVGParsePathCtx * ctx, const char *data)
       exp_wait_sign = FALSE;
     } else if (c == 'z' || c == 'Z') {
       if (ctx->param)
-        s_path_parse_do_cmd (ctx, TRUE);
+        lepton_path_parse_do_cmd (ctx, TRUE);
       /* s_path_closepath (ctx->path); */
-      /* s_path_lineto (ctx->path, ctx->mpx, ctx->mpy); */
-      s_path_art_finish (ctx->path);
+      /* lepton_path_lineto (ctx->path, ctx->mpx, ctx->mpy); */
+      lepton_path_art_finish (ctx->path);
 
       ctx->cpx = ctx->rpx = ctx->path->sections[ctx->path->num_sections - 1].x3;
       ctx->cpy = ctx->rpy = ctx->path->sections[ctx->path->num_sections - 1].y3;
     } else if (c >= 'A' && c <= 'Z' && c != 'E') {
       if (ctx->param)
-        s_path_parse_do_cmd (ctx, TRUE);
+        lepton_path_parse_do_cmd (ctx, TRUE);
       ctx->cmd = c + 'a' - 'A';
       ctx->rel = FALSE;
     } else if (c >= 'a' && c <= 'z' && c != 'e') {
       if (ctx->param)
-        s_path_parse_do_cmd (ctx, TRUE);
+        lepton_path_parse_do_cmd (ctx, TRUE);
       ctx->cmd = c;
       ctx->rel = TRUE;
     }
@@ -664,12 +866,21 @@ static void s_path_parse_data (RSVGParsePathCtx * ctx, const char *data)
 }
 
 
+/*! \brief Return #LeptonPath pointer object from path string.
+ *  \par Function Description
+ *  Given a path string representation in gEDA file format creates
+ *  a #LeptonPath object corresponding to it and returns the
+ *  pointer to the object.
+ *
+ *  \param path_str [in] The representation of path as a string.
+ *  \return The #LeptonPath object pointer.
+ */
 LeptonPath*
-s_path_parse (const char *path_str)
+lepton_path_parse (const char *path_str)
 {
   RSVGParsePathCtx ctx;
 
-  ctx.path = s_path_new ();
+  ctx.path = lepton_path_new ();
   ctx.cpx = 0.0;
   ctx.cpy = 0.0;
   ctx.mpx = 0.0;
@@ -677,17 +888,25 @@ s_path_parse (const char *path_str)
   ctx.cmd = 0;
   ctx.param = 0;
 
-  s_path_parse_data (&ctx, path_str);
+  lepton_path_parse_data (&ctx, path_str);
 
   if (ctx.param)
-    s_path_parse_do_cmd (&ctx, TRUE);
+    lepton_path_parse_do_cmd (&ctx, TRUE);
 
   return ctx.path;
 }
 
 
+/*! \brief Return string representation of #LeptonPath object.
+ *  \par Function Description
+ *  Given a #LeptonPath object pointer, returns its representation
+ *  as a string in gEDA file format.
+ *
+ *  \param path [in] The #LeptonPath object pointer.
+ *  \return The string representing the object.
+ */
 char*
-s_path_string_from_path (const LeptonPath *path)
+lepton_path_string_from_path (const LeptonPath *path)
 {
   LeptonPathSection *section;
   GString *path_string;
@@ -738,8 +957,8 @@ s_path_string_from_path (const LeptonPath *path)
  *  \return TRUE if the path is closed, FALSE if it is open.
  */
 int
-s_path_to_polygon (LeptonPath *path,
-                   GArray *points)
+lepton_path_to_polygon (LeptonPath *path,
+                        GArray *points)
 {
   int closed = FALSE;
   int i;
@@ -800,10 +1019,10 @@ s_path_to_polygon (LeptonPath *path,
  *  an invalid parameter, this function returns G_MAXDOUBLE.
  */
 double
-s_path_shortest_distance (LeptonPath *path,
-                          int x,
-                          int y,
-                          int solid)
+lepton_path_shortest_distance (LeptonPath *path,
+                               int x,
+                               int y,
+                               int solid)
 {
   double shortest_distance = G_MAXDOUBLE;
   int closed;
@@ -811,7 +1030,7 @@ s_path_shortest_distance (LeptonPath *path,
 
   points = g_array_new (FALSE, FALSE, sizeof (LeptonPoint));
 
-  closed = s_path_to_polygon (path, points);
+  closed = lepton_path_to_polygon (path, points);
 
   if (!solid) {
     shortest_distance = m_polygon_shortest_distance (points, x, y, closed);
