@@ -29,6 +29,29 @@
  *  \brief functions for the path object
  */
 
+/*! \brief Return path object section with given number.
+ *  \par Function Description
+ *  Returns the #LeptonPathSection object pointer with the number
+ *  \a i for #LeptonObject.
+ *
+ *  \param [in] object The #LeptonObject.
+ *  \param [in] i The id number of wanted section.
+ *  \return The pointer to the requested #LeptonPathSection.
+ */
+LeptonPathSection*
+lepton_path_object_get_section (const LeptonObject *object,
+                                int i)
+{
+  g_return_val_if_fail (lepton_object_is_path (object), NULL);
+  g_return_val_if_fail (object->path != NULL, NULL);
+
+  g_return_val_if_fail ((i >= 0) &&
+                        (i < lepton_path_object_get_num_sections (object)),
+                        NULL);
+
+  return &object->path->sections[i];
+}
+
 
 /*! \brief Create a new path object.
  *  \par Function Description
@@ -62,7 +85,7 @@ lepton_path_object_new (int color,
                         const char *path_string)
 {
   return lepton_path_object_new_take_path (color,
-                                           s_path_parse (path_string));
+                                           lepton_path_parse (path_string));
 }
 
 
@@ -126,7 +149,7 @@ lepton_path_object_copy (LeptonObject *o_current)
   LeptonObject *new_obj;
   char *path_string;
 
-  path_string = s_path_string_from_path (o_current->path);
+  path_string = lepton_path_string_from_path (o_current->path);
   new_obj = lepton_path_object_new (lepton_object_get_color (o_current),
                                     path_string);
   g_free (path_string);
@@ -139,12 +162,12 @@ lepton_path_object_copy (LeptonObject *o_current)
                                   lepton_object_get_stroke_dash_length (o_current),
                                   lepton_object_get_stroke_space_length (o_current));
   lepton_object_set_fill_options (new_obj,
-                                  o_current->fill_type,
-                                  o_current->fill_width,
-                                  o_current->fill_pitch1,
-                                  o_current->fill_angle1,
-                                  o_current->fill_pitch2,
-                                  o_current->fill_angle2);
+                                  lepton_object_get_fill_type (o_current),
+                                  lepton_object_get_fill_width (o_current),
+                                  lepton_object_get_fill_pitch1 (o_current),
+                                  lepton_object_get_fill_angle1 (o_current),
+                                  lepton_object_get_fill_pitch2 (o_current),
+                                  lepton_object_get_fill_angle2 (o_current));
 
   /* return the new tail of the object list */
   return new_obj;
@@ -292,14 +315,14 @@ lepton_path_object_to_buffer (const LeptonObject *object)
   line_space  = lepton_object_get_stroke_space_length (object);
 
   /* filling parameters */
-  fill_type    = object->fill_type;
-  fill_width   = object->fill_width;
-  angle1       = object->fill_angle1;
-  pitch1       = object->fill_pitch1;
-  angle2       = object->fill_angle2;
-  pitch2       = object->fill_pitch2;
+  fill_type    = lepton_object_get_fill_type (object);
+  fill_width   = lepton_object_get_fill_width (object);
+  angle1       = lepton_object_get_fill_angle1 (object);
+  pitch1       = lepton_object_get_fill_pitch1 (object);
+  angle2       = lepton_object_get_fill_angle2 (object);
+  pitch2       = lepton_object_get_fill_pitch2 (object);
 
-  path_string = s_path_string_from_path (object->path);
+  path_string = lepton_path_string_from_path (object->path);
   num_lines = o_text_num_lines (path_string);
   buf = g_strdup_printf ("%c %d %d %d %d %d %d %d %d %d %d %d %d %d\n%s",
                          lepton_object_get_type (object),
@@ -340,8 +363,9 @@ lepton_path_object_modify (LeptonObject *object,
 
   lepton_object_emit_pre_change_notify (object);
 
-  for (i = 0; i <  object->path->num_sections; i++) {
-    section = &object->path->sections[i];
+  for (i = 0; i < lepton_path_object_get_num_sections (object); i++)
+  {
+    section = lepton_path_object_get_section (object, i);
 
     switch (section->code) {
     case PATH_CURVETO:
@@ -393,8 +417,9 @@ lepton_path_object_translate (LeptonObject *object,
   g_return_if_fail (lepton_object_is_path (object));
   g_return_if_fail (object->path != NULL);
 
-  for (i = 0; i < object->path->num_sections; i++) {
-    section = &object->path->sections[i];
+  for (i = 0; i < lepton_path_object_get_num_sections (object); i++)
+  {
+    section = lepton_path_object_get_section (object, i);
 
     switch (section->code) {
     case PATH_CURVETO:
@@ -440,8 +465,9 @@ lepton_path_object_rotate (int world_centerx,
   g_return_if_fail (lepton_object_is_path (object));
   g_return_if_fail (object->path != NULL);
 
-  for (i = 0; i < object->path->num_sections; i++) {
-    section = &object->path->sections[i];
+  for (i = 0; i < lepton_path_object_get_num_sections (object); i++)
+  {
+    section = lepton_path_object_get_section (object, i);
 
     switch (section->code) {
     case PATH_CURVETO:
@@ -492,8 +518,9 @@ lepton_path_object_mirror (int world_centerx,
   g_return_if_fail (lepton_object_is_path (object));
   g_return_if_fail (object->path != NULL);
 
-  for (i = 0; i < object->path->num_sections; i++) {
-    section = &object->path->sections[i];
+  for (i = 0; i < lepton_path_object_get_num_sections (object); i++)
+  {
+    section = lepton_path_object_get_section (object, i);
 
     switch (section->code) {
     case PATH_CURVETO:
@@ -534,8 +561,9 @@ lepton_path_object_calculate_bounds (const LeptonObject *object,
   g_return_if_fail (object->path != NULL);
 
   /* Find the bounds of the path region */
-  for (i = 0; i < object->path->num_sections; i++) {
-    LeptonPathSection *section = &object->path->sections[i];
+  for (i = 0; i < lepton_path_object_get_num_sections (object); i++)
+  {
+    LeptonPathSection *section = lepton_path_object_get_section (object, i);
 
     switch (section->code) {
       case PATH_CURVETO:
@@ -586,7 +614,8 @@ lepton_path_object_get_position (const LeptonObject *object,
   g_return_val_if_fail (lepton_object_is_path (object), FALSE);
   g_return_val_if_fail (object->path != NULL, FALSE);
 
-  if (object->path->num_sections == 0) {
+  if (lepton_path_object_get_num_sections (object) == 0)
+  {
     return FALSE;
   }
 
@@ -619,9 +648,132 @@ lepton_path_object_shortest_distance (LeptonObject *object,
                                       int force_solid,
                                       gboolean include_hidden)
 {
+  g_return_val_if_fail (lepton_object_is_path (object), G_MAXDOUBLE);
+  g_return_val_if_fail (object->path != NULL, G_MAXDOUBLE);
+
   int solid;
 
-  solid = force_solid || object->fill_type != FILLING_HOLLOW;
+  solid = force_solid ||
+    lepton_object_get_fill_type (object) != FILLING_HOLLOW;
 
-  return s_path_shortest_distance (object->path, x, y, solid);
+  return lepton_path_shortest_distance (object->path, x, y, solid);
+}
+
+
+/*! \brief Insert a new path section into path object.
+ *  \par Function description
+ *  Given the object #LeptonObject, section #LeptonPathSection,
+ *  and position id \a i, inserts the section into the object in
+ *  specified position.  If the position number is less than zero
+ *  or greater than the number of path object sections, appends
+ *  the section to the end of the path.
+ *
+ *  \param [in] object  The path #LeptonObject to insert section into.
+ *  \param [in] section The #LeptonPathSection to insert.
+ *  \param [in] i       The position id of the new section in the path.
+ *  \return The modified #LeptonObject.
+ */
+LeptonObject*
+lepton_path_object_insert_section (LeptonObject *object,
+                                   LeptonPathSection *section,
+                                   int i)
+{
+  LeptonPath *path = object->path;
+
+  /* Start making changes. */
+  lepton_object_emit_pre_change_notify (object);
+
+  /* Make sure there's enough space for the new element. */
+  if (path->num_sections == path->num_sections_max) {
+    path->sections =
+      (LeptonPathSection*) g_realloc (path->sections,
+                                      (path->num_sections_max <<= 1) *
+                                      sizeof (LeptonPathSection));
+  }
+
+  /* Move path contents to make a gap in the right place. */
+  if ((i < 0) || (i > path->num_sections)) {
+    i = path->num_sections;
+  } else {
+    memmove (&path->sections[i+1], &path->sections[i],
+             sizeof (LeptonPathSection) * (path->num_sections - i));
+  }
+
+  path->num_sections++;
+  path->sections[i] = *section;
+
+  lepton_object_emit_change_notify (object);
+
+  return object;
+}
+
+
+/*! \brief Remove a path section from path object.
+ *  \par Function description
+ *  Given the object #LeptonObject, and the section number \a i,
+ *  removes the section with the specified number from the path
+ *  object and returns the modified object.
+ *
+ *  \param [in] object  The path #LeptonObject to remove section from.
+ *  \param [in] i       The id number of the section to remove.
+ *  \return The modified #LeptonObject.
+ */
+LeptonObject*
+lepton_path_object_remove_section (LeptonObject *object,
+                                   int i)
+{
+  int num_sections = lepton_path_object_get_num_sections (object);
+
+  if ((i < 0) || (i >= num_sections))
+  {
+    /* Index is invalid for path.  Return the object unchanged. */
+    return object;
+  }
+
+  lepton_object_emit_pre_change_notify (object);
+
+  /* If section is not last in path, remove section at index by
+   * moving all sections above index one location down. */
+  if (i + 1 != num_sections)
+  {
+    memmove (&object->path->sections[i],
+             &object->path->sections[i+1],
+             sizeof (LeptonPathSection) * (num_sections - i - 1));
+  }
+
+  /* Decrement the number of sections. */
+  lepton_path_object_set_num_sections (object, num_sections - 1);
+
+  lepton_object_emit_change_notify (object);
+
+  return object;
+}
+
+/*! \brief Get the number of sections of path object.
+ *
+ *  \param [in] object The path #LeptonObject.
+ *  \return The number of sections.
+ */
+int
+lepton_path_object_get_num_sections (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_path (object), 0);
+  g_return_val_if_fail (object->path != NULL, 0);
+
+  return object->path->num_sections;
+}
+
+/*! \brief Set the number of sections of path object.
+ *
+ *  \param [in] object The path #LeptonObject.
+ *  \param [in] num The new number of sections.
+ */
+void
+lepton_path_object_set_num_sections (LeptonObject *object,
+                                     int num)
+{
+  g_return_if_fail (lepton_object_is_path (object));
+  g_return_if_fail (object->path != NULL);
+
+  object->path->num_sections = num;
 }
