@@ -24,6 +24,35 @@
 
 #include "liblepton_priv.h"
 
+
+/*! \brief Test if object is a bus pin object.
+ *
+ *  \param [in] object The object to test.
+ *  \return TRUE, if the object is bus pin, otherwise FALSE.
+ */
+gboolean
+lepton_pin_object_is_bus_pin (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_pin (object), FALSE);
+
+  return (object->pin_type == PIN_TYPE_BUS);
+}
+
+
+/*! \brief Test if object is a net pin object.
+ *
+ *  \param [in] object The object to test.
+ *  \return TRUE, if the object is net pin, otherwise FALSE.
+ */
+gboolean
+lepton_pin_object_is_net_pin (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_pin (object), FALSE);
+
+  return (object->pin_type == PIN_TYPE_NET);
+}
+
+
 /*! \file pin_object.c
  *  \brief functions for the pin object
  */
@@ -307,6 +336,53 @@ lepton_pin_object_new (int color,
   return new_node;
 }
 
+/*! \brief Create a new net pin object.
+ *  \par Function Description
+ *  This function creates and returns a new net pin object.
+ *
+ *  \param [in] color    The color of the pin.
+ *  \param [in] x1       X-coord of the first point.
+ *  \param [in] y1       Y-coord of the first point.
+ *  \param [in] x2       X-coord of the second point.
+ *  \param [in] y2       Y-coord of the second point.
+ *  \param [in] whichend The connectible end of the pin.
+ *  \return A new pin LeptonObject
+ */
+LeptonObject*
+lepton_pin_object_new_net_pin (int color,
+                               int x1,
+                               int y1,
+                               int x2,
+                               int y2,
+                               int whichend)
+{
+  return lepton_pin_object_new (color, x1, y1, x2, y2, PIN_TYPE_NET, whichend);
+}
+
+
+/*! \brief Create a new bus pin object.
+ *  \par Function Description
+ *  This function creates and returns a new bus pin object.
+ *
+ *  \param [in] color    The color of the pin.
+ *  \param [in] x1       X-coord of the first point.
+ *  \param [in] y1       Y-coord of the first point.
+ *  \param [in] x2       X-coord of the second point.
+ *  \param [in] y2       Y-coord of the second point.
+ *  \param [in] whichend The connectible end of the pin.
+ *  \return A new pin LeptonObject
+ */
+LeptonObject*
+lepton_pin_object_new_bus_pin (int color,
+                               int x1,
+                               int y1,
+                               int x2,
+                               int y2,
+                               int whichend)
+{
+  return lepton_pin_object_new (color, x1, y1, x2, y2, PIN_TYPE_BUS, whichend);
+}
+
 /*! \brief read a pin object from a char buffer
  *  \par Function Description
  *  This function reads a pin object from the buffer \a buf.
@@ -319,10 +395,10 @@ lepton_pin_object_new (int color,
  *  \return The object list, or NULL on error.
  */
 LeptonObject*
-o_pin_read (const char buf[],
-            unsigned int release_ver,
-            unsigned int fileformat_ver,
-            GError **err)
+lepton_pin_object_read (const char buf[],
+                        unsigned int release_ver,
+                        unsigned int fileformat_ver,
+                        GError **err)
 {
   LeptonObject *new_obj;
   char type;
