@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2014 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,9 @@
 #include <string.h>
 #endif
 
-#include "libgeda_priv.h"
+#include "liblepton_priv.h"
 
-#define MAX_ATTRIBS	128
+#define MAX_ATTRIBS 128
 
 /*! \brief */
 struct st_attrib_names {
@@ -50,16 +50,19 @@ static struct st_attrib_names attrib[MAX_ATTRIBS];
  *  \par Function Description
  *
  */
-int s_attrib_add_entry(char *new_attrib) 
+int
+s_attrib_add_entry (char *new_attrib)
 {
-  if (new_attrib == NULL) {
-    return(-1); 
+  if (new_attrib == NULL)
+  {
+    return(-1);
   }
 
-  if (attrib_index >= MAX_ATTRIBS) {
-    return(-1); 
+  if (attrib_index >= MAX_ATTRIBS)
+  {
+    return(-1);
   }
-	
+
   attrib[attrib_index].attrib_name = g_strdup (new_attrib);
 
   attrib_index++;
@@ -111,9 +114,10 @@ void s_attrib_free()
 void s_attrib_init()
 {
   int i;
-  for (i = 0; i < MAX_ATTRIBS; i++) {
-    attrib[i].attrib_name = NULL;	
-  } 
+  for (i = 0; i < MAX_ATTRIBS; i++)
+  {
+    attrib[i].attrib_name = NULL;
+  }
 }
 
 /*! \todo Finish function documentation!!!
