@@ -1,6 +1,6 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -129,6 +129,7 @@
 #include <time.h>
 
 #include "liblepton_priv.h"
+#include <liblepton/glib_compat.h>
 
 /* Constant definitions
  * ===================
@@ -1297,7 +1298,8 @@ GList *s_clib_search (const gchar *pattern, const CLibSearchMode mode)
           }
           break;
         case CLIB_GLOB:
-          if (g_pattern_match_string (globpattern, symbol->name)) {
+          if (g_pattern_spec_match_string (globpattern, symbol->name))
+          {
             result = g_list_prepend (result, symbol);
           }
           break;
