@@ -203,7 +203,10 @@ s_conn_remove_object_connections (LeptonObject *to_remove)
       break;
 
     case OBJ_COMPONENT:
-      for (iter = to_remove->component->prim_objs; iter != NULL; iter = g_list_next (iter)) {
+      for (iter = lepton_component_object_get_contents (to_remove);
+           iter != NULL;
+           iter = g_list_next (iter))
+      {
         o_current = (LeptonObject*) iter->data;
         s_conn_remove_object_connections (o_current);
       }
@@ -510,6 +513,7 @@ void
 s_conn_update_object (LeptonPage* page,
                       LeptonObject *object)
 {
+  GList *primitives = NULL;
 
   /* Add object to the list of connectible objects */
   s_conn_add_object (page, object);
@@ -522,7 +526,8 @@ s_conn_update_object (LeptonPage* page,
       break;
 
     case OBJ_COMPONENT:
-      s_conn_update_glist (page, object->component->prim_objs);
+      primitives = lepton_component_object_get_contents (object);
+      s_conn_update_glist (page, primitives);
       break;
   }
 }
@@ -637,6 +642,7 @@ GList *s_conn_return_others(GList *input_list, LeptonObject *object)
 {
   GList *c_iter;
   GList *return_list;
+  GList *primitives;
 
   return_list = input_list;
 
@@ -655,8 +661,8 @@ GList *s_conn_return_others(GList *input_list, LeptonObject *object)
       break;
 
     case OBJ_COMPONENT:
-      return_list = s_conn_return_glist_others (return_list,
-                                                object->component->prim_objs);
+      primitives = lepton_component_object_get_contents (object);
+      return_list = s_conn_return_glist_others (return_list, primitives);
       break;
   }
 
@@ -710,7 +716,7 @@ s_conn_add_object (LeptonPage *page,
       break;
 
   case OBJ_COMPONENT:
-    for (iter = object->component->prim_objs;
+    for (iter = lepton_component_object_get_contents (object);
          iter != NULL;
          iter = g_list_next (iter)) {
       s_conn_add_object (page, (LeptonObject*) iter->data);
@@ -735,7 +741,7 @@ s_conn_remove_object (LeptonPage* page,
   /* Correctly deal with compound objects */
   if (lepton_object_is_component (object))
   {
-    for (iter = object->component->prim_objs;
+    for (iter = lepton_component_object_get_contents (object);
          iter != NULL;
          iter = g_list_next (iter)) {
       s_conn_remove_object (page, (LeptonObject*) iter->data);
