@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2013 gEDA Contributors
- * Copyright (C) 2017-2020 Lepton EDA Contributors
+ * Copyright (C) 2017-2021 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include <string.h>
 #endif
 
-#include "libgeda_priv.h"
+#include "liblepton_priv.h"
 
 
 /*!
@@ -56,7 +56,7 @@ struct _TextBuffer
 
 /*! \brief Create a new managed text buffer.
  *
- *  \par Function description 
+ *  \par Function description
  *  Allocates and initialises a new TextBuffer to manage the given data
  *  buffer.
  *
@@ -250,4 +250,3 @@ s_textbuffer_linenum (TextBuffer* tb)
 
   return tb->linenum;
 }
-
