@@ -264,8 +264,9 @@ smob_free (SCM smob)
                            unpack_as_pointer (smob));
     break;
   case GEDA_SMOB_PAGE:
-    s_page_weak_unref ((LeptonPage *) data, smob_weakref_notify,
-                       unpack_as_pointer (smob));
+    lepton_page_weak_unref ((LeptonPage *) data,
+                            smob_weakref_notify,
+                            unpack_as_pointer (smob));
     break;
   case GEDA_SMOB_OBJECT:
     /* See edascm_from_object() for an explanation of why LeptonObject
@@ -274,11 +275,6 @@ smob_free (SCM smob)
                               smob_weakref2_notify,
                               unpack_as_pointer (smob));
     break;
-  case GEDA_SMOB_CONFIG:
-    g_object_unref (G_OBJECT (data));
-    break;
-  case GEDA_SMOB_CLOSURE:
-    break;
   default:
     /* This should REALLY definitely never be run */
     g_critical ("%s: received bad smob flags.", __FUNCTION__);
@@ -303,12 +299,6 @@ smob_free (SCM smob)
     case GEDA_SMOB_OBJECT:
       lepton_object_delete ((LeptonObject *) data);
       break;
-    case GEDA_SMOB_CONFIG:
-      /* These are reference counted, so the structure will have
-       * already been destroyed above if appropriate. */
-      break;
-    case GEDA_SMOB_CLOSURE:
-      break;
     default:
       /* This should REALLY definitely never be run */
       g_critical ("%s: received bad smob flags.", __FUNCTION__);
@@ -342,12 +332,6 @@ smob_print (SCM smob, SCM port, scm_print_state *pstate)
   case GEDA_SMOB_OBJECT:
     scm_puts ("object", port);
     break;
-  case GEDA_SMOB_CONFIG:
-    scm_puts ("config", port);
-    break;
-  case GEDA_SMOB_CLOSURE:
-    scm_puts ("closure", port);
-    break;
   default:
     g_critical ("%s: received bad smob flags.", __FUNCTION__);
     scm_puts ("unknown", port);
@@ -440,8 +424,9 @@ edascm_from_page (LeptonPage *page)
   SCM_SET_SMOB_FLAGS (smob, GEDA_SMOB_PAGE);
 
   /* Set weak reference */
-  s_page_weak_ref (page, smob_weakref_notify,
-                   unpack_as_pointer (smob));
+  lepton_page_weak_ref (page,
+                        smob_weakref_notify,
+                        unpack_as_pointer (smob));
 
   smob_cache_add (page, smob);
 
@@ -537,69 +522,6 @@ edascm_to_object (SCM smob)
   return (LeptonObject *) SCM_SMOB_DATA (smob);
 }
 
-/*! \brief Get a smob for a configuration context.
- * \ingroup guile_c_iface
- * \par Function Description
- * Create a new smob representing \a cfg.
- *
- * \param cfg Configuration context to create a smob for.
- * \return a smob representing \a cfg.
- */
-SCM
-edascm_from_config (EdaConfig *cfg)
-{
-  SCM smob = smob_cache_lookup (cfg);
-
-  if (EDASCM_CONFIGP (smob)) {
-    return smob;
-  }
-
-  SCM_NEWSMOB (smob, geda_smob_tag, g_object_ref (cfg));
-  SCM_SET_SMOB_FLAGS (smob, GEDA_SMOB_CONFIG);
-  return smob;
-}
-
-/*! \brief Get a configuration context from a smob.
- * \ingroup guile_c_iface
- * \par Function Description
- * Return the #EdaConfig represented by \a smob.
- *
- * \param [in] smob Guile value to retrieve #EdaConfig from.
- * \return the #EdaConfig represented by \a smob.
- */
-EdaConfig *
-edascm_to_config (SCM smob)
-{
-  g_debug ("edascm_to_config()\n");
-#ifndef NDEBUG
-  SCM_ASSERT (EDASCM_CONFIGP (smob), smob,
-              SCM_ARG1, "edascm_to_object");
-#endif
-  EDASCM_ASSERT_SMOB_VALID (smob);
-
-  return EDA_CONFIG (SCM_SMOB_DATA (smob));
-}
-
-/*! \brief Get a smob for a C closure.
- * \par Function Description
- * Create a new smob representing a C closure.
- *
- * \warning Do not call this function from user code; use
- * edascm_c_make_closure() instead.
- *
- * \param func C function to make closure around.
- * \param user_data User data for function.
- * \return a C closure smob.
- */
-SCM
-edascm_from_closure (SCM (*func)(SCM, gpointer), gpointer user_data)
-{
-  SCM smob;
-  SCM_NEWSMOB2 (smob, geda_smob_tag, func, user_data);
-  SCM_SET_SMOB_FLAGS (smob, GEDA_SMOB_CLOSURE);
-  return smob;
-}
-
 /*! \brief Set whether a Lepton EDA object may be garbage collected.
  * \ingroup guile_c_iface
  * \par Function Description
@@ -660,21 +582,6 @@ edascm_is_page (SCM smob)
   return EDASCM_PAGEP (smob);
 }
 
-/*! \brief Test whether a smob is an #EdaConfig instance.
- * \ingroup guile_c_iface
- * \par Function Description
- * If \a smob is a configuration context, returns non-zero. Otherwise,
- * returns zero.
- *
- * \param [in] smob Guile value to test.
- * \return non-zero iff \a smob is an #EdaConfig instance.
- */
-int
-edascm_is_config (SCM smob)
-{
-  return EDASCM_CONFIGP (smob);
-}
-
 /*!
  * \brief Initialise the basic Lepton EDA smob types.
  * \par Function Description
