@@ -1,6 +1,6 @@
 /* Lepton EDA library - Scheme API
  * Copyright (C) 2010-2012 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,20 +29,6 @@
 
 SCM scheme_toplevel_fluid = SCM_UNDEFINED;
 
-/*!
- * \brief Creates new toplevel.
- * \par Function Description
- * Creates and returns new toplevel variable.
- */
-SCM_DEFINE (edascm_make_toplevel, "%make-toplevel", 0, 0, 0,
-            (),
-            "Make new LeptonToplevel.")
-{
-  LeptonToplevel* toplevel = s_toplevel_new();
-  return edascm_from_toplevel (toplevel);
-}
-
-
 /*!
  * \brief Set the #LeptonToplevel fluid in the current dynamic context.
  * \ingroup guile_c_iface
@@ -67,9 +53,8 @@ edascm_dynwind_toplevel (LeptonToplevel *toplevel)
  * Return the value of the #LeptonToplevel fluid in the current dynamic
  * context.
  */
-SCM_DEFINE (edascm_current_toplevel, "%current-toplevel", 0, 0, 0,
-            (),
-            "Get the LeptonToplevel for the current dynamic context.")
+SCM
+edascm_current_toplevel ()
 {
   return scm_fluid_ref (scheme_toplevel_fluid);
 }
@@ -99,31 +84,12 @@ edascm_c_current_toplevel ()
  * \par Function Description
  * Set the #LeptonToplevel fluid to \a toplevel and call \a thunk.
  */
-SCM_DEFINE (edascm_with_toplevel, "%with-toplevel", 2, 0, 0,
-            (SCM toplevel, SCM thunk),
-            "Call `thunk', setting the LeptonToplevel fluid to `toplevel'.")
+SCM
+edascm_with_toplevel (SCM toplevel, SCM thunk)
 {
   return scm_with_fluid (scheme_toplevel_fluid, toplevel, thunk);
 }
 
-/*!
- * \brief Create the (lepton core toplevel) Scheme module
- * \par Function Description
- * Defines procedures in the (lepton core toplevel) module. The module
- * can be accessed using (use-modules (lepton core toplevel)).
- */
-static void
-init_module_lepton_core_toplevel (void *unused)
-{
-  /* Register the functions */
-  #include "scheme_toplevel.x"
-
-  /* Add them to the module's public definitions. */
-  scm_c_export (s_edascm_make_toplevel,
-                s_edascm_with_toplevel,
-                s_edascm_current_toplevel,
-                NULL);
-}
 
 /*!
  * \brief Initialise the LeptonToplevel manipulation procedures.
@@ -136,9 +102,4 @@ void
 edascm_init_toplevel ()
 {
   scheme_toplevel_fluid = scm_permanent_object (scm_make_fluid ());
-
-  /* Define the (lepton core toplevel) module */
-  scm_c_define_module ("lepton core toplevel",
-                       (void (*)(void*)) init_module_lepton_core_toplevel,
-                       NULL);
 }
