@@ -26,13 +26,12 @@
  *
  *  The text is stored and printed in several different representations.
  *
- *  In the gEDA files the text is just a string. It is stored unmodified
- *  in <b>LeptonObject->text->string</b>.
+ *  In the gEDA files the text is just a string. You can get it using
+ *  <b>lepton_text_object_get_string (object) (</b>.
  *
  *  If the string is an attribute with an equal sign as delimiter between
  *  an attribute name and an attribute value, then it is possible to
- *  hide some parts of the text. The still visible part of an attribute
- *  is stored in <b>LeptonObject->text->disp_string</b>.
+ *  hide either its name or value together with the equal sign.
  *
  *  \image html o_text_text_overview.png
  *  \image latex o_text_text_overview.pdf "text overview" width=14cm
@@ -81,7 +80,7 @@ lepton_text_free (LeptonText *text)
 {
   if (text != NULL) {
     g_free (text->string);
-    g_free (text->disp_string);
+    g_free (text->value);
     g_free (text);
   }
 }
@@ -215,6 +214,70 @@ lepton_text_object_get_size_in_points (const LeptonObject *object)
   return GEDA_FONT_FACTOR * lepton_text_object_get_size (object);
 }
 
+
+/*! \brief Get the attribute name field of object text string.
+ *
+ *  \param [in] object The #LeptonObject to get the string of.
+ *  \return The name field of the object.
+ */
+const gchar*
+lepton_text_object_get_name (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_text (object), NULL);
+  g_return_val_if_fail (object->text != NULL, NULL);
+
+  return object->text->name;
+}
+
+
+/*! \brief Set the attribute name field of text object.
+ *
+ *  \param [in] object The #LeptonObject to set the string of.
+ *  \param [in] name The new value of the name field of the object.
+ */
+void
+lepton_text_object_set_name (const LeptonObject *object,
+                             const char *name)
+{
+  g_return_if_fail (lepton_object_is_text (object));
+  g_return_if_fail (object->text != NULL);
+
+  object->text->name = g_intern_string (name);
+}
+
+
+/*! \brief Get the attribute value field of object text string.
+ *
+ *  \param [in] object The #LeptonObject to get the string of.
+ *  \return The value field of the object.
+ */
+const gchar*
+lepton_text_object_get_value (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_text (object), NULL);
+  g_return_val_if_fail (object->text != NULL, NULL);
+
+  return object->text->value;
+}
+
+
+/*! \brief Set the attribute value field of text object.
+ *
+ *  \param [in] object The #LeptonObject to set the string of.
+ *  \param [in] value The new value of the value field of the object.
+ */
+void
+lepton_text_object_set_value (LeptonObject *object,
+                              const char *value)
+{
+  g_return_if_fail (lepton_object_is_text (object));
+  g_return_if_fail (object->text != NULL);
+
+  g_free (object->text->value);
+  object->text->value = g_strdup (value);
+}
+
+
 /*! \brief Get the text string
  *
  *  \param [in] object The text object
@@ -379,63 +442,6 @@ lepton_text_object_set_show (LeptonObject *object,
   object->text->show = show;
 }
 
-/*! \brief update the visible part of a string
- *  \par Function Description
- *  If a string is an attribute, then it is possible to hide
- *  the name or the value part of the attribute string.
- *  This functions updates the text->disp_string according
- *  to the object->text->show settings
- *
- *  \param [in] object  The LeptonObject to update
- */
-static void
-update_disp_string (LeptonObject *object)
-{
-  char *name = NULL;
-  char *value = NULL;
-  LeptonText *text = object->text;
-
-  g_free (text->disp_string);
-
-  if (o_attrib_get_name_value (object, &name, &value)) {
-    switch (lepton_text_object_get_show (object))
-    {
-      case (SHOW_NAME_VALUE):
-        text->disp_string = g_strdup (text->string);
-        break;
-
-      case (SHOW_NAME):
-        if (name[0] != '\0') {
-          text->disp_string = g_strdup (name);
-        } else {
-          g_critical ("Got an improper attribute: %1$s\n",
-                      text->string);
-          text->disp_string = g_strdup ("invalid");
-        }
-        break;
-
-      case (SHOW_VALUE):
-        if (value[0] != '\0') {
-          text->disp_string = g_strdup(value);
-        } else {
-          g_critical ("Got an improper attribute: %1$s\n",
-                      text->string);
-          text->disp_string = g_strdup ("invalid");
-        }
-        break;
-    }
-
-    text->name = g_intern_string (name);
-
-    /* free the strings allocated by o_attrib_get_name_value */
-    g_free(name);
-    g_free(value);
-  } else {
-    text->disp_string = g_strdup (text->string);
-    text->name = NULL;
-  }
-}
-
 /*! \brief Creates a text LeptonObject and the graphical objects representing it
  *  \par Function Description
  *  Create an LeptonObject of type OBJ_TEXT.
@@ -473,25 +479,21 @@ lepton_text_object_new (gint color,
 
   new_node = lepton_object_new (OBJ_TEXT, "text");
 
-  text = (LeptonText *) g_malloc (sizeof (LeptonText));
+  text = (LeptonText *) g_new0 (LeptonText, 1);
 
-  text->string = g_strdup (string);
-  text->disp_string = NULL; /* We'll fix this up later */
   text->length = strlen(string);
   text->size = size;
   text->alignment = alignment;
   text->x = x;
   text->y = y;
   text->angle = angle;
-  text->name = NULL;
 
   new_node->text = text;
 
   lepton_object_set_color (new_node, color);
   lepton_text_object_set_visibility (new_node, visibility);
   lepton_text_object_set_show (new_node, show_name_value);
-
-  update_disp_string (new_node);
+  lepton_text_object_set_string (new_node, string);
 
   return new_node;
 }
@@ -701,7 +703,6 @@ lepton_text_object_recreate (LeptonObject *o_current)
   g_return_if_fail (o_current->text != NULL);
 
   lepton_object_emit_pre_change_notify (o_current);
-  update_disp_string (o_current);
   lepton_object_emit_change_notify (o_current);
 }
 
@@ -948,6 +949,9 @@ void
 lepton_text_object_set_string (LeptonObject *obj,
                                const gchar *new_string)
 {
+  char *name = NULL;
+  char *value = NULL;
+
   g_return_if_fail (lepton_object_is_text (obj));
   g_return_if_fail (obj->text != NULL);
   g_return_if_fail (new_string != NULL);
@@ -955,6 +959,21 @@ lepton_text_object_set_string (LeptonObject *obj,
   g_free (obj->text->string);
   obj->text->string = g_strdup (new_string);
 
+  if (o_attrib_string_get_name_value (new_string, &name, &value))
+  {
+    lepton_text_object_set_name (obj, name);
+    lepton_text_object_set_value (obj, value);
+    /* Free the strings allocated by
+     * o_attrib_string_get_name_value(). */
+    g_free (name);
+    g_free (value);
+  }
+  else
+  {
+    lepton_text_object_set_name (obj, NULL);
+    lepton_text_object_set_value (obj, NULL);
+  }
+
   lepton_text_object_recreate (obj);
 }
 
@@ -1005,6 +1024,39 @@ lepton_text_object_set_visibility (LeptonObject *object,
 }
 
 
+/*! \brief Get the visible part of text object string.
+ *  \par Function Description
+ *  If a string is an attribute, then it is possible to hide the
+ *  name or the value part of the attribute string.  This function
+ *  chooses the part of text to be shown depending on the value of
+ *  its 'show' setting.
+ *
+ *  \param [in] object  The #LeptonObject to get text from.
+ */
+const char*
+lepton_text_object_visible_string (const LeptonObject *object)
+{
+  g_return_val_if_fail (lepton_object_is_text (object), NULL);
+  g_return_val_if_fail (object->text != NULL, NULL);
+
+  switch (lepton_text_object_get_show (object))
+  {
+  case (SHOW_NAME_VALUE):
+    return lepton_text_object_get_string (object);
+    break;
+  case (SHOW_NAME):
+    return lepton_text_object_get_name (object);
+    break;
+  case (SHOW_VALUE):
+    return lepton_text_object_get_value (object);
+    break;
+  default:
+    g_assert_not_reached ();
+    return NULL;
+  }
+}
+
+
 const char*
 lepton_text_object_alignment_to_string (gint alignment)
 {
