@@ -105,8 +105,8 @@ char *s_attrib_get_refdes(LeptonObject *object)
                temp_uref);
     } else {        /* didn't find refdes.  Report error to log. */
       g_debug ("s_attrib_get_refdes: "
-               "Found non-graphical component with no refdes: component_basename = %s\n",
-               object->component_basename);
+               "Found non-graphical component with no refdes: component basename = %s\n",
+               lepton_component_object_get_basename (object));
       return NULL;
     }
   }
