@@ -122,9 +122,8 @@ SHEET_DATA *s_sheet_data_new()
  *
  * Add to the master list of components refdeses by running through
  * the components and recording the comp refdeses it discovers. Then
- * it sorts them into alphabetical order.  Data struct being searched
- * is: LeptonObject->attribs(->next. . .)->object->text->string
- * \param obj_list pointer to the component list to be added.
+ * it sorts them into alphabetical order.
+ * \param[in] obj_list pointer to the component list to be added.
  */
 void s_sheet_data_add_master_comp_list_items (const GList *obj_list) {
   char *temp_uref;
@@ -147,11 +146,12 @@ void s_sheet_data_add_master_comp_list_items (const GList *obj_list) {
 
       /*-----  only process if this is a component with attributes ----*/
     if (lepton_object_is_component (o_current) &&
-          o_current->attribs != NULL) {
+        lepton_object_get_attribs (o_current) != NULL)
+    {
 
         g_debug ("s_sheet_data_add_master_comp_list_items: "
-                 "Found component on page: component_basename = %s\n",
-                 o_current->component_basename);
+                 "Found component on page: component basename = %s\n",
+                 lepton_component_object_get_basename (o_current));
         verbose_print(" C");
 
         temp_uref = s_attrib_get_refdes(o_current);
@@ -206,12 +206,13 @@ void s_sheet_data_add_master_comp_attrib_list_items (const GList *obj_list) {
 
       /*-----  only process if this is a component with attributes ----*/
     if (lepton_object_is_component (o_current) &&
-          o_current->attribs != NULL) {
+        lepton_object_get_attribs (o_current) != NULL)
+    {
 
         verbose_print(" C");
 
         /*------ Iterate through all attribs found on component -----*/
-        a_iter = o_current->attribs; /* This has a side effect.  Why? */
+        a_iter = lepton_object_get_attribs (o_current); /* This has a side effect.  Why? */
         while (a_iter != NULL) {
           a_current = (LeptonObject*) a_iter->data;
           if (lepton_object_is_text (a_current)
@@ -280,10 +281,10 @@ void s_sheet_data_add_master_net_attrib_list_items (const GList *obj_start) {
  * list of pin names.  It writes the
  * label refdes:pinnumber into the global master pin list.
  * Algorithm:
- * -# Loop on o_current looking for OBJ_COMPONENT
+ * -# Loop on objects looking for components.
  * -# When we find a component, save the refdes.
- * -# Dive down to o_lower_current = o_current->component->prim_objs
- * -# Loop on o_lower_current looking for OBJ_PIN
+ * -# Dive down to primitives of the component.
+ * -# Loop on the primitives looking for pins.
  * -# When we find a pin, find the pinnumber by calling
  *    o_attrib_search_object_attribs_by_name(o_lower_current, "pinnumber", 0)
  * -# Create the pin list label as "refdes=XXX", and stick it into
@@ -318,7 +319,7 @@ void s_sheet_data_add_master_pin_list_items (const GList *obj_list) {
       if (temp_uref != NULL) {      /* make sure object component has a refdes  */
 
         /* -----  Now iterate through lower level objects looking for pins.  ----- */
-        for (o_lower_iter = o_current->component->prim_objs;
+        for (o_lower_iter = lepton_component_object_get_contents (o_current);
              o_lower_iter != NULL;
              o_lower_iter = g_list_next (o_lower_iter)) {
           LeptonObject *o_lower_current = (LeptonObject*) o_lower_iter->data;
@@ -348,8 +349,8 @@ void s_sheet_data_add_master_pin_list_items (const GList *obj_list) {
 
       } else {          /* didn't find refdes.  Report error to log. */
         g_debug ("s_sheet_data_add_master_pin_list_items: "
-                 "Found component with no refdes: component_basename = %s\n",
-                 o_current->component_basename);
+                 "Found component with no refdes: component basename = %s\n",
+                 lepton_component_object_get_basename (o_current));
       }
       g_free (temp_uref);
 
@@ -367,12 +368,12 @@ void s_sheet_data_add_master_pin_list_items (const GList *obj_list) {
  * list of pin attributes.  It writes
  * each attrib name into the master pin attrib list.
  * Algorithm:
- * -# Loop on o_current looking for OBJ_COMPONENT
+ * -# Loop on objects, looking for components.
  * -# When we find a component, save the refdes.
- * -# Dive down to o_lower_current = o_current->component->prim_objs
- * -# Loop on o_lower_current looking for OBJ_PIN
- * -# When we find a pin, get pin_attribs = o_lower_current->attribs
- * -# Loop on attribs looking for non-NULL text.
+ * -# Dive down to primitives of the component.
+ * -# Loop on the primitives looking for pins.
+ * -# When we find a pin, get its attribs.
+ * -# Loop on the attribs looking for non-NULL text.
  * -# When we find a non-NULL text attrib, extract the attrib name
  *    and stick it in the master pin attrib list.
  * \param obj_list pointer to list of pin attributes to be added.
@@ -406,7 +407,7 @@ void s_sheet_data_add_master_pin_attrib_list_items (const GList *obj_list) {
         if (temp_uref != NULL) {      /* make sure object component has a refdes  */
 
           /* -----  Now iterate through lower level objects looking for pins.  ----- */
-          for (o_lower_iter = o_current->component->prim_objs;
+          for (o_lower_iter = lepton_component_object_get_contents (o_current);
                o_lower_iter != NULL;
                o_lower_iter = g_list_next (o_lower_iter)) {
             LeptonObject *o_lower_current = (LeptonObject*) o_lower_iter->data;
@@ -416,7 +417,7 @@ void s_sheet_data_add_master_pin_attrib_list_items (const GList *obj_list) {
             if (lepton_object_is_pin (o_lower_current))
             {
               /* -----  Found a pin.  Now get attrib head and loop on attribs.  ----- */
-              a_iter = o_lower_current->attribs;
+              a_iter = lepton_object_get_attribs (o_lower_current);
               while (a_iter != NULL) {
                 pin_attrib = (LeptonObject*) a_iter->data;
                 if (lepton_object_is_text (pin_attrib)
