@@ -390,7 +390,8 @@ void s_table_add_toplevel_comp_items_to_comp_table (const GList *obj_list) {
 
     /* -----  Now process objects found on page  ----- */
     if (lepton_object_is_component (o_current) &&
-        o_current->attribs != NULL) {
+        lepton_object_get_attribs (o_current) != NULL)
+    {
 
       /* ---- Don't process part if it lacks a refdes ----- */
       temp_uref = g_strdup(s_attrib_get_refdes(o_current));
@@ -404,7 +405,7 @@ void s_table_add_toplevel_comp_items_to_comp_table (const GList *obj_list) {
         /* Having found a component, we loop over all attribs in this
          * component, and stick them
          * into cells in the table. */
-        a_iter = o_current->attribs;
+        a_iter = lepton_object_get_attribs (o_current);
         while (a_iter != NULL) {
           a_current = (LeptonObject*) a_iter->data;
           if (lepton_object_is_text (a_current)
@@ -499,7 +500,7 @@ void s_table_add_toplevel_net_items_to_net_table(LeptonObject *start_obj) {
       verbose_print(" N");
 
       /* Having found a net, we stick it into the table. */
-      a_current = o_current->attribs;
+      a_current = lepton_object_get_attribs (o_current);
       while (a_current != NULL) {
         if (lepton_object_is_text (a_current->object)
             && a_current->object->text != NULL) {  /* found an attribute */
@@ -584,14 +585,14 @@ void s_table_add_toplevel_pin_items_to_pin_table (const GList *obj_list) {
 
     /* -----  Now process objects found on page  ----- */
     if (lepton_object_is_component (o_current) &&
-        o_current->attribs != NULL) {
-
+        lepton_object_get_attribs (o_current) != NULL)
+    {
       /* ---- Don't process part if it lacks a refdes ----- */
       temp_uref = s_attrib_get_refdes(o_current);
       if (temp_uref) {
 
         /* -----  Now iterate through lower level objects looking for pins.  ----- */
-        for (o_lower_iter = o_current->component->prim_objs;
+        for (o_lower_iter = lepton_component_object_get_contents (o_current);
              o_lower_iter != NULL;
              o_lower_iter = g_list_next (o_lower_iter)) {
           LeptonObject *o_lower_current = (LeptonObject*) o_lower_iter->data;
@@ -606,7 +607,7 @@ void s_table_add_toplevel_pin_items_to_pin_table (const GList *obj_list) {
                      "Examining pin %s\n",
                      row_label);
 
-            a_iter = o_lower_current->attribs;
+            a_iter = lepton_object_get_attribs (o_lower_current);
             while (a_iter != NULL) {
               pin_attrib = (LeptonObject*) a_iter->data;
               if (lepton_object_is_text (pin_attrib)
