@@ -2,7 +2,7 @@
  * Copyright (C) 2003-2010 Stuart D. Brorson.
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
  * Copyright (C) 2003-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,8 +62,10 @@
 static void
 x_window_init ();
 
+#ifndef ENABLE_GTK3
 static void
 x_window_create_menu(GtkWindow *window, GtkWidget **menubar);
+#endif
 
 static void
 x_window_set_default_icon( void );
@@ -113,9 +115,6 @@ x_window_init ()
   /* Set default icon */
   x_window_set_default_icon();
 
-  /*  window is a global declared in globals.h.  */
-  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-
   g_signal_connect(window, "delete_event",
                    G_CALLBACK (attrib_really_quit), 0);
 
@@ -130,7 +129,11 @@ x_window_init ()
   gtk_container_add(GTK_CONTAINER(window), GTK_WIDGET(main_vbox) );
 
   /* -----  Now create menu bar  ----- */
+#ifdef ENABLE_GTK3
+  menu_bar = gtk_menu_bar_new ();
+#else /* GTK2 */
   x_window_create_menu(GTK_WINDOW(window), &menu_bar);
+#endif
   gtk_box_pack_start(GTK_BOX (main_vbox), menu_bar, FALSE, TRUE, 0);
 
   /* -----  Now init notebook widget  ----- */
@@ -149,10 +152,35 @@ x_window_init ()
   GtkWidget* label_1 = gtk_label_new (NULL);
   gtk_label_set_markup (GTK_LABEL (label_1), _("   Color Legend:  "));
 
-  GtkWidget* label_inv      = gtk_label_new (_(" Invisible ") );
-  GtkWidget* label_val      = gtk_label_new (_(" Show value "));
-  GtkWidget* label_name     = gtk_label_new (_(" Show name "));
-  GtkWidget* label_name_val = gtk_label_new (_(" Show name and value "));
+  char *markup;
+
+  GtkWidget* label_inv = gtk_label_new (NULL);
+  const char *format_inv = "<span foreground=\"grey\">\%s</span>";
+  const char *str_inv = _(" Invisible ");
+  markup = g_markup_printf_escaped (format_inv, str_inv);
+  gtk_label_set_markup (GTK_LABEL (label_inv), markup);
+  g_free (markup);
+
+  GtkWidget* label_val = gtk_label_new (NULL);
+  const char *format_val = "<span foreground=\"black\">\%s</span>";
+  const char *str_val = _(" Show value ");
+  markup = g_markup_printf_escaped (format_val, str_val);
+  gtk_label_set_markup (GTK_LABEL (label_val), markup);
+  g_free (markup);
+
+  GtkWidget* label_name = gtk_label_new (NULL);
+  const char *format_name = "<span foreground=\"red\">\%s</span>";
+  const char *str_name = _(" Show name ");
+  markup = g_markup_printf_escaped (format_name, str_name);
+  gtk_label_set_markup (GTK_LABEL (label_name), markup);
+  g_free (markup);
+
+  GtkWidget* label_name_val = gtk_label_new (NULL);
+  const char *format_name_val = "<span foreground=\"blue\">\%s</span>";
+  const char *str_name_val = _(" Show name and value ");
+  markup = g_markup_printf_escaped (format_name_val, str_name_val);
+  gtk_label_set_markup (GTK_LABEL (label_name_val), markup);
+  g_free (markup);
 
   gtk_box_pack_start (GTK_BOX (marea), label_1, FALSE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (marea), separator_new() , FALSE, TRUE, 0);
@@ -168,35 +196,6 @@ x_window_init ()
 
   gtk_box_pack_start (GTK_BOX (marea), label_name_val, FALSE, TRUE, 0);
 
-#ifdef ENABLE_GTK3
-  GdkRGBA color;
-  gdk_rgba_parse (&color, "grey");
-  gtk_widget_override_color (label_inv, GTK_STATE_FLAG_NORMAL, &color);
-
-  gdk_rgba_parse (&color, "black");
-  gtk_widget_override_color (label_val, GTK_STATE_FLAG_NORMAL, &color);
-
-  gdk_rgba_parse (&color, "red");
-  gtk_widget_override_color (label_name, GTK_STATE_FLAG_NORMAL, &color);
-
-  gdk_rgba_parse (&color, "blue");
-  gtk_widget_override_color (label_name_val, GTK_STATE_FLAG_NORMAL, &color);
-#else
-  GdkColor color;
-  gdk_color_parse ("grey", &color);
-  gtk_widget_modify_fg (label_inv, GTK_STATE_NORMAL, &color);
-
-  gdk_color_parse ("black", &color);
-  gtk_widget_modify_fg (label_val, GTK_STATE_NORMAL, &color);
-
-  gdk_color_parse ("red", &color);
-  gtk_widget_modify_fg (label_name, GTK_STATE_NORMAL, &color);
-
-  gdk_color_parse ("blue", &color);
-  gtk_widget_modify_fg (label_name_val, GTK_STATE_NORMAL, &color);
-#endif
-
-
   /* -----  Now malloc -- but don't fill out -- space for sheets  ----- */
   /* This basically sets up the overhead for the sheets, as I understand
    * it.  The memory for the actual sheet cells is allocated later,
@@ -230,7 +229,13 @@ x_window_init ()
  * Implement the File->Export CSV menu item
  */
 static void
+#ifdef ENABLE_GTK3
+menu_file_export_csv (GSimpleAction *action,
+                      GVariant *parameter,
+                      gpointer user_data)
+#else
 menu_file_export_csv()
+#endif
 {
   gint cur_page;
 
@@ -252,7 +257,13 @@ menu_file_export_csv()
  * Implement the New attrib menu item
  */
 static void
+#ifdef ENABLE_GTK3
+menu_edit_newattrib (GSimpleAction *action,
+                     GVariant *parameter,
+                     gpointer user_data)
+#else
 menu_edit_newattrib()
+#endif
 {
   gint cur_page;
 
@@ -271,15 +282,96 @@ menu_edit_newattrib()
  * Implements the Delete Attribute menu item
  */
 static void
+#ifdef ENABLE_GTK3
+menu_edit_delattrib (GSimpleAction *action,
+                     GVariant *parameter,
+                     gpointer user_data)
+#else
 menu_edit_delattrib()
+#endif
 {
   x_dialog_delattrib();
 }
 
 
 /*!
- * The main menu description
+ * GTK3 main menu structure.
  */
+#ifdef ENABLE_GTK3
+static const gchar menu[] =
+  "<interface>"
+  "  <menu id='appmenu'>"
+  "    <section>"
+  "      <item>"
+  "        <attribute name='label' translatable='yes'>_About</attribute>"
+  "        <attribute name='action'>app.help-about</attribute>"
+  "        <attribute name='accel'>&lt;Primary&gt;a</attribute>"
+  "      </item>"
+  "    </section>"
+  "    <section>"
+  "      <item>"
+  "        <attribute name='label' translatable='yes'>_Quit</attribute>"
+  "        <attribute name='action'>app.file-quit</attribute>"
+  "        <attribute name='accel'>&lt;Primary&gt;q</attribute>"
+  "      </item>"
+  "    </section>"
+  "  </menu>"
+  "  <menu id='menubar'>"
+  "    <submenu>"
+  "      <attribute name='label' translatable='yes'>_File</attribute>"
+  "      <section>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>_Save</attribute>"
+  "          <attribute name='action'>app.file-save</attribute>"
+  "          <attribute name='accel'>&lt;Primary&gt;s</attribute>"
+  "          <attribute name='icon'>document-save</attribute>"
+  "        </item>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>_Export CSV</attribute>"
+  "          <attribute name='action'>app.file-export-csv</attribute>"
+  "          <attribute name='accel'>&lt;Primary&gt;e</attribute>"
+  "        </item>"
+  "      </section>"
+  "    </submenu>"
+  "    <submenu>"
+  "      <attribute name='label' translatable='yes'>_Edit</attribute>"
+  "      <section>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>Add attrib column</attribute>"
+  "          <attribute name='action'>app.edit-add-attrib</attribute>"
+  "        </item>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>Delete attrib column</attribute>"
+  "          <attribute name='action'>app.edit-delete-attrib</attribute>"
+  "        </item>"
+  "      </section>"
+  "    </submenu>"
+  "    <submenu>"
+  "      <attribute name='label' translatable='yes'>_Visibility</attribute>"
+  "      <section>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>Invisible</attribute>"
+  "          <attribute name='action'>app.visibility-invisible</attribute>"
+  "        </item>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>Name only</attribute>"
+  "          <attribute name='action'>app.visibility-name-only</attribute>"
+  "        </item>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>Value only</attribute>"
+  "          <attribute name='action'>app.visibility-value-only</attribute>"
+  "        </item>"
+  "        <item>"
+  "          <attribute name='label' translatable='yes'>Name and value</attribute>"
+  "          <attribute name='action'>app.visibility-name-value</attribute>"
+  "        </item>"
+  "      </section>"
+  "    </submenu>"
+  "  </menu>"
+  "</interface>";
+
+#else /* GTK2 */
+
 static const gchar menu[] =
   "<menubar>"
     "<menu action='file'>"
@@ -311,25 +403,44 @@ static const gchar menu[] =
       "<menuitem action='help-about' />"
     "</menu>"
   "</menubar>";
+#endif
 
 
 /*!
  * The Gtk action table
  */
+#ifdef ENABLE_GTK3
+
+static GActionEntry app_entries[] = {
+  { "file-save", s_toplevel_save_sheet, NULL, NULL, NULL },
+  { "file-export-csv", menu_file_export_csv, NULL, NULL, NULL },
+  { "file-quit", attrib_really_quit, NULL, NULL, NULL },
+  { "edit-add-attrib", menu_edit_newattrib, NULL, NULL, NULL },
+  { "edit-delete-attrib", menu_edit_delattrib, NULL, NULL, NULL },
+  { "visibility-invisible", s_visibility_set_invisible, NULL, NULL, NULL },
+  { "visibility-name-only", s_visibility_set_name_only, NULL, NULL, NULL },
+  { "visibility-value-only", s_visibility_set_value_only, NULL, NULL, NULL },
+  { "visibility-name-value", s_visibility_set_name_and_value, NULL, NULL, NULL },
+  { "help-about", x_dialog_about_dialog, NULL, NULL, NULL },
+};
+
+
+#else /* GTK2 */
+
 static const GtkActionEntry actions[] = {
   /* name, stock-id, label, accelerator, tooltip, callback function */
   /* File menu */
   { "file", NULL, "_File"},
-  { "file-save", GTK_STOCK_SAVE, "Save", "<Control>S", "", s_toplevel_save_sheet},
+  { "file-save", "document-save", "Save", "<Control>S", "", s_toplevel_save_sheet},
   { "file-export-csv", NULL, "Export CSV", "", "", menu_file_export_csv},
-  /* { "file-print", GTK_STOCK_PRINT, "Print", "<Control>P", "", x_dialog_unimplemented_feature}, */
-  { "file-quit", GTK_STOCK_QUIT, "Quit", "<Control>Q", "", G_CALLBACK(attrib_really_quit)},
+  /* { "file-print", "document-print", "Print", "<Control>P", "", x_dialog_unimplemented_feature}, */
+  { "file-quit", "application-exit", "Quit", "<Control>Q", "", G_CALLBACK(attrib_really_quit)},
 
   /* Edit menu */
   { "edit", NULL, "_Edit"},
   { "edit-add-attrib", NULL, "Add new attrib column", "", "", menu_edit_newattrib},
   { "edit-delete-attrib", NULL, "Delete attrib column", "", "", menu_edit_delattrib},
-  /* { "edit-find-attrib", GTK_STOCK_FIND, "Find attrib value", "<Control>F", "", x_dialog_unimplemented_feature}, */
+  /* { "edit-find-attrib", "edit-find", "Find attrib value", "<Control>F", "", x_dialog_unimplemented_feature}, */
   /* { "edit-search-replace-attrib-value", NULL, "Search and replace attrib value", "", "", x_dialog_unimplemented_feature}, */
   /* { "edit-search-for-refdes", NULL, "Search for refdes", "", "", x_dialog_unimplemented_feature}, */
 
@@ -342,10 +453,12 @@ static const GtkActionEntry actions[] = {
 
   /* Help menu */
   { "help", NULL, "_Help"},
-  { "help-about", GTK_STOCK_ABOUT, "About", "", "", x_dialog_about_dialog},
+  { "help-about", "help-about", "About", "", "", x_dialog_about_dialog},
 };
+#endif
 
 
+#ifndef ENABLE_GTK3
 /*! \brief Create and attach the menu bar
  *
  * Create the menu bar and attach it to the main window.
@@ -387,6 +500,7 @@ x_window_create_menu(GtkWindow *window, GtkWidget **menubar)
 
   *menubar = gtk_ui_manager_get_widget(ui, "/ui/menubar/");
 }
+#endif
 
 
 /*! \brief Add all items to the top level window
@@ -600,17 +714,47 @@ x_window_set_title_changed (int changed)
 }
 
 
-/*! \brief Open lepton-attrib window.
- *
- * The function populates the spreadsheet data structure and
- * updates GUI.
- */
-void
-lepton_attrib_window ()
+#ifdef ENABLE_GTK3
+static void
+startup (GApplication *app)
+{
+  GtkBuilder *builder;
+  GMenuModel *appmenu;
+  GMenuModel *menubar;
+
+  builder = gtk_builder_new ();
+  gtk_builder_add_from_string (builder, menu, -1, NULL);
+
+  appmenu = (GMenuModel *) gtk_builder_get_object (builder, "appmenu");
+  menubar = (GMenuModel *) gtk_builder_get_object (builder, "menubar");
+
+  gtk_application_set_app_menu (GTK_APPLICATION (app), appmenu);
+  gtk_application_set_menubar (GTK_APPLICATION (app), menubar);
+
+  g_object_unref (builder);
+}
+#endif
+
+
+static void
+#ifdef ENABLE_GTK3
+activate (GtkApplication* app,
+          gpointer user_data)
+#else
+activate ()
+#endif
 {
   GList *iter;
   LeptonPage *p_local;
 
+
+  /*  window is a global declared in globals.h.  */
+#ifdef ENABLE_GTK3
+  window = gtk_application_window_new (app);
+#else
+  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+#endif
+
   LeptonToplevel *toplevel = edascm_c_current_toplevel ();
   x_window_set_toplevel (toplevel);
 
@@ -696,4 +840,40 @@ lepton_attrib_window ()
   s_toplevel_verify_design(toplevel);  /* toplevel is a global */
 
   x_window_set_title (lepton_list_get_glist (toplevel->pages));
+
+  gtk_widget_show_all (window);
+}
+
+
+/*! \brief Open lepton-attrib window.
+ *
+ * The function populates the spreadsheet data structure and
+ * updates GUI.
+ */
+int
+lepton_attrib_window ()
+{
+#ifdef ENABLE_GTK3
+  GtkApplication *app;
+  int status;
+
+  app = gtk_application_new ("com.github.lepton_eda.lepton_attrib",
+                             G_APPLICATION_FLAGS_NONE);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (app),
+                                   app_entries, G_N_ELEMENTS (app_entries),
+                                   app);
+
+  g_signal_connect (app, "startup", G_CALLBACK (startup), NULL);
+  g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
+
+  status = g_application_run (G_APPLICATION (app), 0, NULL);
+  g_object_unref (app);
+  return status;
+#else
+  activate ();
+  /* Run main GTK loop. */
+  gtk_main ();
+  return 0;
+#endif
 }
