@@ -12,12 +12,13 @@ void a_zoom_box_invalidate_rubber(GschemToplevel *w_current);
 void a_zoom_box_draw_rubber(GschemToplevel *w_current, EdaRenderer *renderer);
 /* g_action.c */
 gboolean g_action_eval_by_name (GschemToplevel *w_current, const gchar *action_name);
-gboolean g_action_get_position (gboolean snap, int *x, int *y);
-void g_init_action (void);
-/* g_attrib.c */
-void g_init_attrib ();
+gboolean
+g_action_get_position (GschemToplevel *w_current,
+                       gboolean snap,
+                       int *x,
+                       int *y);
+
 /* g_hook.c */
-void g_init_hook ();
 void g_run_hook_object (GschemToplevel *w_current, const char *name, LeptonObject *obj);
 void g_run_hook_object_list (GschemToplevel *w_current, const char *name, GList *obj_lst);
 void
@@ -26,25 +27,23 @@ g_run_hook_page (GschemToplevel *w_current,
                  LeptonPage *page);
 void g_run_hook_action_mode (GschemToplevel *w_current, const char *name, const gchar *action_mode);
 
-/* g_keys.c */
-void g_keys_reset (GschemToplevel *w_current);
-int g_keys_execute(GschemToplevel *w_current, GdkEventKey *event);
-void g_init_keys ();
+/* keys.c */
+guint
+schematic_keys_get_event_keyval (GdkEventKey *event);
 
-/* g_register.c */
-void g_register_funcs(void);
-/* g_select.c */
-void g_init_select ();
-/* g_util.c */
-void g_init_util ();
+guint
+schematic_keys_get_event_modifiers (GdkEventKey *event);
 
-/* scheme_undo.c */
-void scheme_init_undo();
+guint
+schematic_keys_verify_keyval (guint keyval);
+
+void
+schematic_keys_reset (GschemToplevel *w_current);
 
 /* g_window.c */
-GschemToplevel *g_current_window ();
 void g_dynwind_window (GschemToplevel *w_current);
-void g_init_window ();
+void g_init_window (SCM fluid);
+
 /* lepton-schematic.c */
 void gschem_quit(void);
 void
@@ -215,7 +214,17 @@ o_attrib_select_invisible (GschemToplevel *w_current,
                            LeptonObject *selected);
 void o_attrib_toggle_visibility(GschemToplevel *w_current, LeptonObject *object);
 void o_attrib_toggle_show_name_value(GschemToplevel *w_current, LeptonObject *object, int new_show_name_value);
-LeptonObject *o_attrib_add_attrib(GschemToplevel *w_current, const char *text_string, int visibility, int show_name_value, LeptonObject *object);
+
+LeptonObject*
+o_attrib_add_attrib (GschemToplevel *w_current,
+                     const char *text_string,
+                     int visibility,
+                     int show_name_value,
+                     LeptonObject *object,
+                     gboolean proposed_coord,
+                     int x,
+                     int y);
+
 /* o_basic.c */
 #ifdef ENABLE_GTK3
 void
@@ -443,11 +452,22 @@ gboolean x_clipboard_set (GschemToplevel *w_current, const GList *object_list);
 GList *x_clipboard_get (GschemToplevel *w_current);
 /* x_color.c */
 void x_color_init();
+#ifdef ENABLE_GTK3
+GdkRGBA *x_color_lookup_gdk_rgba (size_t color_id);
+#else
 GdkColor *x_color_lookup_gdk(size_t color_id);
+#endif
 LeptonColor *x_color_lookup(size_t color_id);
 gboolean x_color_display_enabled (size_t color_id);
-void x_color_set_display (size_t color_id, GdkColor* color);
-void x_color_set_outline (size_t color_id, GdkColor* color);
+#ifdef ENABLE_GTK3
+void x_color_set_display_color (size_t color_id,
+                                GdkRGBA* color);
+void x_color_set_outline_color (size_t color_id,
+                                GdkRGBA* color);
+#else
+void x_color_set_display (size_t color_id, GdkColor* color, guint16 alpha);
+void x_color_set_outline (size_t color_id, GdkColor* color, guint16 alpha);
+#endif
 GString* x_color_map2str_display();
 GString* x_color_map2str_outline();
 
@@ -456,7 +476,11 @@ GtkWidget* x_colorcb_new ();
 int x_colorcb_get_index (GtkWidget *widget);
 void x_colorcb_set_index (GtkWidget *widget, int color_index);
 void x_colorcb_update_colors();
+#ifdef ENABLE_GTK3
+void x_colorcb_set_rgba_color (GtkTreeIter* iter, GdkRGBA* color);
+#else
 void x_colorcb_set_color (GtkTreeIter* iter, GdkColor* color);
+#endif
 
 /* x_dialog.c */
 int text_view_calculate_real_tab_width(GtkTextView *textview, int tab_size);
@@ -500,7 +524,12 @@ gint x_event_motion(GschemPageView *page_view, GdkEventMotion *event, GschemTopl
 gboolean x_event_faked_motion (GschemPageView *view, GdkEventKey *event);
 gboolean x_event_configure (GschemPageView *page_view, GdkEventConfigure *event, gpointer user_data);
 gint x_event_enter(GtkWidget *widget, GdkEventCrossing *event, GschemToplevel *w_current);
-gboolean x_event_key(GschemPageView *page_view, GdkEventKey *event, GschemToplevel *w_current);
+
+GdkEventKey*
+x_event_key (GschemPageView *page_view,
+             GdkEventKey *event,
+             GschemToplevel *w_current);
+
 gint x_event_scroll(GtkWidget *widget, GdkEventScroll *event, GschemToplevel *w_current);
 gboolean x_event_get_pointer_position (GschemToplevel *w_current, gboolean snapped, gint *wx, gint *wy);
 /* x_compselect.c */
@@ -593,7 +622,11 @@ void x_window_setup_draw_events_main_wnd (GschemToplevel* w_current,
                                           GtkWidget*      main_window);
 void x_window_setup_draw_events_drawing_area (GschemToplevel* w_current,
                                               GschemPageView* drawing_area);
-GschemToplevel* x_window_create_main (GschemToplevel *w_current, GtkWidget *menubar);
+GschemToplevel*
+x_window_create_main (GschemToplevel *w_current,
+                      GtkWidget *menubar,
+                      gpointer key_event_callback);
+
 void x_window_close(GschemToplevel *w_current);
 void x_window_close_all(GschemToplevel *w_current);
 LeptonPage*
