@@ -32,7 +32,6 @@
   #:use-module (lepton object)
   #:use-module (lepton page)
 
-  #:use-module (schematic core builtins)
   #:use-module (schematic attrib)
   #:use-module (schematic core gettext)
   #:use-module (schematic dialog)
@@ -40,6 +39,27 @@
   #:use-module (schematic selection)
   #:use-module (schematic window))
 
+
+(define (deprecation-warning name)
+  (format (current-error-port)
+          "WARNING: The function ~S() is deprecated and does nothing.~%"
+          name))
+
+(define-syntax define-deprecated
+  (syntax-rules ()
+    ((_ (name . args))
+     (begin
+       (define (name . args)
+         (deprecation-warning (quote name))
+         #f)
+       (export name)))
+    ((_ name)
+     (begin
+       (define (name)
+         (deprecation-warning (quote name))
+         #f)
+       (export name)))))
+
 ;; add-attribute-to-object object name value visible show
 ;;
 ;; Add an attribute "name=value" to object.  If visible is #f, the new
@@ -420,152 +440,144 @@
 (add-hook!/full-attribs select-objects-hook select-net-hook net?)
 
 
-(define-public (gschem-image filename)
-  (format (current-error-port)
-   "WARNING: gschem-image function is deprecated and does nothing.~%")
-)
-
-(define-public (gschem-pdf filename)
-  (format (current-error-port)
-   "WARNING: gschem-pdf function is deprecated and does nothing.~%")
-)
-
-(define-public (gschem-use-rc-values)
-  (format (current-error-port)
-   "WARNING: gschem-use-rc-values function is deprecated and does nothing.~%")
-)
+(define-deprecated (gschem-image filename))
+(define-deprecated (gschem-pdf filename))
+(define-deprecated (gschem-use-rc-values))
 
 
 ;;; Deprecated procedures replaced with actions
-;;
-;; - defined in the module (schematic core builtins)
-(define-public file-close-window %file-close-window)
-(define-public file-image %file-image)
-(define-public file-new %file-new)
-(define-public file-new-window %file-new-window)
-(define-public file-open %file-open)
-(define-public file-print %file-print)
-(define-public file-quit %file-quit)
-(define-public file-save %file-save)
-(define-public file-save-all %file-save-all)
-(define-public file-save-as %file-save-as)
-(define-public file-script %file-script)
-(define-public edit-undo %edit-undo)
-(define-public edit-redo %edit-redo)
-(define-public edit-select %edit-select)
-(define-public edit-select-all %edit-select-all)
-(define-public edit-deselect %edit-deselect)
-(define-public edit-copy %edit-copy)
-(define-public edit-mcopy %edit-mcopy)
-(define-public edit-move %edit-move)
-(define-public edit-delete %edit-delete)
-(define-public edit-rotate-90 %edit-rotate-90)
-(define-public edit-mirror %edit-mirror)
-(define-public edit-slot %edit-slot)
-(define-public edit-object-properties %edit-object-properties)
-(define-public edit-edit %edit-edit)
-(define-public edit-text %edit-text)
-(define-public edit-lock %edit-lock)
-(define-public edit-unlock %edit-unlock)
-(define-public edit-translate %edit-translate)
-(define-public edit-invoke-macro %edit-invoke-macro)
-(define-public edit-embed %edit-embed)
-(define-public edit-unembed %edit-unembed)
-(define-public edit-update %edit-update)
-(define-public edit-show-hidden %edit-show-hidden)
-(define-public edit-find-text %edit-find-text)
-(define-public edit-show-text %edit-show-text)
-(define-public edit-hide-text %edit-hide-text)
-(define-public edit-autonumber %edit-autonumber)
+(define-deprecated file-close-window)
+(define-deprecated file-image)
+(define-deprecated file-new)
+(define-deprecated file-open)
+(define-deprecated file-print)
+(define-deprecated file-quit)
+(define-deprecated file-save)
+(define-deprecated file-save-all)
+(define-deprecated file-save-as)
+(define-deprecated file-script)
 
-(define-public clipboard-copy %clipboard-copy)
-(define-public clipboard-cut %clipboard-cut)
-(define-public clipboard-paste %clipboard-paste)
+(define-deprecated edit-undo)
+(define-deprecated edit-redo)
+(define-deprecated edit-select)
+(define-deprecated edit-select-all)
+(define-deprecated edit-deselect)
+(define-deprecated edit-copy)
+(define-deprecated edit-mcopy)
+(define-deprecated edit-move)
+(define-deprecated edit-delete)
+(define-deprecated edit-rotate-90)
+(define-deprecated edit-mirror)
+(define-deprecated edit-slot)
+(define-deprecated edit-object-properties)
+(define-deprecated edit-edit)
+(define-deprecated edit-text)
+(define-deprecated edit-lock)
+(define-deprecated edit-unlock)
+(define-deprecated edit-translate)
+(define-deprecated edit-invoke-macro)
+(define-deprecated edit-embed)
+(define-deprecated edit-unembed)
+(define-deprecated edit-update)
+(define-deprecated edit-show-hidden)
+(define-deprecated edit-find-text)
+(define-deprecated edit-show-text)
+(define-deprecated edit-hide-text)
+(define-deprecated edit-autonumber)
 
-(define-public buffer-copy1 %buffer-copy1)
-(define-public buffer-copy2 %buffer-copy2)
-(define-public buffer-copy3 %buffer-copy3)
-(define-public buffer-copy4 %buffer-copy4)
-(define-public buffer-copy5 %buffer-copy5)
-(define-public buffer-cut1 %buffer-cut1)
-(define-public buffer-cut2 %buffer-cut2)
-(define-public buffer-cut3 %buffer-cut3)
-(define-public buffer-cut4 %buffer-cut4)
-(define-public buffer-cut5 %buffer-cut5)
-(define-public buffer-paste1 %buffer-paste1)
-(define-public buffer-paste2 %buffer-paste2)
-(define-public buffer-paste3 %buffer-paste3)
-(define-public buffer-paste4 %buffer-paste4)
-(define-public buffer-paste5 %buffer-paste5)
+(define-deprecated clipboard-copy)
+(define-deprecated clipboard-cut)
+(define-deprecated clipboard-paste)
+
+(define-deprecated buffer-copy1)
+(define-deprecated buffer-copy2)
+(define-deprecated buffer-copy3)
+(define-deprecated buffer-copy4)
+(define-deprecated buffer-copy5)
+(define-deprecated buffer-cut1)
+(define-deprecated buffer-cut2)
+(define-deprecated buffer-cut3)
+(define-deprecated buffer-cut4)
+(define-deprecated buffer-cut5)
+(define-deprecated buffer-paste1)
+(define-deprecated buffer-paste2)
+(define-deprecated buffer-paste3)
+(define-deprecated buffer-paste4)
+(define-deprecated buffer-paste5)
+
+(define-deprecated view-sidebar)
+(define-deprecated view-status)
+(define-deprecated view-find-text-state)
+(define-deprecated view-redraw)
+(define-deprecated view-zoom-full)
+(define-deprecated view-zoom-extents)
+(define-deprecated view-zoom-in)
+(define-deprecated view-zoom-out)
+(define-deprecated view-zoom-box)
+(define-deprecated view-pan)
+(define-deprecated view-pan-left)
+(define-deprecated view-pan-right)
+(define-deprecated view-pan-up)
+(define-deprecated view-pan-down)
+(define-deprecated view-dark-colors)
+(define-deprecated view-light-colors)
+(define-deprecated view-bw-colors)
+(define-deprecated view-color-edit)
+
+(define-deprecated page-manager)
+(define-deprecated page-next)
+(define-deprecated page-prev)
+(define-deprecated page-close)
+(define-deprecated page-revert)
+(define-deprecated page-print)
+(define-deprecated page-next-tab)
+(define-deprecated page-prev-tab)
+
+(define-deprecated add-component)
+(define-deprecated add-attribute)
+(define-deprecated add-net)
+(define-deprecated add-bus)
+(define-deprecated add-text)
+(define-deprecated add-path)
+(define-deprecated add-line)
+(define-deprecated add-box)
+(define-deprecated add-picture)
+(define-deprecated add-circle)
+(define-deprecated add-arc)
+(define-deprecated add-pin)
+
+(define-deprecated hierarchy-down-schematic)
+(define-deprecated hierarchy-down-symbol)
+(define-deprecated hierarchy-up)
+
+(define-deprecated attributes-show-name)
+(define-deprecated attributes-show-value)
+(define-deprecated attributes-show-both)
+(define-deprecated attributes-visibility-toggle)
+
+(define-deprecated options-snap-size)
+(define-deprecated options-scale-up-snap-size)
+(define-deprecated options-scale-down-snap-size)
+(define-deprecated options-action-feedback)
+(define-deprecated options-grid)
+(define-deprecated options-snap)
+(define-deprecated options-rubberband)
+(define-deprecated options-magneticnet)
+(define-deprecated options-select-font)
+(define-deprecated options-draw-grips)
+(define-deprecated options-show-log-window)
+(define-deprecated options-show-coord-window)
+
+(define-deprecated help-about)
+(define-deprecated help-hotkeys)
+
+(define-deprecated cancel)
 
-(define-public view-sidebar %view-sidebar)
-(define-public view-status %view-status)
-(define-public view-find-text-state %view-find-text-state)
-(define-public view-redraw %view-redraw)
-(define-public view-zoom-full %view-zoom-full)
-(define-public view-zoom-extents %view-zoom-extents)
-(define-public view-zoom-in %view-zoom-in)
-(define-public view-zoom-out %view-zoom-out)
-(define-public view-zoom-box %view-zoom-box)
-(define-public view-pan %view-pan)
-(define-public view-pan-left %view-pan-left)
-(define-public view-pan-right %view-pan-right)
-(define-public view-pan-up %view-pan-up)
-(define-public view-pan-down %view-pan-down)
-(define-public view-dark-colors %view-dark-colors)
-(define-public view-light-colors %view-light-colors)
-(define-public view-bw-colors %view-bw-colors)
-(define-public view-color-edit %view-color-edit)
-(define-public page-manager %page-manager)
-(define-public page-next %page-next)
-(define-public page-prev %page-prev)
-(define-public page-close %page-close)
-(define-public page-revert %page-revert)
-(define-public page-print %page-print)
-(define-public page-next-tab %page-next-tab)
-(define-public page-prev-tab %page-prev-tab)
-(define-public add-component %add-component)
-(define-public add-attribute %add-attribute)
-(define-public add-net %add-net)
-(define-public add-bus %add-bus)
-(define-public add-text %add-text)
-(define-public add-path %add-path)
-(define-public add-line %add-line)
-(define-public add-box %add-box)
-(define-public add-picture %add-picture)
-(define-public add-circle %add-circle)
-(define-public add-arc %add-arc)
-(define-public add-pin %add-pin)
-(define-public hierarchy-down-schematic %hierarchy-down-schematic)
-(define-public hierarchy-down-symbol %hierarchy-down-symbol)
-(define-public hierarchy-up %hierarchy-up)
-(define-public attributes-show-name %attributes-show-name)
-(define-public attributes-show-value %attributes-show-value)
-(define-public attributes-show-both %attributes-show-both)
-(define-public attributes-visibility-toggle %attributes-visibility-toggle)
-(define-public options-snap-size %options-snap-size)
-(define-public options-scale-up-snap-size %options-scale-up-snap-size)
-(define-public options-scale-down-snap-size %options-scale-down-snap-size)
-(define-public options-action-feedback %options-action-feedback)
-(define-public options-grid %options-grid)
-(define-public options-snap %options-snap)
-(define-public options-rubberband %options-rubberband)
-(define-public options-magneticnet %options-magneticnet)
-(define-public options-select-font %options-select-font)
-(define-public options-draw-grips %options-draw-grips)
-(define-public options-show-log-window %options-show-log-window)
-(define-public options-show-coord-window %options-show-coord-window)
-(define-public help-about %help-about)
-(define-public help-hotkeys %help-hotkeys)
-(define-public cancel %cancel)
 
-;; - defined in the gschem source code
 (define-public (gschem-exit) (primitive-exit 0))
 (define-public (gschem-log msg)
   (log! 'message msg))
 (define-public gschem-msg schematic-message-dialog)
 (define-public gschem-confirm schematic-confirm-dialog)
 (define-public gschem-filesel schematic-fileselect-dialog)
-(define-public (gschem-version version)
-  (format (current-error-port)
-   "WARNING: The function gschem-version() is deprecated and does nothing.~%"))
+(define-deprecated (gschem-version version))
