@@ -1,6 +1,6 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 2018 dmn <graahnul.grom@gmail.com>
- * Copyright (C) 2018-2021 Lepton EDA Contributors
+ * Copyright (C) 2018-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -585,8 +585,8 @@ save_settings_dlg (FontSelectWidget* widget)
     _("Save configuration"),
     GTK_WINDOW (widget->toplevel_->main_window),
     GTK_DIALOG_MODAL,
-    GTK_STOCK_OK,     GTK_RESPONSE_ACCEPT,
-    GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+    _("_OK"), GTK_RESPONSE_ACCEPT,
+    _("_Cancel"), GTK_RESPONSE_REJECT,
     NULL);
 
   /* text for radio buttons: */
