@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ void arc_angle_dialog (GschemToplevel *w_current, LeptonObject *arc_object)
 {
   GtkWidget *label[3];
   GtkWidget *vbox;
-  GtkWidget *alignment, *table;
+  GtkWidget *table;
   GtkWidget *widget[3];
 
   if (!w_current->aawindow) {
@@ -104,17 +104,17 @@ void arc_angle_dialog (GschemToplevel *w_current, LeptonObject *arc_object)
                                                          GTK_WINDOW(w_current->main_window),
                                                          GTK_DIALOG_MODAL,
                                                          "arc-angle", w_current,
-                                                         GTK_STOCK_CANCEL,
-                                                         GTK_RESPONSE_REJECT,
-                                                         GTK_STOCK_OK,
-                                                         GTK_RESPONSE_ACCEPT,
+                                                         _("_Cancel"), GTK_RESPONSE_REJECT,
+                                                         _("_OK"), GTK_RESPONSE_ACCEPT,
                                                          NULL);
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
     gtk_dialog_set_alternative_button_order(GTK_DIALOG(w_current->aawindow),
                                             GTK_RESPONSE_ACCEPT,
                                             GTK_RESPONSE_REJECT,
                                             -1);
+#endif
 
     gtk_window_set_position (GTK_WINDOW (w_current->aawindow), GTK_WIN_POS_MOUSE);
 
@@ -130,11 +130,12 @@ void arc_angle_dialog (GschemToplevel *w_current, LeptonObject *arc_object)
     vbox = gtk_dialog_get_content_area (GTK_DIALOG (w_current->aawindow));
     gtk_box_set_spacing(GTK_BOX(vbox), DIALOG_V_SPACING);
 
-
-    alignment = gtk_alignment_new(0,0,1,1);
+#ifndef ENABLE_GTK3
+    GtkWidget *alignment = gtk_alignment_new (0, 0, 1, 1);
     gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0,
                               0 /*DIALOG_INDENTATION */, 0);
     gtk_box_pack_start(GTK_BOX(vbox), alignment, FALSE, FALSE, 0);
+#endif
 
     label[0] = gschem_dialog_misc_create_property_label (_("Arc _Radius:"));
     label[1] = gschem_dialog_misc_create_property_label (_("Start _Angle:"));
@@ -149,8 +150,13 @@ void arc_angle_dialog (GschemToplevel *w_current, LeptonObject *arc_object)
     widget[2] = gtk_spin_button_new_with_range (-360,360,1);
     gtk_entry_set_activates_default(GTK_ENTRY(widget[2]), TRUE);
 
-        table = gschem_dialog_misc_create_property_table (label, widget, 3);
+    table = gschem_dialog_misc_create_property_table (label, widget, 3);
+
+#ifdef ENABLE_GTK3
+    gtk_box_pack_start (GTK_BOX(vbox), table, FALSE, FALSE, 0);
+#else
     gtk_container_add (GTK_CONTAINER(alignment), table);
+#endif
 
     GLADE_HOOKUP_OBJECT(w_current->aawindow, widget[0], "radius");
     GLADE_HOOKUP_OBJECT(w_current->aawindow, widget[1],"spin_start");
