@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -460,12 +460,14 @@ close_confirmation_dialog_constructor (GType type,
                 /* GtkBox */
                 "spacing", 14,
                 NULL);
+#ifndef ENABLE_GTK3
   g_object_set (gtk_dialog_get_action_area (GTK_DIALOG (dialog)),
                 /* GtkBox */
                 "spacing",      6,
                 /* GtkContainer */
                 "border-width", 5,
                 NULL);
+#endif
 
   /* check if there is one or more than one page with changes */
   ret = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (
@@ -496,7 +498,7 @@ close_confirmation_dialog_constructor (GType type,
                                     "xalign",    0.5,
                                     "yalign",    0.0,
                                     /* GtkImage */
-                                    "stock",     GTK_STOCK_DIALOG_WARNING,
+                                    "icon-name", "dialog-warning",
                                     "icon-size", GTK_ICON_SIZE_DIALOG,
                                     NULL));
   gtk_box_pack_start (GTK_BOX (hbox), image,
@@ -583,16 +585,18 @@ close_confirmation_dialog_constructor (GType type,
   /* add buttons to dialog action area */
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
                           _("Close _without saving"), GTK_RESPONSE_NO,
-                          GTK_STOCK_CANCEL,           GTK_RESPONSE_CANCEL,
-                          GTK_STOCK_SAVE,             GTK_RESPONSE_YES,
+                          _("_Cancel"), GTK_RESPONSE_CANCEL,
+                          _("_Save"), GTK_RESPONSE_YES,
                           NULL);
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
                                           GTK_RESPONSE_YES,
                                           GTK_RESPONSE_NO,
                                           GTK_RESPONSE_CANCEL,
                                           -1);
+#endif
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
 
