@@ -48,9 +48,14 @@ gschem_dialog_misc_create_property_label (const char *label)
 {
   GtkWidget *widget = gtk_label_new_with_mnemonic (label);
 
+#ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (widget), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (widget), 0.0);
+#else
   gtk_misc_set_alignment (GTK_MISC (widget),
                           0.0,                  /* xalign */
                           0.0);                 /* yalign */
+#endif
 
   return widget;
 }
@@ -88,6 +93,8 @@ gschem_dialog_misc_create_property_table (GtkWidget *label[], GtkWidget *widget[
                      1,
                      1);
 
+    gtk_widget_set_hexpand (GTK_WIDGET (widget[index]), TRUE);
+
     gtk_grid_attach (GTK_GRID (grid),
                      widget[index],
                      1,
@@ -155,9 +162,10 @@ gschem_dialog_misc_create_property_table (GtkWidget *label[], GtkWidget *widget[
 GtkWidget*
 gschem_dialog_misc_create_section_widget (const char *label, GtkWidget *child)
 {
-  GtkWidget *alignment;
   GtkWidget *expander;
 
+#ifndef ENABLE_GTK3
+  GtkWidget *alignment;
   alignment = gtk_alignment_new (0.0,     /* xalign */
                                  0.0,     /* yalign */
                                  1.0,     /* xscale */
@@ -170,6 +178,7 @@ gschem_dialog_misc_create_section_widget (const char *label, GtkWidget *child)
                             0);                    /* padding_right  */
 
   gtk_container_add (GTK_CONTAINER (alignment), child);
+#endif
 
   expander = gtk_expander_new (label);
 
@@ -181,7 +190,11 @@ gschem_dialog_misc_create_section_widget (const char *label, GtkWidget *child)
   gtk_expander_set_spacing (GTK_EXPANDER (expander), DIALOG_V_SPACING);
   gtk_expander_set_use_markup (GTK_EXPANDER (expander), TRUE);
 
+#ifdef ENABLE_GTK3
+  gtk_container_add (GTK_CONTAINER (expander), child);
+#else
   gtk_container_add (GTK_CONTAINER (expander), alignment);
+#endif
 
   return expander;
 }
