@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 
 #include <config.h>
 #include "gschem.h"
+#include <liblepton/glib_compat.h>
 
 
 enum
@@ -386,7 +387,8 @@ find_objects_using_pattern (GSList *pages,
         continue;
       }
 
-      if (g_pattern_match_string (pattern, str)) {
+      if (g_pattern_spec_match_string (pattern, str))
+      {
         object_list = g_slist_prepend (object_list, object);
       }
     }
