@@ -174,7 +174,7 @@ dispose (GObject *object)
   g_return_if_fail (view != NULL);
 
   if (view->_page) {
-    s_page_remove_weak_ptr (view->_page, &view->_page);
+    lepton_page_remove_weak_ptr (view->_page, &view->_page);
     view->_page = NULL;
   }
 
@@ -529,7 +529,7 @@ gschem_page_view_get_page_geometry (GschemPageView *view)
     geometry_cache_insert (view, page, geometry);
 
     gschem_page_geometry_zoom_extents (geometry,
-                                       s_page_objects (page),
+                                       lepton_page_objects (page),
                                        view->show_hidden_text);
   }
   else {
@@ -1045,16 +1045,16 @@ gschem_page_view_set_page (GschemPageView *view,
   if (page != view->_page) {
 
     if (view->_page) {
-      s_page_remove_weak_ptr (view->_page, &view->_page);
+      lepton_page_remove_weak_ptr (view->_page, &view->_page);
       view->_page = NULL;
     }
 
     if (page) {
       view->_page = page;
-      s_page_add_weak_ptr (view->_page, &view->_page);
+      lepton_page_add_weak_ptr (view->_page, &view->_page);
 
       g_return_if_fail (page->toplevel != NULL);
-      s_page_goto (page->toplevel, page);
+      lepton_toplevel_goto_page (page->toplevel, page);
 
       /* redraw the current page and update UI */
       gschem_page_view_invalidate_all (view);
@@ -1488,7 +1488,7 @@ gschem_page_view_zoom_extents (GschemPageView *view, const GList *objects)
   g_return_if_fail (geometry != NULL);
 
   if (temp == NULL) {
-    temp = s_page_objects (gschem_page_view_get_page (view));
+    temp = lepton_page_objects (gschem_page_view_get_page (view));
   }
 
   gschem_page_geometry_zoom_extents (geometry, temp, view->show_hidden_text);
@@ -1655,7 +1655,7 @@ geometry_cache_insert (GschemPageView *view,
   g_return_if_fail (geometry);
   g_return_if_fail (!g_hash_table_contains (view->_geometry_cache, page));
 
-  s_page_weak_ref (page, geometry_cache_page_weak_ref_notify, view);
+  lepton_page_weak_ref (page, geometry_cache_page_weak_ref_notify, view);
   g_hash_table_insert (view->_geometry_cache, page, geometry);
 }
 
@@ -1664,7 +1664,9 @@ geometry_cache_dispose_func (gpointer key,
                              gpointer value,
                              gpointer user_data)
 {
-  s_page_weak_unref ((LeptonPage*) key, geometry_cache_page_weak_ref_notify, user_data);
+  lepton_page_weak_unref ((LeptonPage*) key,
+                          geometry_cache_page_weak_ref_notify,
+                          user_data);
   gschem_page_geometry_free ((GschemPageGeometry*) value);
   return TRUE;
 }
