@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,17 +92,17 @@ void slot_edit_dialog (GschemToplevel *w_current, const char *count, const char
                                                          GTK_WINDOW(w_current->main_window),
                                                          GTK_DIALOG_MODAL,
                                                          "slot-edit", w_current,
-                                                         GTK_STOCK_CANCEL,
-                                                         GTK_RESPONSE_REJECT,
-                                                         GTK_STOCK_OK,
-                                                         GTK_RESPONSE_ACCEPT,
+                                                         _("_Cancel"), GTK_RESPONSE_REJECT,
+                                                         _("_OK"), GTK_RESPONSE_ACCEPT,
                                                          NULL);
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
     gtk_dialog_set_alternative_button_order(GTK_DIALOG(w_current->sewindow),
                                             GTK_RESPONSE_ACCEPT,
                                             GTK_RESPONSE_REJECT,
                                             -1);
+#endif
 
     gtk_window_set_position (GTK_WINDOW (w_current->sewindow), GTK_WIN_POS_MOUSE);
 
@@ -124,21 +124,21 @@ void slot_edit_dialog (GschemToplevel *w_current, const char *count, const char
     widget[0] = gtk_entry_new();
     gtk_entry_set_max_length(GTK_ENTRY(widget[0]), 80);
     gtk_editable_set_editable (GTK_EDITABLE(widget[0]), FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET(widget[0]), FALSE);
+    gtk_widget_set_sensitive (GTK_WIDGET(widget[0]), FALSE);
 
-	widget[1] = gtk_entry_new();
+    widget[1] = gtk_entry_new();
     gtk_entry_set_max_length(GTK_ENTRY(widget[1]), 80);
     gtk_entry_set_activates_default (GTK_ENTRY(widget[1]),TRUE);
 
     table = gschem_dialog_misc_create_property_table(label, widget, 2);
 
-	gtk_box_pack_start (GTK_BOX (vbox),                          /* box     */
+    gtk_box_pack_start (GTK_BOX (vbox),                          /* box     */
                         table,                                   /* child   */
                         FALSE,                                   /* expand  */
                         FALSE,                                   /* fill    */
                         0);                                      /* padding */
 
-	GLADE_HOOKUP_OBJECT(w_current->sewindow, widget[0], "countentry");
+    GLADE_HOOKUP_OBJECT(w_current->sewindow, widget[0], "countentry");
     GLADE_HOOKUP_OBJECT(w_current->sewindow, widget[1], "textentry");
     gtk_widget_show_all (w_current->sewindow);
   }
