@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 2013 Ales Hvezda
  * Copyright (C) 2013-2015 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -220,7 +220,7 @@ create_text_content_section (GschemTextPropertiesWidget *widget)
 
   gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
 
-  widget->apply_button = gtk_button_new_from_stock (GTK_STOCK_APPLY);
+  widget->apply_button = gtk_button_new_with_mnemonic (_("_Apply"));
 
   g_signal_connect_swapped (G_OBJECT (widget->apply_button),
                             "clicked",
