@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -213,7 +213,7 @@ GschemToplevel *gschem_toplevel_new ()
 
 
   w_current->keyaccel_string = NULL;
-  w_current->keyaccel_string_source_id = FALSE;
+  w_current->keyaccel_string_source_id = 0;
 
   /* ------------ */
   /* Dialog boxes */
@@ -352,8 +352,6 @@ GschemToplevel *gschem_toplevel_new ()
 
   w_current->bus_ripper_symname = NULL;
 
-  w_current->smob = SCM_UNDEFINED;
-
   return w_current;
 }
 
@@ -827,3 +825,128 @@ schematic_window_get_active_page (GschemToplevel *w_current)
 
   return toplevel->page_current;
 }
+
+
+/*! \brief Get the GdkDisplay for this schematic window.
+ *
+ *  \param [in] w_current The schematic window.
+ *  \return The GdkDisplay of the window.
+ */
+GdkDisplay*
+schematic_window_get_gdk_display (GschemToplevel *w_current)
+{
+  g_return_val_if_fail (w_current != NULL, NULL);
+
+  return gtk_widget_get_display (w_current->main_window);
+}
+
+
+/*! \brief Get the options for this schematic window.
+ *
+ *  \param [in] w_current The schematic window.
+ *  \return The options of the schematic window.
+ */
+GschemOptions*
+schematic_window_get_options (GschemToplevel *w_current)
+{
+  g_return_val_if_fail (w_current != NULL, NULL);
+
+  return w_current->options;
+}
+
+
+/*! \brief Update key accelerator string in status bar.
+ * \par Function Description
+ * Given the key accelerator string previously set in the status
+ * bar, updates it by combining it with the new key label, or just
+ * sets the new value provided.  The behaviour varies depending on
+ * whether the previously set string was a prefix in a key
+ * sequence or not.
+ *
+ * \param [in] w_current The active #GschemToplevel context.
+ * \param [in] keystr The new key label.
+ */
+void
+schematic_window_update_keyaccel_string (GschemToplevel *w_current,
+                                         char *keystr)
+{
+  /* If no current hint string, or the hint string is going to be
+   * cleared anyway, use key string directly */
+  if ((w_current->keyaccel_string == NULL) ||
+      w_current->keyaccel_string_source_id) {
+    g_free (w_current->keyaccel_string);
+    w_current->keyaccel_string = g_strdup (keystr);
+  }
+  else
+  {
+    gchar *p = w_current->keyaccel_string;
+    w_current->keyaccel_string = g_strconcat (p, " ", keystr, NULL);
+    g_free (p);
+  }
+
+  /* Update status bar */
+  i_show_state(w_current, NULL);
+}
+
+
+/*! \brief Clear the current key accelerator string.
+ * \par Function Description
+ * This function clears the current keyboard accelerator string in
+ * the status bar of the relevant toplevel.  Called some time after a
+ * keystroke is pressed.  If the current key sequence was a prefix,
+ * let it persist.
+ *
+ * \param [in] data a pointer to the GschemToplevel to update.
+ * \return FALSE (this is a one-shot timer).
+ */
+static gboolean
+clear_keyaccel_string (gpointer data)
+{
+  GschemToplevel *w_current = GSCHEM_TOPLEVEL (data);
+
+  /* If the window context has disappeared, do nothing. */
+  if (g_list_find(global_window_list, w_current) == NULL) {
+    return FALSE;
+  }
+
+  g_free(w_current->keyaccel_string);
+  w_current->keyaccel_string = NULL;
+  w_current->keyaccel_string_source_id = 0;
+  i_show_state(w_current, NULL);
+  return FALSE;
+}
+
+
+/*! \brief Update timer for clearing the current key accelerator string.
+ * \par Function Description
+ * If a timer responsible for clearing key accelerator string in
+ * the status bar has been started, the function stops it.  If \a
+ * start_timer is TRUE, it runs a new timer for this.  It should
+ * be FALSE if the current key sequence is a prefix which should
+ * persist.
+ *
+ * \param [in] w_current The GschemToplevel to update.
+ * \param [in] start_timer If a new timer should be started.
+ */
+void
+schematic_window_update_keyaccel_timer (GschemToplevel *w_current,
+                                        gboolean start_timer)
+{
+  if (w_current->keyaccel_string_source_id)
+  {
+    /* Cancel any existing timers that haven't fired yet. */
+    GSource *timer =
+      g_main_context_find_source_by_id (NULL,
+                                        w_current->keyaccel_string_source_id);
+    if (timer != NULL)
+    {
+      g_source_destroy (timer);
+    }
+    w_current->keyaccel_string_source_id = 0;
+  }
+  if (start_timer)
+  {
+    w_current->keyaccel_string_source_id =
+      g_timeout_add (400, clear_keyaccel_string, w_current);
+  }
+}
