@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -253,7 +253,7 @@ void i_set_state(GschemToplevel *w_current, enum x_states newstate)
 
   update_state_menu_items (w_current, newstate);
 
-  g_run_hook_action_mode (w_current, "%switch-action-mode-hook", mode);
+  g_run_hook_action_mode (w_current, "switch-action-mode-hook", mode);
 }
 
 /*! \brief Set new state, then show state field including some
