@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -106,8 +106,8 @@ i_callback_file_script (GtkWidget *widget, gpointer data)
     _("Execute Script"),
     GTK_WINDOW (w_current->main_window),
     GTK_FILE_CHOOSER_ACTION_OPEN,
-    GTK_STOCK_CANCEL,  GTK_RESPONSE_CANCEL,
-    GTK_STOCK_EXECUTE, GTK_RESPONSE_ACCEPT,
+    _("_Cancel"), GTK_RESPONSE_CANCEL,
+    _("_Run"), GTK_RESPONSE_ACCEPT,
     NULL);
 
   /* Filter for Scheme files:
@@ -124,11 +124,13 @@ i_callback_file_script (GtkWidget *widget, gpointer data)
   gtk_file_filter_add_pattern (filter_all, "*");
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter_all);
 
+#ifndef ENABLE_GTK3
   gtk_dialog_set_alternative_button_order(
     GTK_DIALOG (dialog),
     GTK_RESPONSE_ACCEPT,
     GTK_RESPONSE_CANCEL,
     -1);
+#endif
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
   {
@@ -461,7 +463,8 @@ i_callback_edit_copy (GtkWidget *widget, gpointer data)
 
   if (o_select_return_first_object(w_current)) {
     o_redraw_cleanstates(w_current);
-    if (g_action_get_position (TRUE, &wx, &wy)) {
+    if (g_action_get_position (w_current, TRUE, &wx, &wy))
+    {
       o_copy_start(w_current, wx, wy);
     }
     i_set_state (w_current, COPYMODE);
@@ -485,7 +488,8 @@ i_callback_edit_mcopy (GtkWidget *widget, gpointer data)
 
   if (o_select_return_first_object(w_current)) {
     o_redraw_cleanstates(w_current);
-    if (g_action_get_position (TRUE, &wx, &wy)) {
+    if (g_action_get_position (w_current, TRUE, &wx, &wy))
+    {
       o_copy_start(w_current, wx, wy);
     }
     i_set_state (w_current, MCOPYMODE);
@@ -509,7 +513,8 @@ i_callback_edit_move (GtkWidget *widget, gpointer data)
 
   if (o_select_return_first_object(w_current)) {
     o_redraw_cleanstates(w_current);
-    if (g_action_get_position (TRUE, &wx, &wy)) {
+    if (g_action_get_position (w_current, TRUE, &wx, &wy))
+    {
       o_move_start(w_current, wx, wy);
     }
     i_set_state (w_current, MOVEMODE);
@@ -636,7 +641,8 @@ i_callback_edit_rotate_90 (GtkWidget *widget, gpointer data)
     return;
   }
 
-  if (!g_action_get_position (TRUE, &wx, &wy)) {
+  if (!g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     i_set_state(w_current, ROTATEMODE);
     return;
   }
@@ -678,7 +684,8 @@ i_callback_edit_mirror (GtkWidget *widget, gpointer data)
     return;
   }
 
-  if (!g_action_get_position (TRUE, &wx, &wy)) {
+  if (!g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     i_set_state(w_current, MIRRORMODE);
     return;
   }
@@ -1126,7 +1133,8 @@ i_callback_view_zoom_box (GtkWidget *widget, gpointer data)
 
   i_set_state(w_current, ZOOMBOX);
 
-  if (g_action_get_position (FALSE, &wx, &wy)) {
+  if (g_action_get_position (w_current, FALSE, &wx, &wy))
+  {
     a_zoom_box_start(w_current, wx, wy);
   }
 }
@@ -1150,7 +1158,7 @@ i_callback_view_zoom_in (GtkWidget *widget, gpointer data)
   a_zoom (w_current,
           page_view,
           ZOOM_IN,
-          g_action_get_position (FALSE, NULL, NULL) ? HOTKEY : MENU);
+          g_action_get_position (w_current, FALSE, NULL, NULL) ? HOTKEY : MENU);
 
   if (w_current->undo_panzoom) {
     o_undo_savestate_old(w_current, UNDO_VIEWPORT_ONLY);
@@ -1176,7 +1184,7 @@ i_callback_view_zoom_out (GtkWidget *widget, gpointer data)
   a_zoom(w_current,
          page_view,
          ZOOM_OUT,
-         g_action_get_position (FALSE, NULL, NULL) ? HOTKEY : MENU);
+         g_action_get_position (w_current, FALSE, NULL, NULL) ? HOTKEY : MENU);
 
   if (w_current->undo_panzoom) {
     o_undo_savestate_old(w_current, UNDO_VIEWPORT_ONLY);
@@ -1199,7 +1207,8 @@ i_callback_view_pan (GtkWidget *widget, gpointer data)
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
   g_return_if_fail (page_view != NULL);
 
-  if (!g_action_get_position (FALSE, &wx, &wy)) {
+  if (!g_action_get_position (w_current, FALSE, &wx, &wy))
+  {
     o_redraw_cleanstates (w_current);
     i_action_stop (w_current);
     i_set_state (w_current, PAN);
@@ -1530,11 +1539,13 @@ i_callback_page_revert (GtkWidget *widget, gpointer data)
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Revert"));
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
                                           GTK_RESPONSE_YES,
                                           GTK_RESPONSE_NO,
                                           -1);
+#endif
 
   response = gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
@@ -1657,7 +1668,7 @@ i_callback_clipboard_paste (GtkWidget *widget, gpointer data)
 
   g_return_if_fail (w_current != NULL);
 
-  g_action_get_position (TRUE, &wx, &wy);
+  g_action_get_position (w_current, TRUE, &wx, &wy);
 
   o_redraw_cleanstates(w_current);
   empty = o_buffer_paste_start (w_current, wx, wy, CLIPBOARD_BUFFER);
@@ -1724,7 +1735,7 @@ buffer_paste (gpointer data, int n)
 
   g_return_if_fail (w_current != NULL);
 
-  g_action_get_position (TRUE, &wx, &wy);
+  g_action_get_position (w_current, TRUE, &wx, &wy);
 
   empty = o_buffer_paste_start (w_current, wx, wy, n-1);
 
@@ -1786,7 +1797,7 @@ i_callback_add_attribute (GtkWidget *widget, gpointer data)
   g_return_if_fail (w_current != NULL);
 
   attrib_edit_dialog(w_current, NULL,
-                     g_action_get_position (TRUE, NULL, NULL) ? FROM_HOTKEY : FROM_MENU);
+                     g_action_get_position (w_current, TRUE, NULL, NULL) ? FROM_HOTKEY : FROM_MENU);
 
   i_set_state(w_current, SELECT);
 }
@@ -1808,7 +1819,8 @@ i_callback_add_net (GtkWidget *widget, gpointer data)
 
   i_set_state(w_current, NETMODE);
 
-  if (g_action_get_position (TRUE, &wx, &wy)) {
+  if (g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     o_net_reset(w_current);
     o_net_start(w_current, wx, wy);
   }
@@ -1851,7 +1863,8 @@ i_callback_add_bus (GtkWidget *widget, gpointer data)
 
   i_set_state(w_current, BUSMODE);
 
-  if (g_action_get_position (TRUE, &wx, &wy)) {
+  if (g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     o_bus_start(w_current, wx, wy);
   }
 }
@@ -1914,7 +1927,8 @@ i_callback_add_line (GtkWidget *widget, gpointer data)
 
   i_set_state(w_current, LINEMODE);
 
-  if (g_action_get_position (TRUE, &wx, &wy)) {
+  if (g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     o_line_start(w_current, wx, wy);
   }
 }
@@ -1953,7 +1967,8 @@ i_callback_add_box (GtkWidget *widget, gpointer data)
 
   i_set_state(w_current, BOXMODE);
 
-  if (g_action_get_position (TRUE, &wx, &wy)) {
+  if (g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     o_box_start(w_current, wx, wy);
   }
 }
@@ -1996,7 +2011,8 @@ i_callback_add_circle (GtkWidget *widget, gpointer data)
 
   i_set_state(w_current, CIRCLEMODE);
 
-  if (g_action_get_position (TRUE, &wx, &wy)) {
+  if (g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     o_circle_start(w_current, wx, wy);
   }
 }
@@ -2019,7 +2035,8 @@ i_callback_add_arc (GtkWidget *widget, gpointer data)
 
   i_set_state(w_current, ARCMODE);
 
-  if (g_action_get_position (TRUE, &wx, &wy)) {
+  if (g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     o_arc_start(w_current, wx, wy);
   }
 }
@@ -2042,7 +2059,8 @@ i_callback_add_pin (GtkWidget *widget, gpointer data)
 
   i_set_state (w_current, PINMODE);
 
-  if (g_action_get_position (TRUE, &wx, &wy)) {
+  if (g_action_get_position (w_current, TRUE, &wx, &wy))
+  {
     o_pin_start(w_current, wx, wy);
   }
 }
@@ -2702,7 +2720,7 @@ i_callback_cancel (GtkWidget *widget, gpointer data)
   i_set_state(w_current, SELECT);
 
   /* clear the key guile command-sequence */
-  g_keys_reset (w_current);
+  schematic_keys_reset (w_current);
 
   gschem_page_view_invalidate_all (gschem_toplevel_get_current_page_view (w_current));
 
