@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,7 +68,8 @@ o_attrib_add_selected (GschemToplevel *w_current,
     a_current = (LeptonObject*) a_iter->data;
 
     /* make sure object isn't selected already */
-    if (!a_current->selected) {
+    if (!lepton_object_get_selected (a_current))
+    {
       o_selection_add (selection, a_current);
       selected_objects = g_list_prepend (selected_objects, a_current);
     }
@@ -76,7 +77,7 @@ o_attrib_add_selected (GschemToplevel *w_current,
 
   if (selected_objects != NULL) {
     /* Run select-objects-hook */
-    g_run_hook_object_list (w_current, "%select-objects-hook",
+    g_run_hook_object_list (w_current, "select-objects-hook",
                             selected_objects);
     g_list_free (selected_objects);
   }
@@ -114,7 +115,9 @@ o_attrib_deselect_invisible (GschemToplevel *w_current,
        a_iter = g_list_next (a_iter)) {
     a_current = (LeptonObject*) a_iter->data;
 
-    if (a_current->selected && !lepton_text_object_is_visible (a_current)) {
+    if (lepton_object_get_selected (a_current)
+        && !lepton_text_object_is_visible (a_current))
+    {
       o_selection_remove (selection, a_current);
     }
   }
@@ -152,7 +155,9 @@ o_attrib_select_invisible (GschemToplevel *w_current,
        a_iter = g_list_next (a_iter)) {
     a_current = (LeptonObject*) a_iter->data;
 
-    if (!a_current->selected && !lepton_text_object_is_visible (a_current)) {
+    if (!lepton_object_get_selected (a_current)
+        && !lepton_text_object_is_visible (a_current))
+    {
       o_selection_add (selection, a_current);
     }
   }
@@ -224,19 +229,78 @@ void o_attrib_toggle_show_name_value(GschemToplevel *w_current,
 }
 
 
-/*! \todo Finish function documentation!!!
- *  \brief
+/*! \brief Adds an attribute with given parameters to the active page
  *  \par Function Description
+ *  This function creates and returns an attribute object with
+ *  given properties from \a text_string and adds it to the canvas
+ *  of the #GschemToplevel object \a w_current.  Depending on the
+ *  state of the objects on the page (selection, visibility), it
+ *  adds an attached or unattached attribute and selects an
+ *  appropriate place for it.  The strategy of choosing the place
+ *  and other features is rather complicated:
  *
+ * - First, the function checks if \a object is not NULL, and if
+ *   so, gets its coordinates to learn where to place the
+ *   attribute.  For most of primitives, the attribute becomes an
+ *   attached one, and its coords are set using the coords of \a
+ *   object.  For text, its coords are used in the calculations,
+ *   though the attribute gets unattached.
+ *
+ *   \bug Some objects, like paths or pictures, are not taken
+ *   into account in the code.
+ *
+ * - If there is no object to attach the attrib to, a toplevel
+ *   (floating) attribute is created.
+ *
+ * - If any cooordinate is proposed with \a proposed_coord, \a x,
+ *   and \a y, it becomes the coordinate of the new attrib.
+ *
+ * - Otherwise, if no coord is proposed, and no any visible object
+ *   exists on the page, the coordinate is set to the bottom-left
+ *   corner of the visible objects.
+ *
+ * - Then, if there is no visible object, and no coord is proposed,
+ *   the value of the center of the current page view becomes the
+ *   anchor of the attribute.
+ *
+ * - Eventually, if no one of the above conditions can be met,
+ *   when, for example, the program using this function, be it C
+ *   or Scheme code, misses a page view, the last resort is
+ *   setting the anchor to a specific value.  Currently, it is
+ *   (0,0).
+ *
+ * After creating a text item for the attribute with the coords
+ * and other parameters described above, it gets appended to the
+ * currently active page, attached to the given object if it
+ * exists, and selected in order to enable further GUI processing.
+ *
+ * \bug slot= attributes are processed specially in this function,
+ * which is wrong.
+ *
+ * Eventually, two Scheme hooks are evaluated, add-objects-hook()
+ * and select-objects-hook().  The user may set up some other
+ * script processing of newly added and hence selected attributes
+ * there.
+ *
+ *  \param [in] w_current The GschemToplevel object.
+ *  \param [in] text_string The text string of the attribute object.
+ *  \param [in] visibility If the attribute should be visible.
+ *  \param [in] show_name_value What combination of name-value to show.
+ *  \param [in] object The parent object to attach the new attribute to.
+ *  \param [in] proposed_coord If the proposed coord values can be used.
+ *  \param [in] x The proposed X coordinate.
+ *  \param [in] y The proposed Y coordinate.
+ *  \return The new attribute object.
  */
-/* This function no longer returns NULL, but will always return the new */
-/* text item */
 LeptonObject*
 o_attrib_add_attrib (GschemToplevel *w_current,
                      const char *text_string,
                      int visibility,
                      int show_name_value,
-                     LeptonObject *object)
+                     LeptonObject *object,
+                     gboolean proposed_coord,
+                     int x,
+                     int y)
 {
   LeptonObject *new_obj;
   int world_x = - 1, world_y = -1;
@@ -244,6 +308,7 @@ o_attrib_add_attrib (GschemToplevel *w_current,
   int angle = 0;
   int color;
   int left, right, top, bottom;
+  int found;
   LeptonObject *o_current;
   LeptonPage *active_page = schematic_window_get_active_page (w_current);
 
@@ -251,9 +316,10 @@ o_attrib_add_attrib (GschemToplevel *w_current,
 
   o_current = object;
 
-  /* creating a toplevel or unattached attribute */
+  /* Creating an attribute for the given object, if it exists. */
   if (o_current) {
-    /* get coordinates of where to place the text object */
+    /* Get coordinates of where to place the text object and
+     * parameters of the new attribute. */
     switch (lepton_object_get_type (o_current)) {
       case(OBJ_COMPONENT):
         world_x = lepton_component_object_get_x (o_current);
@@ -339,6 +405,8 @@ o_attrib_add_attrib (GschemToplevel *w_current,
         }
         break;
 
+        /* We cannot attach an attribute to text, so create a
+         * toplevel attribute here. */
       case(OBJ_TEXT):
         world_x = lepton_text_object_get_x (o_current);
         world_y = lepton_text_object_get_y (o_current);
@@ -348,18 +416,58 @@ o_attrib_add_attrib (GschemToplevel *w_current,
         o_current = NULL;
         break;
     }
-  } else {
-    world_get_object_glist_bounds (lepton_page_objects (active_page),
-                                   /* Don't include hidden objects. */
-                                   FALSE,
-                                   &left,
-                                   &top,
-                                   &right,
-                                   &bottom);
+  }
+  else
+  {
+    /* Creating a toplevel (unattached, floating) attribute. */
 
-    /* this really is the lower left hand corner */
-    world_x = left;
-    world_y = top;
+    /* If any coordinate is proposed, set the attrib anchor to it.  */
+    if (proposed_coord)
+    {
+      world_x = x;
+      world_y = y;
+    }
+    else
+    {
+      /* Otherwise, try first to set the coordinate to the
+       * bottom-left corner of the visible objects. */
+      found =
+        world_get_object_glist_bounds (lepton_page_objects (active_page),
+                                       /* Don't include hidden objects. */
+                                       FALSE,
+                                       &left,
+                                       &top,
+                                       &right,
+                                       &bottom);
+      if (found)
+      {
+        world_x = left;
+        world_y = top;
+      }
+      else
+      {
+        /* No visible object was found on the canvas, and no coord
+         * is proposed.  Set the value to the center of the current
+         * page view. */
+        GschemPageView *view = gschem_toplevel_get_current_page_view (w_current);
+
+        if (view != NULL)
+        {
+          GschemPageGeometry *geometry = gschem_page_view_get_page_geometry (view);
+          world_x = (geometry->viewport_left + geometry->viewport_right) / 2;
+          world_y = (geometry->viewport_top + geometry->viewport_bottom) / 2;
+        }
+        else
+        {
+          /* Hmm, no page view found?  Ah, the function can be
+           * evaluated somewhere in Scheme code when no GUI is
+           * available.  The last resort.  Let's set the coord to
+           * a specific value. */
+          world_x = 0;
+          world_y = 0;
+        }
+      }
+    }
 
     /* printf("%d %d\n", world_x, world_y); */
     align = LOWER_LEFT;
@@ -385,6 +493,7 @@ o_attrib_add_attrib (GschemToplevel *w_current,
     o_attrib_attach (new_obj, o_current, FALSE);
   }
 
+  /* Select the attribute to enable its further processing. */
   o_selection_add (active_page->selection_list, new_obj);
 
   /* handle slot= attribute, it's a special case */
@@ -394,8 +503,8 @@ o_attrib_add_attrib (GschemToplevel *w_current,
   }
 
   /* Call add-objects-hook. */
-  g_run_hook_object (w_current, "%add-objects-hook", new_obj);
-  g_run_hook_object (w_current, "%select-objects-hook", new_obj);
+  g_run_hook_object (w_current, "add-objects-hook", new_obj);
+  g_run_hook_object (w_current, "select-objects-hook", new_obj);
 
   schematic_window_active_page_changed (w_current);
 
