@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -475,7 +475,7 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
   GList *prev_conn_objects;
   LeptonObject *new_net = NULL;
 
-  /* Save a list of added objects to run the %add-objects-hook later */
+  /* Save a list of added objects to run the add-objects-hook later */
   GList *added_objects = NULL;
 
   g_assert( w_current->inside_action != 0 );
@@ -575,7 +575,7 @@ void o_net_end(GschemToplevel *w_current, int w_x, int w_y)
 
   /* Call add-objects-hook */
   if (added_objects != NULL) {
-    g_run_hook_object_list (w_current, "%add-objects-hook", added_objects);
+    g_run_hook_object_list (w_current, "add-objects-hook", added_objects);
     g_list_free (added_objects);
   }
 
