@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -115,8 +115,8 @@ void o_picture_end(GschemToplevel *w_current, int w_x, int w_y)
                                          FALSE);
     lepton_page_append (active_page, new_obj);
 
-    /* Run %add-objects-hook */
-    g_run_hook_object (w_current, "%add-objects-hook", new_obj);
+    /* Run add-objects-hook */
+    g_run_hook_object (w_current, "add-objects-hook", new_obj);
 
     schematic_window_active_page_changed (w_current);
     o_undo_savestate_old(w_current, UNDO_ALL);
@@ -181,19 +181,21 @@ void picture_selection_dialog (GschemToplevel *w_current)
   GtkWidget* pfswindow = gtk_file_chooser_dialog_new (_("Add Picture"),
                                                       GTK_WINDOW(w_current->main_window),
                                                       GTK_FILE_CHOOSER_ACTION_OPEN,
-                                                      GTK_STOCK_CANCEL,
+                                                      _("_Cancel"),
                                                       GTK_RESPONSE_CANCEL,
-                                                      GTK_STOCK_OPEN,
+                                                      _("_Open"),
                                                       GTK_RESPONSE_ACCEPT,
                                                       NULL);
 
   setup_filechooser_filters (GTK_FILE_CHOOSER (pfswindow));
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(pfswindow),
                                           GTK_RESPONSE_ACCEPT,
                                           GTK_RESPONSE_CANCEL,
                                           -1);
+#endif
 
   if (w_current->pixbuf_filename)
     gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(pfswindow),
@@ -386,19 +388,21 @@ void picture_change_filename_dialog (GschemToplevel *w_current)
   GtkWidget* pfswindow = gtk_file_chooser_dialog_new (_("Select Picture"),
                                                       GTK_WINDOW(w_current->main_window),
                                                       GTK_FILE_CHOOSER_ACTION_OPEN,
-                                                      GTK_STOCK_CANCEL,
+                                                      _("_Cancel"),
                                                       GTK_RESPONSE_CANCEL,
-                                                      GTK_STOCK_OPEN,
+                                                      _("_Open"),
                                                       GTK_RESPONSE_ACCEPT,
                                                       NULL);
 
   setup_filechooser_filters (GTK_FILE_CHOOSER (pfswindow));
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(pfswindow),
                                           GTK_RESPONSE_ACCEPT,
                                           GTK_RESPONSE_CANCEL,
                                           -1);
+#endif
 
   if (w_current->pixbuf_filename)
     gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(pfswindow),
