@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -133,7 +133,7 @@ void o_slot_end(GschemToplevel *w_current, LeptonObject *object, const char *str
     o_attrib_attach (new_obj, object, FALSE);
 
     /* Call add-objects-hook */
-    g_run_hook_object (w_current, "%add-objects-hook", new_obj);
+    g_run_hook_object (w_current, "add-objects-hook", new_obj);
   }
 
   s_slot_update_object (object);
