@@ -175,10 +175,10 @@ o_undo_savestate (GschemToplevel *w_current,
     /* f_save manages the creaton of backup copies.
        This way, f_save is called only when saving a file, and not when
        saving an undo backup copy */
-    o_save (s_page_objects (page), filename, NULL);
+    o_save (lepton_page_objects (page), filename, NULL);
 
   } else if (w_current->undo_type == UNDO_MEMORY && flag == UNDO_ALL) {
-    object_list = o_glist_copy_all (s_page_objects (page),
+    object_list = o_glist_copy_all (lepton_page_objects (page),
                                     object_list);
   }
 
@@ -433,7 +433,7 @@ o_undo_callback (GschemToplevel *w_current,
   }
 
   /* save filename */
-  save_filename = g_strdup (s_page_get_filename (page));
+  save_filename = g_strdup (lepton_page_get_filename (page));
 
   /* save structure so it's not nuked */
   save_bottom = page->undo_bottom;
@@ -448,13 +448,13 @@ o_undo_callback (GschemToplevel *w_current,
   if ((w_current->undo_type == UNDO_DISK && u_current->filename) ||
       (w_current->undo_type == UNDO_MEMORY && u_current->object_list)) {
     /* delete objects of page */
-    s_page_delete_objects (page);
+    lepton_page_delete_objects (page);
 
     /* Free the objects in the place list. */
     lepton_object_list_delete (page->place_list);
     page->place_list = NULL;
 
-    gschem_toplevel_page_content_changed (w_current, page);
+    schematic_window_active_page_changed (w_current);
   }
 
   /* temporarily disable logging */
@@ -471,9 +471,9 @@ o_undo_callback (GschemToplevel *w_current,
 
   } else if (w_current->undo_type == UNDO_MEMORY && u_current->object_list) {
 
-    s_page_append_list (page,
-                        o_glist_copy_all (u_current->object_list,
-                                          NULL));
+    lepton_page_append_list (page,
+                             o_glist_copy_all (u_current->object_list,
+                                               NULL));
   }
 
   page->page_control = u_current->page_control;
@@ -502,7 +502,7 @@ o_undo_callback (GschemToplevel *w_current,
   do_logging = save_logging;
 
   /* set filename right */
-  s_page_set_filename (page, save_filename);
+  lepton_page_set_filename (page, save_filename);
   g_free(save_filename);
 
   /* final redraw */
