@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -109,9 +109,8 @@ void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
 
   attribptr =
     (LeptonObject*) g_object_get_data (G_OBJECT (w_current->aewindow), "attrib");
-  if (!attribptr) {
-    LeptonObject *new_object = NULL;
-
+  if (!attribptr)
+  {
     s_current = lepton_list_get_glist( toplevel->page_current->selection_list );
     while (s_current != NULL) {
       object = (LeptonObject *)s_current->data;
@@ -194,39 +193,59 @@ void attrib_edit_dialog_ok(GtkWidget * w, GschemToplevel *w_current)
               }
             }
             if (!replaced) {
-              o_attrib_add_attrib(w_current, newtext, vis, show, object);
+              o_attrib_add_attrib (w_current, newtext, vis, show, object, FALSE, 0, 0);
             }
           }
         }
         s_current = g_list_next (s_current);
       }
       o_undo_savestate_old(w_current, UNDO_ALL);
-    } else {
+    }
+    else
+    {
+      /* There is one or no selected object. */
       object = o_select_return_first_object(w_current);
-      new_object = o_attrib_add_attrib(w_current, newtext, vis, show, object);
 
-      invocation_flag =
-        GPOINTER_TO_INT (g_object_get_data (G_OBJECT (w_current->aewindow),
-                                            "invocation_flag"));
+      /* We should set reasonable defaults for the coordinate of
+       * the new attribute if it is floating, that is, no object
+       * to attach to is selected.  We can do it only if the mouse
+       * pointer is somewhere over the canvas.  For this, the
+       * three following conditions should be met: invocation_flag
+       * must be set to FROM_HOTKEY, and proposed x and y must not
+       * have the value of -1.  The former condition means the
+       * user did not use menus to invoke the dialog, and the
+       * latter two mean the mouse cursor was not out of the
+       * program window.  In any other case, let's rely on
+       * o_attrib_add_attrib() in choosing some reasonable
+       * strategy for this.*/
       wx =
         GPOINTER_TO_INT (g_object_get_data (G_OBJECT (w_current->aewindow),
                                             "position_wx"));
       wy =
         GPOINTER_TO_INT (g_object_get_data (G_OBJECT (w_current->aewindow),
                                             "position_wy"));
-
+      invocation_flag =
+        GPOINTER_TO_INT (g_object_get_data (G_OBJECT (w_current->aewindow),
+                                            "invocation_flag"));
 #if DEBUG
       printf("invocation flag: %d\n", invocation_flag);
 #endif
-      if (invocation_flag == FROM_HOTKEY
-          && wx != -1 && wy != -1) {
-        o_invalidate (w_current, new_object);
-        lepton_text_object_set_x (new_object, wx);
-        lepton_text_object_set_y (new_object, wy);
-        lepton_text_object_recreate (new_object);
-        schematic_window_active_page_changed (w_current);
-        o_undo_savestate_old(w_current, UNDO_ALL);
-      }
+      gboolean propose_coord = (object == NULL
+                                && invocation_flag == FROM_HOTKEY
+                                && wx != -1
+                                && wy != -1);
+
+      o_attrib_add_attrib (w_current,
+                           newtext,
+                           vis,
+                           show,
+                           object,
+                           propose_coord,
+                           wx,
+                           wy);
+
+      schematic_window_active_page_changed (w_current);
+      o_undo_savestate_old(w_current, UNDO_ALL);
     }
   } else {
     o_text_change(w_current, attribptr, newtext, vis, show);
@@ -273,7 +292,7 @@ void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int
 {
   LeptonToplevel *toplevel = gschem_toplevel_get_toplevel (w_current);
   GtkWidget *aewindow;
-  GtkWidget *vbox, *label, *alignment;
+  GtkWidget *vbox, *label;
   GtkWidget *show_options;
   GtkWidget *attrib_combo_box_entry;
   GtkWidget *attrib_combo_entry;
@@ -313,16 +332,16 @@ void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int
                                             GTK_WINDOW(w_current->main_window),
                                             GTK_DIALOG_MODAL,
                                             "singleattrib", w_current,
-                                            GTK_STOCK_CANCEL,
-                                            GTK_RESPONSE_REJECT,
-                                            GTK_STOCK_OK,
-                                            GTK_RESPONSE_APPLY,
+                                            _("_Cancel"), GTK_RESPONSE_REJECT,
+                                            _("_OK"), GTK_RESPONSE_APPLY,
                                             NULL);
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(aewindow),
                                           GTK_RESPONSE_APPLY,
                                           GTK_RESPONSE_REJECT,
                                           -1);
+#endif
 
   g_signal_connect (G_OBJECT (aewindow), "response",
                     G_CALLBACK (attribute_edit_dialog_response),
@@ -347,17 +366,17 @@ void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int
     gtk_window_set_title (GTK_WINDOW(aewindow), _("Add Attribute"));
   }
 
-  alignment = gtk_alignment_new(0,0,1,1);
-  gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0,
-                            DIALOG_INDENTATION, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), alignment, TRUE, TRUE, 0);
-
 #ifdef ENABLE_GTK3
   GtkWidget *grid = gtk_grid_new ();
   gtk_grid_set_row_spacing (GTK_GRID (grid), DIALOG_V_SPACING);
   gtk_grid_set_column_spacing (GTK_GRID (grid), DIALOG_H_SPACING);
-  gtk_container_add (GTK_CONTAINER (alignment), grid);
+  gtk_box_pack_start (GTK_BOX(vbox), grid, TRUE, TRUE, 0);
 #else
+  GtkWidget *alignment = gtk_alignment_new(0,0,1,1);
+  gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0,
+                            DIALOG_INDENTATION, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), alignment, TRUE, TRUE, 0);
+
   GtkWidget *table = gtk_table_new (3, 2, FALSE);
   gtk_table_set_row_spacings(GTK_TABLE(table), DIALOG_V_SPACING);
   gtk_table_set_col_spacings(GTK_TABLE(table), DIALOG_H_SPACING);
@@ -366,10 +385,12 @@ void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int
 
   /* Name selection */
   label = gtk_label_new_with_mnemonic (_("N_ame:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 #ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 #else
+  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
@@ -381,6 +402,7 @@ void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), attrib_combo_box_entry);
 
 #ifdef ENABLE_GTK3
+  gtk_widget_set_hexpand (GTK_WIDGET (attrib_combo_box_entry), TRUE);
   gtk_grid_attach (GTK_GRID (grid), attrib_combo_box_entry, 1, 0, 1, 1);
 #else
   gtk_table_attach (GTK_TABLE (table), attrib_combo_box_entry, 1, 2, 0, 1,
@@ -395,10 +417,12 @@ void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int
 
   /* Value entry */
   label = gtk_label_new_with_mnemonic (_("_Value:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 #ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 #else
+  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
@@ -463,20 +487,25 @@ void attrib_edit_dialog (GschemToplevel *w_current, LeptonObject *attr_obj, int
 
     label = gtk_label_new(_("<b>Attach Options</b>"));
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+#ifdef ENABLE_GTK3
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+    gtk_label_set_yalign (GTK_LABEL (label), 0.0);
+#else
     gtk_misc_set_alignment(GTK_MISC(label),0,0);
+#endif
     gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
-    alignment = gtk_alignment_new(0,0,1,1);
-    gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0,
-                              DIALOG_INDENTATION, 0);
-    gtk_box_pack_start(GTK_BOX(vbox), alignment, TRUE, TRUE, 0);
-
 #ifdef ENABLE_GTK3
     grid = gtk_grid_new ();
     gtk_grid_set_row_spacing (GTK_GRID (grid), DIALOG_V_SPACING);
     gtk_grid_set_column_spacing (GTK_GRID (grid), DIALOG_H_SPACING);
-    gtk_container_add (GTK_CONTAINER (alignment), grid);
+    gtk_box_pack_start(GTK_BOX(vbox), grid, TRUE, TRUE, 0);
 #else
+    alignment = gtk_alignment_new(0,0,1,1);
+    gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 0, 0,
+                              DIALOG_INDENTATION, 0);
+    gtk_box_pack_start(GTK_BOX(vbox), alignment, TRUE, TRUE, 0);
+
     table = gtk_table_new (2, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), DIALOG_V_SPACING);
     gtk_table_set_col_spacings(GTK_TABLE(table), DIALOG_H_SPACING);
