@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <string.h>
 #endif
 
+#include <liblepton/glib_compat.h>
 #include "gschem.h"
 #include <gdk/gdkkeysyms.h>
 
@@ -359,14 +360,16 @@ gint autonumber_match(AUTONUMBER_TEXT *autotext, LeptonObject *o_current, gint *
 
   /* we have six cases, 3 from focus multiplied by 2 selection cases */
   if ((autotext->root_page || autotext->scope_number == SCOPE_HIERARCHY)
-      && (o_current->selected
+      && (lepton_object_get_selected (o_current)
           || autotext->scope_number == SCOPE_HIERARCHY || autotext->scope_number == SCOPE_PAGE)
       && (!isnumbered || (autotext->scope_overwrite)))
     return AUTONUMBER_RENUMBER;
 
   if (isnumbered
       && !(autotext->scope_skip == SCOPE_SELECTED
-           && !(o_current->selected)  && autotext->root_page)) {
+           && !(lepton_object_get_selected (o_current))
+           && autotext->root_page))
+  {
     sscanf(&(str[len])," %d", number);
     return AUTONUMBER_RESPECT; /* numbered objects which we don't renumber */
   }
@@ -445,7 +448,7 @@ void autonumber_get_used(GschemToplevel *w_current, AUTONUMBER_TEXT *autotext)
                   /* insert all slots to the list, except of the current one */
                   for (i=1; i <= numslots; i++) {
                     if (i != slotnr) {
-                      slot = (AUTONUMBER_SLOT*) g_memdup (slot, sizeof (AUTONUMBER_SLOT));
+                      slot = (AUTONUMBER_SLOT*) g_memdup2 (slot, sizeof (AUTONUMBER_SLOT));
                       slot->slotnr = i;
                       autotext->free_slots = g_list_insert_sorted(autotext->free_slots,
                                                                   slot,
@@ -702,7 +705,9 @@ void autonumber_text_autonumber(AUTONUMBER_TEXT *autotext)
         {
           if (autotext->scope_number == SCOPE_HIERARCHY
               || autotext->scope_number == SCOPE_PAGE
-              || ((autotext->scope_number == SCOPE_SELECTED) && (o_current->selected))) {
+              || ((autotext->scope_number == SCOPE_SELECTED)
+                  && (lepton_object_get_selected (o_current))))
+          {
             const gchar *str = lepton_text_object_get_string (o_current);
             if (g_str_has_prefix (str, searchtext)) {
               /* the beginnig of the current text matches with the searchtext now */
@@ -1200,7 +1205,6 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
 {
   GtkWidget *autonumber_text;
   GtkWidget *vbox1;
-  GtkWidget *alignment1;
   GtkWidget *vbox3;
   GtkWidget *label4;
   GtkWidget *scope_text;
@@ -1210,7 +1214,6 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   GtkWidget *scope_skip;
   GtkWidget *scope_overwrite;
   GtkWidget *label1;
-  GtkWidget *alignment3;
   GtkWidget *vbox4;
   GtkWidget *label12;
   GtkWidget *label13;
@@ -1225,16 +1228,16 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
                                                    GTK_WINDOW(w_current->main_window),
                                                    (GtkDialogFlags) 0, /* not modal */
                                                    "autonumber", w_current,
-                                                   GTK_STOCK_CLOSE,
-                                                   GTK_RESPONSE_REJECT,
-                                                   GTK_STOCK_APPLY,
-                                                   GTK_RESPONSE_ACCEPT,
+                                                   _("_Close"), GTK_RESPONSE_REJECT,
+                                                   _("_Apply"), GTK_RESPONSE_ACCEPT,
                                                    NULL);
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(autonumber_text),
                                           GTK_RESPONSE_ACCEPT,
                                           GTK_RESPONSE_REJECT,
                                           -1);
+#endif
 
   gtk_window_set_position (GTK_WINDOW (autonumber_text), GTK_WIN_POS_MOUSE);
 
@@ -1246,31 +1249,41 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   /* scope section */
   label1 = gtk_label_new (_("<b>Scope</b>"));
   gtk_label_set_use_markup (GTK_LABEL (label1), TRUE);
+#ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label1), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label1), 0.0);
+#else
   gtk_misc_set_alignment (GTK_MISC(label1), 0, 0);
+#endif
   gtk_box_pack_start (GTK_BOX(vbox1), label1, TRUE, TRUE, 0);
   gtk_widget_show (label1);
 
-  alignment1 = gtk_alignment_new (0, 0, 1, 1);
+#ifdef ENABLE_GTK3
+  vbox3 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
+  GtkWidget *alignment1 = gtk_alignment_new (0, 0, 1, 1);
   gtk_widget_show (alignment1);
   gtk_box_pack_start (GTK_BOX (vbox1), alignment1, TRUE, TRUE, 0);
   gtk_alignment_set_padding (GTK_ALIGNMENT (alignment1),
                              0, 0, DIALOG_INDENTATION, 0);
 
-#ifdef ENABLE_GTK3
-  vbox3 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
   vbox3 = gtk_vbox_new (FALSE, 0);
 #endif
   gtk_widget_show (vbox3);
-  gtk_container_add (GTK_CONTAINER (alignment1), vbox3);
 
 #ifdef ENABLE_GTK3
+  gtk_box_pack_start (GTK_BOX (vbox1), vbox3, TRUE, TRUE, 0);
+
   GtkWidget* grid1 = gtk_grid_new ();
   gtk_widget_show (grid1);
   gtk_box_pack_start (GTK_BOX (vbox3), grid1, TRUE, TRUE, 0);
   gtk_grid_set_row_spacing (GTK_GRID (grid1), DIALOG_V_SPACING);
   gtk_grid_set_column_spacing (GTK_GRID (grid1), DIALOG_H_SPACING);
-#else
+
+#else /* GTK2 */
+
+  gtk_container_add (GTK_CONTAINER (alignment1), vbox3);
+
   GtkWidget *table1 = gtk_table_new (3, 2, FALSE);
   gtk_widget_show (table1);
   gtk_box_pack_start (GTK_BOX (vbox3), table1, TRUE, TRUE, 0);
@@ -1282,17 +1295,20 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   gtk_widget_show (label4);
 #ifdef ENABLE_GTK3
   gtk_grid_attach (GTK_GRID (grid1), label4, 0, 0, 1, 1);
+  gtk_label_set_xalign (GTK_LABEL (label4), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label4), 0.5);
 #else
   gtk_table_attach (GTK_TABLE (table1), label4, 0, 1, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-#endif
   gtk_misc_set_alignment (GTK_MISC (label4), 0, 0.5);
+#endif
 
   scope_text = gtk_combo_box_text_new_with_entry ();
   gtk_entry_set_activates_default(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(scope_text))), TRUE);
   gtk_widget_show (scope_text);
 #ifdef ENABLE_GTK3
+  gtk_widget_set_hexpand (GTK_WIDGET (scope_text), TRUE);
   gtk_grid_attach (GTK_GRID (grid1), scope_text, 1, 0, 1, 1);
 #else
   gtk_table_attach (GTK_TABLE (table1), scope_text, 1, 2, 0, 1,
@@ -1304,23 +1320,27 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   gtk_widget_show (label8);
 #ifdef ENABLE_GTK3
   gtk_grid_attach (GTK_GRID (grid1), label8, 0, 1, 1, 1);
+  gtk_label_set_xalign (GTK_LABEL (label8), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label8), 0.5);
 #else
   gtk_table_attach (GTK_TABLE (table1), label8, 0, 1, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-#endif
   gtk_misc_set_alignment (GTK_MISC (label8), 0, 0.5);
+#endif
 
   label6 = gtk_label_new (_("Skip numbers found in:"));
   gtk_widget_show (label6);
 #ifdef ENABLE_GTK3
   gtk_grid_attach (GTK_GRID (grid1), label6, 0, 2, 1, 1);
+  gtk_label_set_xalign (GTK_LABEL (label6), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label6), 0.5);
 #else
   gtk_table_attach (GTK_TABLE (table1), label6, 0, 1, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-#endif
   gtk_misc_set_alignment (GTK_MISC (label6), 0, 0.5);
+#endif
 
   scope_number = gtk_combo_box_text_new ();
   gtk_widget_show (scope_number);
@@ -1355,31 +1375,41 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   /* Options section */
   label3 = gtk_label_new (_("<b>Options</b>"));
   gtk_label_set_use_markup (GTK_LABEL (label3), TRUE);
+#ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label3), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label3), 0.0);
+#else
   gtk_misc_set_alignment(GTK_MISC(label3), 0, 0);
+#endif
   gtk_widget_show (label3);
   gtk_box_pack_start(GTK_BOX(vbox1), label3, TRUE, TRUE, 0);
 
-  alignment3 = gtk_alignment_new (0, 0, 1, 1);
+#ifdef ENABLE_GTK3
+  vbox4 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
+#else
+  GtkWidget *alignment3 = gtk_alignment_new (0, 0, 1, 1);
   gtk_widget_show (alignment3);
   gtk_box_pack_start(GTK_BOX(vbox1), alignment3, TRUE, TRUE, 0);
   gtk_alignment_set_padding (GTK_ALIGNMENT (alignment3),
                              0, 0, DIALOG_INDENTATION, 0);
 
-#ifdef ENABLE_GTK3
-  vbox4 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
-#else
   vbox4 = gtk_vbox_new (FALSE, 3);
 #endif
   gtk_widget_show (vbox4);
-  gtk_container_add (GTK_CONTAINER (alignment3), vbox4);
 
 #ifdef ENABLE_GTK3
+  gtk_box_pack_start(GTK_BOX(vbox1), vbox4, TRUE, TRUE, 0);
+
   GtkWidget *grid3 = gtk_grid_new ();
   gtk_widget_show (grid3);
   gtk_box_pack_start (GTK_BOX (vbox4), grid3, TRUE, TRUE, 0);
   gtk_grid_set_row_spacing (GTK_GRID (grid3), DIALOG_V_SPACING);
   gtk_grid_set_column_spacing (GTK_GRID (grid3), DIALOG_H_SPACING);
-#else
+
+#else /* GTK2 */
+
+  gtk_container_add (GTK_CONTAINER (alignment3), vbox4);
+
   GtkWidget *table3 = gtk_table_new (2, 2, FALSE);
   gtk_widget_show (table3);
   gtk_box_pack_start (GTK_BOX (vbox4), table3, TRUE, TRUE, 0);
@@ -1391,23 +1421,27 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   gtk_widget_show (label12);
 #ifdef ENABLE_GTK3
   gtk_grid_attach (GTK_GRID (grid3), label12, 0, 0, 1, 1);
+  gtk_label_set_xalign (GTK_LABEL (label12), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label12), 0.5);
 #else
   gtk_table_attach (GTK_TABLE (table3), label12, 0, 1, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-#endif
   gtk_misc_set_alignment (GTK_MISC (label12), 0, 0.5);
+#endif
 
   label13 = gtk_label_new (_("Sort order:"));
   gtk_widget_show (label13);
 #ifdef ENABLE_GTK3
   gtk_grid_attach (GTK_GRID (grid3), label13, 0, 1, 1, 1);
+  gtk_label_set_xalign (GTK_LABEL (label13), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label13), 0.5);
 #else
   gtk_table_attach (GTK_TABLE (table3), label13, 0, 1, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-#endif
   gtk_misc_set_alignment (GTK_MISC (label13), 0, 0.5);
+#endif
 
 
   /* this sets the page size to 10 (step * 10).
@@ -1425,6 +1459,7 @@ GtkWidget* autonumber_create_dialog(GschemToplevel *w_current)
   gtk_entry_set_activates_default(GTK_ENTRY(opt_startnum), TRUE);
   gtk_widget_show (opt_startnum);
 #ifdef ENABLE_GTK3
+  gtk_widget_set_hexpand (GTK_WIDGET (opt_startnum), TRUE);
   gtk_grid_attach (GTK_GRID (grid3), opt_startnum, 1, 0, 1, 1);
 #else
   gtk_table_attach (GTK_TABLE (table3), opt_startnum, 1, 2, 0, 1,
