@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,6 +39,22 @@ x_color_init()
 
 
 
+#ifdef ENABLE_GTK3
+/*! \brief Get a display color map color for specified \a color_id
+ *  as GdkRGBA.
+ *
+ *  \note Caller must gdk_rgba_free() the returned value.
+ */
+GdkRGBA*
+x_color_lookup_gdk_rgba (size_t color_id)
+{
+  LeptonColor *color = x_color_lookup (color_id);
+
+  return gdk_rgba_copy ((GdkRGBA *) color);
+}
+
+#else /* GTK2 */
+
 /*! \brief Get a display color map color for specified \a color_id as GdkColor.
  *
  *  \note Caller must gdk_color_free() the returned value.
@@ -51,12 +67,13 @@ x_color_lookup_gdk (size_t color_id)
   /* Extrapolate 8-bpp color into 16-bpp GDK color:
   */
   GdkColor color_gdk;
-  color_gdk.red   = color->r + (color->r << 8);
-  color_gdk.green = color->g + (color->g << 8);
-  color_gdk.blue  = color->b + (color->b << 8);
+  color_gdk.red   = (guint16) (color->red   * 65535);
+  color_gdk.green = (guint16) (color->green * 65535);
+  color_gdk.blue  = (guint16) (color->blue  * 65535);
 
   return gdk_color_copy (&color_gdk);
 }
+#endif
 
 
 
@@ -79,19 +96,48 @@ x_color_lookup (size_t color_id)
 gboolean
 x_color_display_enabled (size_t color_id)
 {
-  return display_colors[ color_id ].enabled;
+  return lepton_color_enabled (&display_colors [color_id]);
+}
+
+#ifdef ENABLE_GTK3
+/*! \brief: Set new color value for a color with given index in
+ *  the display color map.
+ */
+void
+x_color_set_display_color (size_t color_id,
+                           GdkRGBA* color)
+{
+  display_colors[color_id].red = color->red;
+  display_colors[color_id].green = color->green;
+  display_colors[color_id].blue = color->blue;
+  display_colors[color_id].alpha = color->alpha;
 }
 
 
+/*! \brief: Set new color value for a color with given index in
+ *  the display color map.
+ */
+void
+x_color_set_outline_color (size_t color_id,
+                           GdkRGBA* color)
+{
+  display_outline_colors[color_id].red = color->red;
+  display_outline_colors[color_id].green = color->green;
+  display_outline_colors[color_id].blue = color->blue;
+  display_outline_colors[color_id].alpha = color->alpha;
+}
+
+#else /* GTK2 */
 
 /*! \brief: Change a color in the display color map
  */
 void
-x_color_set_display (size_t color_id, GdkColor* color)
+x_color_set_display (size_t color_id, GdkColor* color, guint16 alpha)
 {
-  display_colors[ color_id ].r = color->red   >> 8;
-  display_colors[ color_id ].g = color->green >> 8;
-  display_colors[ color_id ].b = color->blue  >> 8;
+  display_colors[color_id].red   = (gdouble) color->red   / 65535.0;
+  display_colors[color_id].green = (gdouble) color->green / 65535.0;
+  display_colors[color_id].blue  = (gdouble) color->blue  / 65535.0;
+  display_colors[color_id].alpha = (gdouble) alpha        / 65535.0;
 }
 
 
@@ -99,12 +145,14 @@ x_color_set_display (size_t color_id, GdkColor* color)
 /*! \brief: Change a color in the outline color map
  */
 void
-x_color_set_outline (size_t color_id, GdkColor* color)
+x_color_set_outline (size_t color_id, GdkColor* color, guint16 alpha)
 {
-  display_outline_colors[ color_id ].r = color->red   >> 8;
-  display_outline_colors[ color_id ].g = color->green >> 8;
-  display_outline_colors[ color_id ].b = color->blue  >> 8;
+  display_outline_colors[color_id].red   = (gdouble) color->red   / 65535.0;
+  display_outline_colors[color_id].green = (gdouble) color->green / 65535.0;
+  display_outline_colors[color_id].blue  = (gdouble) color->blue  / 65535.0;
+  display_outline_colors[color_id].alpha = (gdouble) alpha        / 65535.0;
 }
+#endif
 
 
 
@@ -126,22 +174,29 @@ x_color_map2str (LeptonColorMap cmap)
 
     const gchar* scm_str = color_get_name (color_index);
 
-    if (color.enabled)
+    if (lepton_color_enabled (&color))
     {
-      guint8 r = color.r;
-      guint8 g = color.g;
-      guint8 b = color.b;
+      guint8 r = (guint8) (color.red * 255);
+      guint8 g = (guint8) (color.green * 255);
+      guint8 b = (guint8) (color.blue * 255);
+      guint8 a = (guint8) (color.alpha * 255);
 
       /* the line will look like:
-       * (background "#AABBCC")
+       * (background "#RRGGBBAA")
+       * or
+       * (background "#RRGGBB")
       */
-      g_string_append_printf (str, "  (%-20s \"#%.2x%.2x%.2x\")",
-                             scm_str,
-                             r, g, b);
-    }
-    else
-    {
-      g_string_append_printf (str, "  (%-20s #f)", scm_str);
+      if (color.alpha != 1.0) {
+        g_string_append_printf (str, "  (%-20s \"#%.2x%.2x%.2x%.2x\")",
+                                scm_str,
+                                r, g, b, a);
+      }
+      else
+      {
+        g_string_append_printf (str, "  (%-20s \"#%.2x%.2x%.2x\")",
+                                scm_str,
+                                r, g, b);
+      }
     }
 
     g_string_append (str, "\n");
