@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1033,8 +1033,8 @@ create_inuse_treeview (Compselect *compselect)
                                      "relief",    GTK_RELIEF_NONE,
                                      NULL));
   gtk_container_add (GTK_CONTAINER (button),
-                     gtk_image_new_from_stock (GTK_STOCK_REFRESH,
-                                            GTK_ICON_SIZE_SMALL_TOOLBAR));
+                     gtk_image_new_from_icon_name ("view-refresh",
+                                                   GTK_ICON_SIZE_SMALL_TOOLBAR));
   /* add the refresh button to the horizontal box at the end */
   gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
   g_signal_connect (button,
@@ -1155,7 +1155,12 @@ create_lib_treeview (Compselect *compselect)
 
   /* create the entry label */
   label = gtk_label_new_with_mnemonic (_("_Filter:"));
+#ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
 
   /* add the search label to the filter area */
   gtk_box_pack_start (GTK_BOX (hbox), label,
@@ -1196,8 +1201,8 @@ create_lib_treeview (Compselect *compselect)
                                      NULL));
 
   gtk_container_add (GTK_CONTAINER (button),
-                     gtk_image_new_from_stock (GTK_STOCK_CLEAR,
-                                               GTK_ICON_SIZE_SMALL_TOOLBAR));
+                     gtk_image_new_from_icon_name ("edit-clear",
+                                                   GTK_ICON_SIZE_SMALL_TOOLBAR));
 
   gtk_widget_set_tooltip_text (button, _("Reset filter"));
 
@@ -1220,8 +1225,8 @@ create_lib_treeview (Compselect *compselect)
                                      "relief",    GTK_RELIEF_NONE,
                                      NULL));
   gtk_container_add (GTK_CONTAINER (button),
-                     gtk_image_new_from_stock (GTK_STOCK_REFRESH,
-                                            GTK_ICON_SIZE_SMALL_TOOLBAR));
+                     gtk_image_new_from_icon_name ("view-refresh",
+                                                   GTK_ICON_SIZE_SMALL_TOOLBAR));
   gtk_widget_set_tooltip_text (button, _("Reload all libraries"));
 
   /* add the refresh button to the filter area */
@@ -1468,7 +1473,7 @@ compselect_constructor (GType type,
   GtkWidget *hpaned, *vpaned, *notebook, *attributes;
   GtkWidget *libview, *inuseview;
   GtkWidget *preview, *combobox;
-  GtkWidget *alignment, *frame;
+  GtkWidget *frame;
 
   /* chain up to constructor of parent class */
   object = G_OBJECT_CLASS (compselect_parent_class)->
@@ -1525,6 +1530,8 @@ compselect_constructor (GType type,
                                     /* GtkFrame */
                                     "label", _("Preview"),
                                     NULL));
+#ifndef ENABLE_GTK3
+  GtkWidget *alignment;
   alignment = GTK_WIDGET (g_object_new (GTK_TYPE_ALIGNMENT,
                                         /* GtkAlignment */
                                         "border-width", 5,
@@ -1533,11 +1540,17 @@ compselect_constructor (GType type,
                                         "xalign",         0.5,
                                         "yalign",         0.5,
                                         NULL));
+#endif
 
   preview = gschem_preview_new ();
 
+#ifdef ENABLE_GTK3
+  gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
+  gtk_container_add (GTK_CONTAINER (frame), preview);
+#else
   gtk_container_add (GTK_CONTAINER (alignment), preview);
   gtk_container_add (GTK_CONTAINER (frame), alignment);
+#endif
   /* set preview of compselect */
   compselect->preview = GSCHEM_PREVIEW (preview);
   g_object_set (GTK_WIDGET (preview),
@@ -1578,15 +1591,17 @@ compselect_constructor (GType type,
   /* now add buttons in the action area */
   gtk_dialog_add_buttons (GTK_DIALOG (compselect),
                           /*  - close button */
-                          GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-                          GTK_STOCK_OK, COMPSELECT_RESPONSE_HIDE,
+                          _("_Close"), GTK_RESPONSE_CLOSE,
+                          _("_OK"), COMPSELECT_RESPONSE_HIDE,
                           NULL);
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order (GTK_DIALOG (compselect),
                                           COMPSELECT_RESPONSE_HIDE,
                                           GTK_RESPONSE_CLOSE,
                                           -1);
+#endif
 
   /* Initialize the hidden property */
   compselect->hidden = FALSE;
