@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -143,11 +143,11 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
       if (page->place_list != NULL) {
         switch(w_current->event_state) {
           case (COMPMODE)   : o_place_end(w_current, w_x, w_y, w_current->continue_component_place,
-                                "%add-objects-hook"); break;
+                                "add-objects-hook"); break;
           case (TEXTMODE)   : o_place_end(w_current, w_x, w_y, FALSE,
-                                "%add-objects-hook"); break;
+                                "add-objects-hook"); break;
           case (PASTEMODE)  : o_place_end(w_current, w_x, w_y, FALSE,
-                                "%paste-objects-hook"); break;
+                                "paste-objects-hook"); break;
           default: break;
         }
       } else {
@@ -652,10 +652,11 @@ gint x_event_enter(GtkWidget *widget, GdkEventCrossing *event,
  * \param      w_current  the toplevel environment
  * \returns TRUE if the event has been handled.
  */
-gboolean
-x_event_key (GschemPageView *page_view, GdkEventKey *event, GschemToplevel *w_current)
+GdkEventKey*
+x_event_key (GschemPageView *page_view,
+             GdkEventKey *event,
+             GschemToplevel *w_current)
 {
-  gboolean retval = FALSE;
   int pressed;
   gboolean special = FALSE;
 
@@ -691,21 +692,13 @@ x_event_key (GschemPageView *page_view, GdkEventKey *event, GschemToplevel *w_cu
       break;
   }
 
-  scm_dynwind_begin ((scm_t_dynwind_flags) 0);
-  g_dynwind_window (w_current);
-
   /* Special case to update the object being drawn or placed after
    * scrolling when Shift or Control were pressed */
   if (special) {
     x_event_faked_motion (page_view, event);
   }
 
-  if (pressed)
-    retval = g_keys_execute (w_current, event) ? TRUE : FALSE;
-
-  scm_dynwind_end ();
-
-  return retval;
+  return pressed ? event : NULL;
 }
 
 
