@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -206,6 +206,8 @@ on_filter_changed (GtkFileChooserDialog* dialog, gpointer data)
     bname = basename_switch_suffix (fname, "sym");
   }
 
+  g_free (fname);
+
   if (bname != NULL)
   {
     gtk_file_chooser_set_current_name (chooser, bname);
@@ -273,11 +275,13 @@ x_fileselect_callback_update_preview (GtkFileChooser *chooser,
 static void
 x_fileselect_add_preview (GtkFileChooser *filechooser)
 {
-  GtkWidget *alignment, *frame, *preview;
+  GtkWidget *frame, *preview;
 
   frame = GTK_WIDGET (g_object_new (GTK_TYPE_FRAME,
                                     "label", _("Preview"),
                                     NULL));
+#ifndef ENABLE_GTK3
+  GtkWidget *alignment;
   alignment = GTK_WIDGET (g_object_new (GTK_TYPE_ALIGNMENT,
                                         "right-padding", 5,
                                         "left-padding", 5,
@@ -286,11 +290,16 @@ x_fileselect_add_preview (GtkFileChooser *filechooser)
                                         "xalign", 0.5,
                                         "yalign", 0.5,
                                         NULL));
+#endif
 
   preview = gschem_preview_new ();
 
+#ifdef ENABLE_GTK3
+  gtk_container_add (GTK_CONTAINER (frame), preview);
+#else
   gtk_container_add (GTK_CONTAINER (alignment), preview);
   gtk_container_add (GTK_CONTAINER (frame), alignment);
+#endif
   gtk_widget_show_all (frame);
 
   g_object_set (filechooser,
@@ -329,15 +338,17 @@ x_fileselect_open(GschemToplevel *w_current)
   dialog = gtk_file_chooser_dialog_new (_("Open"),
                                         GTK_WINDOW(w_current->main_window),
                                         GTK_FILE_CHOOSER_ACTION_OPEN,
-                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                        GTK_STOCK_OPEN,   GTK_RESPONSE_ACCEPT,
+                                        _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                        _("_Open"), GTK_RESPONSE_ACCEPT,
                                         NULL);
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
                                           GTK_RESPONSE_ACCEPT,
                                           GTK_RESPONSE_CANCEL,
                                           -1);
+#endif
 
   if (w_current->file_preview)
   {
@@ -420,16 +431,18 @@ x_fileselect_save (GschemToplevel *w_current,
     _("Save As"),
     GTK_WINDOW(w_current->main_window),
     GTK_FILE_CHOOSER_ACTION_SAVE,
-    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-    GTK_STOCK_SAVE,   GTK_RESPONSE_ACCEPT,
+    _("_Cancel"), GTK_RESPONSE_CANCEL,
+    _("_Save"),   GTK_RESPONSE_ACCEPT,
     NULL);
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems:
   */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
                                           GTK_RESPONSE_ACCEPT,
                                           GTK_RESPONSE_CANCEL,
                                           -1);
+#endif
 
   /* set default response signal. This is usually triggered by the
    * "Return" key:
@@ -589,11 +602,13 @@ x_fileselect_load_backup (GschemToplevel *w_current,
                                    "%s", message->str);
 
   gtk_window_set_title (GTK_WINDOW (dialog), "Load Backup");
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
                                           GTK_RESPONSE_YES,
                                           GTK_RESPONSE_NO,
                                           -1);
+#endif
 
   gtk_widget_show (dialog);
   if (gtk_dialog_run ((GtkDialog*)dialog) == GTK_RESPONSE_YES) {
