@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -296,6 +296,7 @@ x_image_update_dialog_filename (GtkComboBoxText *combo,
   char *file_name = NULL ;
   char *new_image_filename = NULL;
   GtkWidget *file_chooser;
+  gchar *file_chooser_filename = NULL;
 
   /* Get the current image type */
   image_type_descr =
@@ -307,11 +308,17 @@ x_image_update_dialog_filename (GtkComboBoxText *combo,
       GTK_TYPE_FILE_CHOOSER);
 
   /* Get the previous file name. If none, revert to the page filename */
-  old_image_filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser));
-  if (!old_image_filename) {
+
+  file_chooser_filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_chooser));
+  if (!file_chooser_filename) {
     LeptonPage *active_page = schematic_window_get_active_page (w_current);
     old_image_filename = lepton_page_get_filename (active_page);
   }
+  else
+  {
+    old_image_filename = g_strdup (file_chooser_filename);
+    g_free (file_chooser_filename);
+  }
 
   /* Get the file name, without extension */
   if (old_image_filename) {
@@ -510,8 +517,17 @@ void x_image_setup (GschemToplevel *w_current)
 #endif
   label1 = gtk_label_new (_("Width x Height"));
   gtk_widget_show (label1);
+#ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label1), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label1), 0.0);
+  gtk_widget_set_margin_start (label1, 0);
+  gtk_widget_set_margin_end (label1, 0);
+  gtk_widget_set_margin_top (label1, 0);
+  gtk_widget_set_margin_bottom (label1, 0);
+#else
   gtk_misc_set_alignment( GTK_MISC (label1), 0, 0);
   gtk_misc_set_padding (GTK_MISC (label1), 0, 0);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox1),
       label1, FALSE, FALSE, 0);
 
@@ -530,8 +546,17 @@ void x_image_setup (GschemToplevel *w_current)
 #endif
   label2 = gtk_label_new (_("Image type"));
   gtk_widget_show (label2);
+#ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label2), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label2), 0.0);
+  gtk_widget_set_margin_start (label2, 0);
+  gtk_widget_set_margin_end (label2, 0);
+  gtk_widget_set_margin_top (label2, 0);
+  gtk_widget_set_margin_bottom (label2, 0);
+#else
   gtk_misc_set_alignment( GTK_MISC (label2), 0, 0);
   gtk_misc_set_padding (GTK_MISC (label2), 0, 0);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox2),
       label2, FALSE, FALSE, 0);
 
@@ -548,8 +573,17 @@ void x_image_setup (GschemToplevel *w_current)
   GtkWidget* vbox3 = gtk_vbox_new (TRUE, 0);
 #endif
   GtkWidget* label3 = gtk_label_new (_("Color mode"));
+#ifdef ENABLE_GTK3
+  gtk_label_set_xalign (GTK_LABEL (label3), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label3), 0.0);
+  gtk_widget_set_margin_start (label3, 0);
+  gtk_widget_set_margin_end (label3, 0);
+  gtk_widget_set_margin_top (label3, 0);
+  gtk_widget_set_margin_bottom (label3, 0);
+#else
   gtk_misc_set_alignment (GTK_MISC (label3), 0, 0);
   gtk_misc_set_padding (GTK_MISC (label3), 0, 0);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox3), label3, FALSE, FALSE, 0);
 
   GtkWidget* color_combo = gtk_combo_box_text_new();
@@ -572,17 +606,19 @@ void x_image_setup (GschemToplevel *w_current)
 
   /* Create the dialog */
   dialog = gtk_file_chooser_dialog_new (_("Write Image"),
-      GTK_WINDOW(w_current->main_window),
-      GTK_FILE_CHOOSER_ACTION_SAVE,
-      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-      GTK_STOCK_SAVE,   GTK_RESPONSE_ACCEPT,
+                                        GTK_WINDOW(w_current->main_window),
+                                        GTK_FILE_CHOOSER_ACTION_SAVE,
+                                        _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                        _("_Save"), GTK_RESPONSE_ACCEPT,
       NULL);
 
+#ifndef ENABLE_GTK3
   /* Set the alternative button order (ok, cancel, help) for other systems */
   gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
       GTK_RESPONSE_ACCEPT,
       GTK_RESPONSE_CANCEL,
       -1);
+#endif
 
   /* Add the extra widgets to the dialog*/
   gtk_box_pack_start(GTK_BOX(hbox), vbox1, FALSE, FALSE, 10);
@@ -800,6 +836,14 @@ GdkPixbuf
                 "color-map", render_color_map,
                 NULL);
 
+  EdaConfig *cfg = eda_config_get_context_for_path (".");
+  gchar *fontstr = eda_config_get_string (cfg, "schematic.gui", "font", NULL);
+
+  if (fontstr != NULL) {
+    g_object_set (renderer, "font-name", fontstr, NULL);
+    g_free (fontstr);
+  }
+
   /* Paint background */
   LeptonColor *color = x_color_lookup (BACKGROUND_COLOR);
 
