@@ -1,6 +1,6 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 2018 dmn <graahnul.grom@gmail.com>
- * Copyright (C) 2018-2021 Lepton EDA Contributors
+ * Copyright (C) 2018-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -278,8 +278,19 @@ x_tabs_menu_create_item (GschemToplevel* toplevel,
                          const gchar*    icon_name);
 static void
 x_tabs_menu_create_item_separ (GtkWidget* menu);
+
+#ifdef ENABLE_GTK3
+static void
+x_tabs_menu_item_on_activate (GSimpleAction* action,
+                              GVariant *parameter,
+                              gpointer data);
+static void
+x_tabs_menu_item_on_activate_action (GtkMenuItem *item,
+                                     gpointer data);
+#else /* GTK2 */
 static void
 x_tabs_menu_item_on_activate (GtkAction* action, gpointer data);
+#endif
 
 
 
@@ -911,8 +922,8 @@ x_tabs_hdr_create (TabInfo* nfo)
   );
 #endif
 
-  GtkWidget* img_close = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-                                                   GTK_ICON_SIZE_MENU);
+  GtkWidget* img_close = gtk_image_new_from_icon_name ("window-close",
+                                                       GTK_ICON_SIZE_MENU);
   gtk_container_add (GTK_CONTAINER (btn_close), img_close);
   gtk_widget_set_tooltip_text (btn_close, _("Close"));
 
@@ -924,8 +935,8 @@ x_tabs_hdr_create (TabInfo* nfo)
   gtk_button_set_relief (GTK_BUTTON (btn_up), GTK_RELIEF_NONE);
   gtk_button_set_focus_on_click (GTK_BUTTON (btn_up), FALSE);
 
-  GtkWidget* img_up = gtk_image_new_from_stock (GTK_STOCK_GO_UP,
-                                                GTK_ICON_SIZE_MENU);
+  GtkWidget* img_up = gtk_image_new_from_icon_name ("go-up",
+                                                    GTK_ICON_SIZE_MENU);
   gtk_container_add (GTK_CONTAINER (btn_up), img_up);
 
 
@@ -936,8 +947,8 @@ x_tabs_hdr_create (TabInfo* nfo)
   gtk_button_set_relief (GTK_BUTTON (btn_save), GTK_RELIEF_NONE);
   gtk_button_set_focus_on_click (GTK_BUTTON (btn_save), FALSE);
 
-  GtkWidget* img_save = gtk_image_new_from_stock (GTK_STOCK_SAVE,
-                                                  GTK_ICON_SIZE_MENU);
+  GtkWidget* img_save = gtk_image_new_from_icon_name ("document-save",
+                                                      GTK_ICON_SIZE_MENU);
   gtk_container_add (GTK_CONTAINER (btn_save), img_save);
   gtk_widget_set_tooltip_text (btn_save, _("Save"));
 
@@ -1169,7 +1180,7 @@ x_tabs_cancel_all (GschemToplevel* w_current)
 
   i_set_state (w_current, SELECT);
 
-  g_keys_reset (w_current);
+  schematic_keys_reset (w_current);
 
   GschemPageView* pview = gschem_toplevel_get_current_page_view (w_current);
   gschem_page_view_invalidate_all (pview);
@@ -1668,15 +1679,15 @@ x_tabs_menu_create (TabInfo* nfo)
   g_return_val_if_fail (tl != NULL, NULL);
 
   GtkWidget* menu = gtk_menu_new();
-  x_tabs_menu_create_item (tl, menu, "&file-new", _("_New"), GTK_STOCK_NEW);
-  x_tabs_menu_create_item (tl, menu, "&file-open", _("_Open..."), GTK_STOCK_OPEN);
+  x_tabs_menu_create_item (tl, menu, "&file-new", _("_New"), "document-new");
+  x_tabs_menu_create_item (tl, menu, "&file-open", _("_Open..."), "document-open");
   x_tabs_menu_create_item_separ (menu);
-  x_tabs_menu_create_item (tl, menu, "&file-save", _("_Save"), GTK_STOCK_SAVE);
-  x_tabs_menu_create_item (tl, menu, "&file-save-as", _("Save _As..."), GTK_STOCK_SAVE_AS);
+  x_tabs_menu_create_item (tl, menu, "&file-save", _("_Save"), "document-save");
+  x_tabs_menu_create_item (tl, menu, "&file-save-as", _("Save _As..."), "document-save-as");
   x_tabs_menu_create_item_separ (menu);
   x_tabs_menu_create_item (tl, menu, "&page-manager", _("Page _Manager..."), NULL);
   x_tabs_menu_create_item_separ (menu);
-  x_tabs_menu_create_item (tl, menu, "&page-close", _("_Close"), GTK_STOCK_CLOSE);
+  x_tabs_menu_create_item (tl, menu, "&page-close", _("_Close"), "window-close");
 
   gtk_widget_show_all (menu);
   return GTK_MENU (menu);
@@ -1715,8 +1726,12 @@ x_tabs_hdr_on_mouse_click (GtkWidget* hdr, GdkEvent* e, gpointer data)
     GtkMenu* menu = x_tabs_menu_create (nfo);
     gtk_menu_attach_to_widget (menu, hdr, NULL);
 
+#ifdef ENABLE_GTK3
+    gtk_menu_popup_at_pointer (menu, e);
+#else
     int etime = gtk_get_current_event_time();
     gtk_menu_popup (menu, NULL, NULL, NULL, NULL, ebtn->button, etime);
+#endif
 
     return TRUE;
   }
@@ -1729,6 +1744,27 @@ x_tabs_hdr_on_mouse_click (GtkWidget* hdr, GdkEvent* e, gpointer data)
 
 /*! \brief "activate" signal handler for context menu item action.
  */
+#ifdef ENABLE_GTK3
+static void
+x_tabs_menu_item_on_activate (GSimpleAction* action,
+                              GVariant *parameter,
+                              gpointer data)
+{
+  GschemToplevel* toplevel    = (GschemToplevel*) data;
+  const gchar*    action_name = g_action_get_name (G_ACTION (action));
+
+  g_action_eval_by_name (toplevel, action_name);
+}
+
+static void
+x_tabs_menu_item_on_activate_action (GtkMenuItem *item,
+                                     gpointer data)
+{
+  g_signal_emit_by_name (G_ACTION (data), "activate");
+}
+
+#else /* GTK2 */
+
 static void
 x_tabs_menu_item_on_activate (GtkAction* action, gpointer data)
 {
@@ -1737,6 +1773,7 @@ x_tabs_menu_item_on_activate (GtkAction* action, gpointer data)
 
   g_action_eval_by_name (toplevel, action_name);
 }
+#endif
 
 
 
@@ -1760,6 +1797,17 @@ x_tabs_menu_create_item (GschemToplevel* toplevel,
                          const gchar*    action_label,
                          const gchar*    icon_name)
 {
+#ifdef ENABLE_GTK3
+  GSimpleAction* action = g_simple_action_new (action_name, NULL);
+
+  GtkWidget* item = gtk_menu_item_new_with_mnemonic (action_label);
+
+  g_signal_connect (item,
+                    "activate",
+                    G_CALLBACK (&x_tabs_menu_item_on_activate_action),
+                    action);
+#else /* GTK2 */
+
   GschemAction* action = gschem_action_new (action_name,  /* name */
                                             action_label, /* label */
                                             NULL,         /* tooltip */
@@ -1767,6 +1815,8 @@ x_tabs_menu_create_item (GschemToplevel* toplevel,
                                             NULL);        /* multikey_accel */
 
   GtkWidget* item = gtk_action_create_menu_item (GTK_ACTION (action));
+#endif
+
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
   g_signal_connect (action,
