@@ -2,7 +2,7 @@
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2021 Lepton EDA Contributors
+ * Copyright (C) 2017-2022 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -197,6 +197,8 @@ void x_window_setup_draw_events_main_wnd (GschemToplevel* w_current,
 } /* x_window_setup_draw_events_main_wnd() */
 
 
+gpointer _key_event_callback = NULL;
+
 
 /*! \brief Set up callbacks for the drawing area.
  *  \par Function Description
@@ -227,8 +229,8 @@ void x_window_setup_draw_events_drawing_area (GschemToplevel* w_current,
     { "button_release_event", G_CALLBACK(x_event_button_released)              },
     { "motion_notify_event",  G_CALLBACK(x_event_motion)                       },
     { "configure_event",      G_CALLBACK(x_event_configure)                    },
-    { "key_press_event",      G_CALLBACK(x_event_key)                          },
-    { "key_release_event",    G_CALLBACK(x_event_key)                          },
+    { "key_press_event",      G_CALLBACK(_key_event_callback)                   },
+    { "key_release_event",    G_CALLBACK(_key_event_callback)                   },
     { "scroll_event",         G_CALLBACK(x_event_scroll)                       },
     { "update-grid-info",     G_CALLBACK(i_update_grid_info_callback)          },
     { "notify::page",         G_CALLBACK(gschem_toplevel_notify_page_callback) },
@@ -285,6 +287,11 @@ void x_window_setup_draw_events_drawing_area (GschemToplevel* w_current,
 static GtkWidget *x_window_stock_pixmap(const char *stock, GschemToplevel *w_current)
 {
   GtkWidget *wpixmap = NULL;
+#ifdef ENABLE_GTK3
+  /* Look up the icon in the icon theme. */
+  wpixmap = gtk_image_new_from_icon_name (stock,
+                                          GTK_ICON_SIZE_LARGE_TOOLBAR);
+#else
   GtkStockItem item;
 
   gchar *stockid=g_strconcat("gtk-", stock, NULL);
@@ -300,6 +307,7 @@ static GtkWidget *x_window_stock_pixmap(const char *stock, GschemToplevel *w_cur
   }
 
   g_free(stockid);
+#endif
 
   return wpixmap;
 }
@@ -437,7 +445,9 @@ x_window_translate_response (GschemTranslateWidget *widget, gint response, Gsche
  *
  */
 GschemToplevel*
-x_window_create_main (GschemToplevel *w_current, GtkWidget *menubar)
+x_window_create_main (GschemToplevel *w_current,
+                      GtkWidget *menubar,
+                      gpointer key_event_callback)
 {
   GtkWidget *main_box = NULL;
   GtkWidget *hpaned = NULL;
@@ -501,6 +511,8 @@ x_window_create_main (GschemToplevel *w_current, GtkWidget *menubar)
   work_box = gtk_vbox_new (FALSE, 0);
 #endif
 
+  _key_event_callback = key_event_callback;
+
   if (x_tabs_enabled())
   {
     x_tabs_create (w_current, work_box);
@@ -669,12 +681,6 @@ void x_window_close(GschemToplevel *w_current)
     o_buffer_free (w_current);
   }
 
-  /* Allow Scheme value for this window to be garbage-collected */
-  if (!scm_is_eq (w_current->smob, SCM_UNDEFINED)) {
-    scm_gc_unprotect_object (w_current->smob);
-    w_current->smob = SCM_UNDEFINED;
-  }
-
   /* finally close the main window */
   gtk_widget_destroy(w_current->main_window);
 
@@ -776,7 +782,7 @@ x_window_open_page_impl (GschemToplevel *w_current,
 
 
   /* Run hook: */
-  g_run_hook_page (w_current, "%open-page-hook", page);
+  g_run_hook_page (w_current, "open-page-hook", page);
 
   /* Add page file name to the recent file list: */
   recent_manager_add (w_current, filename);
@@ -996,7 +1002,7 @@ x_window_close_page_impl (GschemToplevel *w_current,
  */
 GschemToplevel* x_window_new ()
 {
-  LeptonToplevel *toplevel = s_toplevel_new ();
+  LeptonToplevel *toplevel = lepton_toplevel_new ();
 
   /* Load old (*rc files) and new (*.conf) configuration: */
   x_rc_parse_gschem (toplevel, NULL);
@@ -1133,25 +1139,25 @@ create_toolbar( GschemToplevel *w_current, GtkWidget *main_box )
 #endif
 
   create_toolbar_button (w_current, toolbar,
-                         "new", _("New"), _("New file"),
+                         "document-new", _("New"), _("New file"),
                          G_CALLBACK (&i_callback_file_new), 0);
 
   create_toolbar_button (w_current, toolbar,
-                         "open", _("Open"), _("Open file"),
+                         "document-open", _("Open"), _("Open file"),
                          G_CALLBACK (&i_callback_file_open), 1);
 
   create_toolbar_button (w_current, toolbar,
-                         "save", _("Save"), _("Save file"),
+                         "document-save", _("Save"), _("Save file"),
                          G_CALLBACK (&i_callback_file_save), 2);
 
   create_toolbar_separator (toolbar, 3);
 
   create_toolbar_button (w_current, toolbar,
-                         "undo", _("Undo"), _("Undo last operation"),
+                         "edit-undo", _("Undo"), _("Undo last operation"),
                          G_CALLBACK (&i_callback_edit_undo), 4);
 
   create_toolbar_button (w_current, toolbar,
-                         "redo", _("Redo"), _("Redo last undo"),
+                         "edit-redo", _("Redo"), _("Redo last undo"),
                          G_CALLBACK (&i_callback_edit_redo), 5);
 
   create_toolbar_separator (toolbar, 6);
@@ -1580,7 +1586,7 @@ x_window_new_page (GschemToplevel* w_current)
   g_free (filename);
 
   /* Run hook: */
-  g_run_hook_page (w_current, "%new-page-hook", page);
+  g_run_hook_page (w_current, "new-page-hook", page);
 
   /* Save current state of the page: */
   o_undo_savestate (w_current, page, UNDO_ALL);
