@@ -1,7 +1,4 @@
-#!/usr/bin/env sh
-exec @GUILE@ -s "$0" "$@"
-!#
-;;; Copyright (C) 2019-2021 Lepton EDA Contributors
+;;; Copyright (C) 2019-2022 Lepton EDA Contributors
 ;;;
 ;;; Based on Python script by Stuart Brorson:
 ;;; Copyright (C) 2003 Stuart Brorson <sdb@cloud9.net>
@@ -60,11 +57,6 @@ exec @GUILE@ -s "$0" "$@"
 ;;;   Before each move, make sure that no overwrite of existing
 ;;;   files will occur.
 
-(eval-when (expand load eval)
-  (unless (getenv "LIBLEPTON")
-    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")
-    (set! %load-compiled-path (cons "@ccachedir@" %load-compiled-path))))
-
 (use-modules (ice-9 ftw)
              (ice-9 getopt-long)
              (ice-9 match)
@@ -74,7 +66,19 @@ exec @GUILE@ -s "$0" "$@"
              (ice-9 rdelim)
              (srfi srfi-1)
              (srfi srfi-26)
-             (lepton ffi))
+             (lepton ffi)
+             (lepton file-system)
+             (lepton library component)
+             (lepton library)
+             (lepton log)
+             (lepton object)
+             (lepton os)
+             (lepton page)
+             (lepton rc)
+             (lepton toplevel)
+             (lepton version)
+             (netlist schematic)
+             (netlist schematic-component))
 
 ;;; Initialize liblepton library.
 (liblepton_init)
@@ -82,20 +86,6 @@ exec @GUILE@ -s "$0" "$@"
   (register-data-dirs))
 (edascm_init)
 
-(primitive-eval
- '(use-modules (lepton core toplevel)
-               (lepton log)
-               (lepton file-system)
-               (lepton library)
-               (lepton library component)
-               (lepton object)
-               (lepton os)
-               (lepton page)
-               (lepton rc)
-               (lepton version)
-               (netlist schematic)
-               (netlist schematic-component)))
-
 
 ;;; Helper functions and data structures.
 
