@@ -1,11 +1,7 @@
-#!/usr/bin/env sh
-exec @GUILE@ -s "$0" "$@"
-!#
-
 ;;; Lepton EDA attribute editor
 ;;; Copyright (C) 2003-2010 Stuart D. Brorson.
 ;;; Copyright (C) 2005-2016 gEDA Contributors
-;;; Copyright (C) 2017-2021 Lepton EDA Contributors
+;;; Copyright (C) 2017-2022 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -21,17 +17,18 @@ exec @GUILE@ -s "$0" "$@"
 ;;; along with this program; if not, write to the Free Software
 ;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-(eval-when (expand load eval)
-  (unless (getenv "LIBLEPTON")
-    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")
-    (set! %load-compiled-path (cons "@ccachedir@" %load-compiled-path))))
-
 (use-modules (ice-9 getopt-long)
              (ice-9 receive)
              (srfi srfi-1)
              (system foreign)
+             (lepton ffi lib)
              (lepton ffi)
-             (lepton ffi lib))
+             (lepton file-system)
+             (lepton log)
+             (lepton page)
+             (lepton rc)
+             (lepton toplevel)
+             (lepton version))
 
 ;;; Initialize liblepton library.
 (liblepton_init)
@@ -41,39 +38,33 @@ exec @GUILE@ -s "$0" "$@"
 
 (define libleptonattrib (dynamic-link %libleptonattrib))
 
-(define gtk-init
+(define gtk_init
   (pointer->procedure
    void
    (dynamic-func "gtk_init" libgtk)
    (list '* '*)))
 
-(define gtk-main
-  (pointer->procedure
-   void
-   (dynamic-func "gtk_main" libgtk)
-   '()))
-
-(define set-verbose-mode!
+(define set_verbose_mode
   (pointer->procedure
    void
    (dynamic-func "set_verbose_mode" libleptonattrib)
    '()))
 
-(define fileselect-open
+(define x_fileselect_open
   (pointer->procedure
    '*
    (dynamic-func "x_fileselect_open" libleptonattrib)
    '()))
 
-(define lepton-attrib-window
+(define lepton_attrib_window
   (pointer->procedure
-   void
+   int
    (dynamic-func "lepton_attrib_window" libleptonattrib)
    '()))
 
 ;;; Localization.
 (define %textdomain "libleptonattrib")
-(bindtextdomain %textdomain "@localedir@")
+(bindtextdomain %textdomain %lepton-localedir)
 (textdomain %textdomain)
 (bind-textdomain-codeset %textdomain "UTF-8")
 (setlocale LC_ALL "")
@@ -81,13 +72,6 @@ exec @GUILE@ -s "$0" "$@"
 
 (define (G_ msg) (gettext msg %textdomain))
 
-(primitive-eval '(use-modules (lepton core toplevel)
-                              (lepton file-system)
-                              (lepton log)
-                              (lepton page)
-                              (lepton rc)
-                              (lepton version)))
-
 (define (usage)
   (format #t
           (G_ "Usage: ~A [OPTIONS] FILE ...
@@ -107,7 +91,7 @@ Lepton EDA homepage: ~S
           (lepton-version-ref 'bugs)
           (lepton-version-ref 'url))
 
-  (primitive-exit 0))
+  (exit 0))
 
 
 (define (report-unreadable filename)
@@ -149,8 +133,8 @@ Lepton EDA homepage: ~S
   ;; Output version to stdout and exit, if requested.
   (when version
     (display-lepton-version #:print-name #t #:copyright #t)
-    (primitive-exit 0))
-  (when verbose? (set-verbose-mode!))
+    (exit 0))
+  (when verbose? (set_verbose_mode))
 
   (receive (readable-files unreadable-files)
       (partition file-readable? files)
@@ -158,26 +142,24 @@ Lepton EDA homepage: ~S
         ;; Main procedure.
         (begin
           ;; Initialize GTK.
-          (gtk-init %null-pointer %null-pointer)
+          (gtk_init %null-pointer %null-pointer)
           (let ((files (if (null? readable-files)
                            ;; No files specified on the command
                            ;; line, pop up the File open dialog.
-                           (gslist->list (fileselect-open))
+                           (gslist->list (x_fileselect_open))
                            readable-files)))
             (if (null? files)
-                (primitive-exit 0)
+                (exit 0)
                 (%with-toplevel (%make-toplevel)
                  (lambda ()
                    (for-each process-gafrc* files)
                    ;; Open all files.
                    (for-each file->page files)
                    ;; Run attribute editor.
-                   (lepton-attrib-window)
-                   ;; Run main GTK loop.
-                   (gtk-main)
-                   (primitive-exit 0))))))
+                   (exit (lepton_attrib_window)))))))
+
         ;; There are non-existing or unreadable files.  Report and
         ;; exit.
         (begin
           (for-each report-unreadable unreadable-files)
-          (primitive-exit 1)))))
+          (exit 1)))))
