@@ -1,9 +1,6 @@
-#!/usr/bin/env sh
-exec @GUILE@ -s "$0" "$@"
-!#
 ;;; Lepton EDA Symbol Checker
 ;;; Scheme API
-;;; Copyright (C) 2017-2021 Lepton EDA Contributors
+;;; Copyright (C) 2017-2022 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -19,12 +16,9 @@ exec @GUILE@ -s "$0" "$@"
 ;;; along with this program; if not, write to the Free Software
 ;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-(eval-when (expand load eval)
-  (unless (getenv "LIBLEPTON")
-    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")
-    (set! %load-compiled-path (cons "@ccachedir@" %load-compiled-path))))
-
-(use-modules (lepton ffi))
+(use-modules (lepton ffi)
+             (lepton toplevel)
+             (symcheck check))
 
 ;;; Initialize liblepton library.
 (liblepton_init)
@@ -35,15 +29,7 @@ exec @GUILE@ -s "$0" "$@"
 ;;; Localization.
 (define %textdomain "lepton-symcheck")
 (textdomain %textdomain)
-(bindtextdomain %textdomain "@localedir@")
+(bindtextdomain %textdomain %lepton-localedir)
 (bind-textdomain-codeset %textdomain "UTF-8")
 
-;;; At compile time of this program guile won't be aware of these
-;;; modules, since it compiles the code before loading the above
-;;; extension. Let's make it quiet here.
-(define with-toplevel (@@ (lepton core toplevel) %with-toplevel))
-(define make-toplevel (@@ (lepton core toplevel) %make-toplevel))
-
-(primitive-eval '(use-modules (symcheck check)))
-
-(with-toplevel (make-toplevel) check-all-symbols)
+(%with-toplevel (%make-toplevel) check-all-symbols)
