@@ -1,7 +1,4 @@
-#!/usr/bin/env sh
-exec @GUILE@ -s "$0" "$@"
-!#
-;;; Copyright (C) 2019-2021 Lepton EDA Contributors
+;;; Copyright (C) 2019-2022 Lepton EDA Contributors
 ;;;
 ;;; Based on Python script by Werner Hoch
 ;;; Copyright (C) 2001,2002,2003,2004,2006,2007,2008 Werner Hoch <werner.ho@gmx.de>
@@ -35,11 +32,6 @@ exec @GUILE@ -s "$0" "$@"
 ;;;   defined by the greater number of pins at the top or at the
 ;;;   bottom of the symbol, and the width requested.
 
-(eval-when (expand load eval)
-  (unless (getenv "LIBLEPTON")
-    (add-to-load-path "@LEPTON_SCHEME_MODULE_DIRECTORY@")
-    (set! %load-compiled-path (cons "@ccachedir@" %load-compiled-path))))
-
 (use-modules (ice-9 getopt-long)
              (ice-9 match)
              (ice-9 rdelim)
@@ -47,7 +39,13 @@ exec @GUILE@ -s "$0" "$@"
              (srfi srfi-1)
              (srfi srfi-9)
              (sxml match)
-             (lepton ffi))
+             (lepton attrib)
+             (lepton ffi)
+             (lepton object)
+             (lepton page)
+             (lepton toplevel)
+             (lepton version)
+             (netlist attrib compare))
 
 ;;; Initialize liblepton library.
 (liblepton_init)
@@ -55,13 +53,6 @@ exec @GUILE@ -s "$0" "$@"
   (register-data-dirs))
 (edascm_init)
 
-(primitive-eval '(use-modules (lepton core toplevel)
-                              (lepton attrib)
-                              (lepton object)
-                              (lepton page)
-                              (lepton version)
-                              (netlist attrib compare)))
-
 (define %option-spec
   '((help    (single-char #\h) (value #f))
    (version (single-char #\V) (value #f))))
